/********************************************************************************
** Form generated from reading UI file 'keydialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_KEYDIALOG_H
#define UI_KEYDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_keyDialog
{
public:
    QPushButton *pbOpen;
    QPushButton *pbCancel;
    QLabel *label;
    QLineEdit *lineEditKey;
    QPushButton *pbkeyOption;
    QLabel *label_2;
    QPushButton *pbOpenMountPoint;
    QLineEdit *lineEditMountPoint;
    QCheckBox *checkBoxOpenReadOnly;
    QCheckBox *checkBoxShareMountPoint;
    QPushButton *pbOptions;
    QComboBox *cbKeyType;
    QCheckBox *checkBoxVeraCryptVolume;
    QCheckBox *checkBoxVisibleKey;
    QCheckBox *checkBoxVeraCryptSystemVolume;
    QLineEdit *lineEditPIM;
    QLabel *labelVeraCryptPIM;
    QLabel *veraCryptWarning;
    QPushButton *pushButton;
    QFrame *frame;
    QLabel *label_3;
    QLabel *label_4;
    QLineEdit *lineEditVolumeOffset;
    QLineEdit *lineEditFsOptions;
    QPushButton *pbSet;
    QPushButton *pbCancelOptions;

    void setupUi(QDialog *keyDialog)
    {
        if (keyDialog->objectName().isEmpty())
            keyDialog->setObjectName(QString::fromUtf8("keyDialog"));
        keyDialog->resize(521, 266);
        keyDialog->setAcceptDrops(true);
        pbOpen = new QPushButton(keyDialog);
        pbOpen->setObjectName(QString::fromUtf8("pbOpen"));
        pbOpen->setGeometry(QRect(210, 230, 101, 31));
        pbCancel = new QPushButton(keyDialog);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(310, 230, 101, 31));
        label = new QLabel(keyDialog);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(0, 200, 101, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        lineEditKey = new QLineEdit(keyDialog);
        lineEditKey->setObjectName(QString::fromUtf8("lineEditKey"));
        lineEditKey->setGeometry(QRect(110, 200, 301, 31));
        pbkeyOption = new QPushButton(keyDialog);
        pbkeyOption->setObjectName(QString::fromUtf8("pbkeyOption"));
        pbkeyOption->setGeometry(QRect(410, 200, 31, 31));
        label_2 = new QLabel(keyDialog);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 0, 101, 51));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        pbOpenMountPoint = new QPushButton(keyDialog);
        pbOpenMountPoint->setObjectName(QString::fromUtf8("pbOpenMountPoint"));
        pbOpenMountPoint->setGeometry(QRect(410, 10, 31, 31));
        lineEditMountPoint = new QLineEdit(keyDialog);
        lineEditMountPoint->setObjectName(QString::fromUtf8("lineEditMountPoint"));
        lineEditMountPoint->setGeometry(QRect(110, 10, 301, 31));
        checkBoxOpenReadOnly = new QCheckBox(keyDialog);
        checkBoxOpenReadOnly->setObjectName(QString::fromUtf8("checkBoxOpenReadOnly"));
        checkBoxOpenReadOnly->setGeometry(QRect(140, 40, 271, 31));
        checkBoxShareMountPoint = new QCheckBox(keyDialog);
        checkBoxShareMountPoint->setObjectName(QString::fromUtf8("checkBoxShareMountPoint"));
        checkBoxShareMountPoint->setGeometry(QRect(140, 60, 271, 31));
        pbOptions = new QPushButton(keyDialog);
        pbOptions->setObjectName(QString::fromUtf8("pbOptions"));
        pbOptions->setGeometry(QRect(110, 230, 101, 31));
        cbKeyType = new QComboBox(keyDialog);
        cbKeyType->setObjectName(QString::fromUtf8("cbKeyType"));
        cbKeyType->setGeometry(QRect(110, 170, 301, 31));
        checkBoxVeraCryptVolume = new QCheckBox(keyDialog);
        checkBoxVeraCryptVolume->setObjectName(QString::fromUtf8("checkBoxVeraCryptVolume"));
        checkBoxVeraCryptVolume->setGeometry(QRect(140, 80, 271, 31));
        checkBoxVisibleKey = new QCheckBox(keyDialog);
        checkBoxVisibleKey->setObjectName(QString::fromUtf8("checkBoxVisibleKey"));
        checkBoxVisibleKey->setGeometry(QRect(410, 200, 31, 31));
        checkBoxVeraCryptSystemVolume = new QCheckBox(keyDialog);
        checkBoxVeraCryptSystemVolume->setObjectName(QString::fromUtf8("checkBoxVeraCryptSystemVolume"));
        checkBoxVeraCryptSystemVolume->setGeometry(QRect(140, 100, 271, 31));
        lineEditPIM = new QLineEdit(keyDialog);
        lineEditPIM->setObjectName(QString::fromUtf8("lineEditPIM"));
        lineEditPIM->setGeometry(QRect(140, 130, 61, 31));
        lineEditPIM->setEchoMode(QLineEdit::Password);
        labelVeraCryptPIM = new QLabel(keyDialog);
        labelVeraCryptPIM->setObjectName(QString::fromUtf8("labelVeraCryptPIM"));
        labelVeraCryptPIM->setGeometry(QRect(210, 130, 201, 31));
        veraCryptWarning = new QLabel(keyDialog);
        veraCryptWarning->setObjectName(QString::fromUtf8("veraCryptWarning"));
        veraCryptWarning->setGeometry(QRect(0, 0, 521, 271));
        veraCryptWarning->setAutoFillBackground(true);
        veraCryptWarning->setAlignment(Qt::AlignCenter);
        veraCryptWarning->setWordWrap(true);
        pushButton = new QPushButton(keyDialog);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(210, 222, 101, 31));
        frame = new QFrame(keyDialog);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setGeometry(QRect(10, 10, 501, 251));
        frame->setAutoFillBackground(true);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        label_3 = new QLabel(frame);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(80, 50, 341, 51));
        label_3->setAlignment(Qt::AlignCenter);
        label_3->setWordWrap(true);
        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(80, 130, 341, 51));
        label_4->setAlignment(Qt::AlignCenter);
        label_4->setWordWrap(true);
        lineEditVolumeOffset = new QLineEdit(frame);
        lineEditVolumeOffset->setObjectName(QString::fromUtf8("lineEditVolumeOffset"));
        lineEditVolumeOffset->setGeometry(QRect(80, 100, 341, 31));
        lineEditFsOptions = new QLineEdit(frame);
        lineEditFsOptions->setObjectName(QString::fromUtf8("lineEditFsOptions"));
        lineEditFsOptions->setGeometry(QRect(80, 180, 341, 31));
        pbSet = new QPushButton(frame);
        pbSet->setObjectName(QString::fromUtf8("pbSet"));
        pbSet->setGeometry(QRect(140, 210, 111, 33));
        pbCancelOptions = new QPushButton(frame);
        pbCancelOptions->setObjectName(QString::fromUtf8("pbCancelOptions"));
        pbCancelOptions->setGeometry(QRect(250, 210, 111, 33));
        QWidget::setTabOrder(lineEditMountPoint, pbOpenMountPoint);
        QWidget::setTabOrder(pbOpenMountPoint, checkBoxOpenReadOnly);
        QWidget::setTabOrder(checkBoxOpenReadOnly, checkBoxShareMountPoint);
        QWidget::setTabOrder(checkBoxShareMountPoint, checkBoxVeraCryptVolume);
        QWidget::setTabOrder(checkBoxVeraCryptVolume, cbKeyType);
        QWidget::setTabOrder(cbKeyType, lineEditKey);
        QWidget::setTabOrder(lineEditKey, pbkeyOption);
        QWidget::setTabOrder(pbkeyOption, checkBoxVisibleKey);
        QWidget::setTabOrder(checkBoxVisibleKey, pbOptions);
        QWidget::setTabOrder(pbOptions, pbOpen);
        QWidget::setTabOrder(pbOpen, pbCancel);

        retranslateUi(keyDialog);

        pbOpen->setDefault(true);


        QMetaObject::connectSlotsByName(keyDialog);
    } // setupUi

    void retranslateUi(QDialog *keyDialog)
    {
        keyDialog->setWindowTitle(QCoreApplication::translate("keyDialog", "unlock and mount a luks volume", nullptr));
        pbOpen->setText(QCoreApplication::translate("keyDialog", "&Open", nullptr));
        pbCancel->setText(QCoreApplication::translate("keyDialog", "&Cancel", nullptr));
        label->setText(QCoreApplication::translate("keyDialog", "Key", nullptr));
        pbkeyOption->setText(QString());
        label_2->setText(QCoreApplication::translate("keyDialog", "Mount Name", nullptr));
        pbOpenMountPoint->setText(QString());
        checkBoxOpenReadOnly->setText(QCoreApplication::translate("keyDialog", "Mount In &Read Only Mode", nullptr));
        checkBoxShareMountPoint->setText(QCoreApplication::translate("keyDialog", "&Share Mount Point", nullptr));
        pbOptions->setText(QCoreApplication::translate("keyDialog", "O&ptions", nullptr));
        checkBoxVeraCryptVolume->setText(QCoreApplication::translate("keyDialog", "&VeraCrypt Volume", nullptr));
        checkBoxVisibleKey->setText(QString());
        checkBoxVeraCryptSystemVolume->setText(QCoreApplication::translate("keyDialog", "VeraCrypt System Volume", nullptr));
        labelVeraCryptPIM->setText(QCoreApplication::translate("keyDialog", "VeraCrypt PIM Value", nullptr));
        veraCryptWarning->setText(QString());
        pushButton->setText(QCoreApplication::translate("keyDialog", "&OK", nullptr));
        label_3->setText(QCoreApplication::translate("keyDialog", "Enter Below The Offset Location Of The Volume About To Be Opened.", nullptr));
        label_4->setText(QCoreApplication::translate("keyDialog", "Enter Comma Separated Volume's File System Options Below", nullptr));
        pbSet->setText(QCoreApplication::translate("keyDialog", "Set", nullptr));
        pbCancelOptions->setText(QCoreApplication::translate("keyDialog", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class keyDialog: public Ui_keyDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_KEYDIALOG_H
