/********************************************************************************
** Form generated from reading UI file 'warnwhenextendingcontainerfile.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_WARNWHENEXTENDINGCONTAINERFILE_H
#define UI_WARNWHENEXTENDINGCONTAINERFILE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_warnWhenExtendingContainerFile
{
public:
    QPushButton *pbOk;
    QCheckBox *checkBox;
    QLabel *label;
    QLabel *label_2;

    void setupUi(QDialog *warnWhenExtendingContainerFile)
    {
        if (warnWhenExtendingContainerFile->objectName().isEmpty())
            warnWhenExtendingContainerFile->setObjectName(QString::fromUtf8("warnWhenExtendingContainerFile"));
        warnWhenExtendingContainerFile->resize(651, 337);
        pbOk = new QPushButton(warnWhenExtendingContainerFile);
        pbOk->setObjectName(QString::fromUtf8("pbOk"));
        pbOk->setGeometry(QRect(269, 300, 111, 33));
        checkBox = new QCheckBox(warnWhenExtendingContainerFile);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setGeometry(QRect(200, 270, 321, 31));
        label = new QLabel(warnWhenExtendingContainerFile);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 40, 631, 231));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        label_2 = new QLabel(warnWhenExtendingContainerFile);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 0, 651, 41));
        QFont font;
        font.setPointSize(12);
        font.setBold(true);
        font.setWeight(75);
        label_2->setFont(font);
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);

        retranslateUi(warnWhenExtendingContainerFile);

        QMetaObject::connectSlotsByName(warnWhenExtendingContainerFile);
    } // setupUi

    void retranslateUi(QDialog *warnWhenExtendingContainerFile)
    {
        warnWhenExtendingContainerFile->setWindowTitle(QCoreApplication::translate("warnWhenExtendingContainerFile", "WARNING!!", nullptr));
        pbOk->setText(QCoreApplication::translate("warnWhenExtendingContainerFile", "OK", nullptr));
        checkBox->setText(QCoreApplication::translate("warnWhenExtendingContainerFile", "Dont Show This Warning Again.", nullptr));
        label->setText(QCoreApplication::translate("warnWhenExtendingContainerFile", "Your cover file will be irreversibly changed and we suggest continuing with a backup file and not the original.\n"
"\n"
"To unlock the volume about to be created, you will need to enter the password you will choose and the volume offset automatically generated by zuluCrypt.\n"
"\n"
"Instructions to unlock the volume are as follows:\n"
"1. From the menu, choose Open -> Volume Hosted In A File.\n"
"2. Select file, then choose \"Volume Type\" = PLAIN dm-crypt.\n"
"3. Enter the generated offset value along with your password. ", nullptr));
        label_2->setText(QCoreApplication::translate("warnWhenExtendingContainerFile", "IMPORTANT!!!", nullptr));
    } // retranslateUi

};

namespace Ui {
    class warnWhenExtendingContainerFile: public Ui_warnWhenExtendingContainerFile {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_WARNWHENEXTENDINGCONTAINERFILE_H
