/********************************************************************************
** Form generated from reading UI file 'createvolumeinexistingfile.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEVOLUMEINEXISTINGFILE_H
#define UI_CREATEVOLUMEINEXISTINGFILE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_createVolumeInExistingFIle
{
public:
    QFrame *frame;
    QLabel *label;
    QLineEdit *lineEditVolumePath;
    QPushButton *pbSetFile;
    QLabel *labelVolumeSize;
    QLineEdit *lineEditContainerSize;
    QLabel *labelVolumeProperties;
    QComboBox *cbVolumeProperties;
    QPushButton *pbCancel;
    QPushButton *pbCreate;
    QLabel *label_4;
    QFrame *frame_2;
    QLabel *labelHeader;
    QLineEdit *lineEditVolumeOffset;
    QLabel *label_2;
    QLineEdit *lineEditPassword;
    QCheckBox *cbShowPassword;
    QLabel *labelWarning;

    void setupUi(QDialog *createVolumeInExistingFIle)
    {
        if (createVolumeInExistingFIle->objectName().isEmpty())
            createVolumeInExistingFIle->setObjectName(QString::fromUtf8("createVolumeInExistingFIle"));
        createVolumeInExistingFIle->resize(643, 326);
        frame = new QFrame(createVolumeInExistingFIle);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setGeometry(QRect(10, 10, 621, 311));
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(0, 70, 171, 51));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        lineEditVolumePath = new QLineEdit(frame);
        lineEditVolumePath->setObjectName(QString::fromUtf8("lineEditVolumePath"));
        lineEditVolumePath->setGeometry(QRect(180, 80, 261, 31));
        pbSetFile = new QPushButton(frame);
        pbSetFile->setObjectName(QString::fromUtf8("pbSetFile"));
        pbSetFile->setGeometry(QRect(440, 80, 31, 31));
        labelVolumeSize = new QLabel(frame);
        labelVolumeSize->setObjectName(QString::fromUtf8("labelVolumeSize"));
        labelVolumeSize->setGeometry(QRect(0, 160, 171, 31));
        labelVolumeSize->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumeSize->setWordWrap(true);
        lineEditContainerSize = new QLineEdit(frame);
        lineEditContainerSize->setObjectName(QString::fromUtf8("lineEditContainerSize"));
        lineEditContainerSize->setGeometry(QRect(180, 160, 131, 31));
        labelVolumeProperties = new QLabel(frame);
        labelVolumeProperties->setObjectName(QString::fromUtf8("labelVolumeProperties"));
        labelVolumeProperties->setGeometry(QRect(0, 240, 171, 31));
        labelVolumeProperties->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumeProperties->setWordWrap(true);
        cbVolumeProperties = new QComboBox(frame);
        cbVolumeProperties->setObjectName(QString::fromUtf8("cbVolumeProperties"));
        cbVolumeProperties->setGeometry(QRect(180, 240, 261, 31));
        pbCancel = new QPushButton(frame);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(310, 280, 121, 31));
        pbCreate = new QPushButton(frame);
        pbCreate->setObjectName(QString::fromUtf8("pbCreate"));
        pbCreate->setGeometry(QRect(190, 280, 121, 31));
        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(0, 120, 171, 31));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4->setWordWrap(true);
        frame_2 = new QFrame(frame);
        frame_2->setObjectName(QString::fromUtf8("frame_2"));
        frame_2->setGeometry(QRect(10, 10, 601, 61));
        frame_2->setFrameShape(QFrame::StyledPanel);
        frame_2->setFrameShadow(QFrame::Raised);
        labelHeader = new QLabel(frame_2);
        labelHeader->setObjectName(QString::fromUtf8("labelHeader"));
        labelHeader->setGeometry(QRect(0, 0, 601, 61));
        labelHeader->setAlignment(Qt::AlignCenter);
        labelHeader->setWordWrap(true);
        lineEditVolumeOffset = new QLineEdit(frame);
        lineEditVolumeOffset->setObjectName(QString::fromUtf8("lineEditVolumeOffset"));
        lineEditVolumeOffset->setGeometry(QRect(180, 120, 131, 31));
        lineEditVolumeOffset->setReadOnly(true);
        label_2 = new QLabel(frame);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 200, 171, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        lineEditPassword = new QLineEdit(frame);
        lineEditPassword->setObjectName(QString::fromUtf8("lineEditPassword"));
        lineEditPassword->setGeometry(QRect(180, 200, 261, 31));
        lineEditPassword->setEchoMode(QLineEdit::Password);
        cbShowPassword = new QCheckBox(frame);
        cbShowPassword->setObjectName(QString::fromUtf8("cbShowPassword"));
        cbShowPassword->setGeometry(QRect(440, 200, 21, 31));
        labelWarning = new QLabel(frame);
        labelWarning->setObjectName(QString::fromUtf8("labelWarning"));
        labelWarning->setGeometry(QRect(-10, -10, 641, 321));
        labelWarning->setAutoFillBackground(true);
        labelWarning->setAlignment(Qt::AlignCenter);
        labelWarning->setWordWrap(true);
        QWidget::setTabOrder(lineEditVolumePath, pbSetFile);
        QWidget::setTabOrder(pbSetFile, lineEditVolumeOffset);
        QWidget::setTabOrder(lineEditVolumeOffset, lineEditContainerSize);
        QWidget::setTabOrder(lineEditContainerSize, lineEditPassword);
        QWidget::setTabOrder(lineEditPassword, cbShowPassword);
        QWidget::setTabOrder(cbShowPassword, cbVolumeProperties);
        QWidget::setTabOrder(cbVolumeProperties, pbCreate);
        QWidget::setTabOrder(pbCreate, pbCancel);

        retranslateUi(createVolumeInExistingFIle);

        QMetaObject::connectSlotsByName(createVolumeInExistingFIle);
    } // setupUi

    void retranslateUi(QDialog *createVolumeInExistingFIle)
    {
        createVolumeInExistingFIle->setWindowTitle(QCoreApplication::translate("createVolumeInExistingFIle", "Create Volume In Existing File", nullptr));
        label->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Select Cover File (Video files like mp4 and mkv)", nullptr));
        pbSetFile->setText(QString());
        labelVolumeSize->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Container Size (MB)", nullptr));
        labelVolumeProperties->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Volume Properties", nullptr));
        pbCancel->setText(QCoreApplication::translate("createVolumeInExistingFIle", "&Cancel", nullptr));
        pbCreate->setText(QCoreApplication::translate("createVolumeInExistingFIle", "C&reate", nullptr));
        label_4->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Volume OffSet\n"
"(Auto calculated)", nullptr));
        labelHeader->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Create A Plain dm-crypt Container Hidden Inside Cover File (Steganography)", nullptr));
        label_2->setText(QCoreApplication::translate("createVolumeInExistingFIle", "Password", nullptr));
        cbShowPassword->setText(QString());
        labelWarning->setText(QCoreApplication::translate("createVolumeInExistingFIle", "TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class createVolumeInExistingFIle: public Ui_createVolumeInExistingFIle {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEVOLUMEINEXISTINGFILE_H
