/********************************************************************************
** Form generated from reading UI file 'favorites2.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FAVORITES2_H
#define UI_FAVORITES2_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QRadioButton>
#include <QtWidgets/QTabWidget>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_favorites2
{
public:
    QTabWidget *tabWidget;
    QWidget *FavoritesList;
    QTableWidget *tableWidget;
    QPushButton *pbAdd;
    QLineEdit *lineEditVolumeID;
    QLabel *label;
    QPushButton *pbFile;
    QPushButton *pbPartition;
    QLineEdit *lineEditMountPath;
    QLabel *label_2;
    QPushButton *pbClose;
    QLineEdit *lineEditMountOptions;
    QLabel *label_3;
    QPushButton *pbFolder;
    QWidget *ManageVolumeKeys;
    QFrame *frame_3;
    QGroupBox *groupBoxKeys;
    QRadioButton *rbInternalWallet;
    QRadioButton *rbLibSecret;
    QRadioButton *rbKWallet;
    QRadioButton *rbNone;
    QTableWidget *tableWidgetWallet;
    QLabel *label_21;
    QLineEdit *lineEditVolumePath;
    QLabel *label_23;
    QLineEdit *lineEditPassword;
    QPushButton *pbAddKeyToWallet;
    QPushButton *pbVolumePathFromFavorites;
    QLabel *label_22;
    QPushButton *pbChangeWalletPassword;
    QCheckBox *cbShowPassword;
    QPushButton *pbClose_2;
    QLabel *labelPassword;
    QPushButton *pbVisiblePassword;
    QPushButton *pbVolumePathFromFileSystem;

    void setupUi(QDialog *favorites2)
    {
        if (favorites2->objectName().isEmpty())
            favorites2->setObjectName(QString::fromUtf8("favorites2"));
        favorites2->resize(791, 474);
        tabWidget = new QTabWidget(favorites2);
        tabWidget->setObjectName(QString::fromUtf8("tabWidget"));
        tabWidget->setGeometry(QRect(10, 10, 771, 461));
        FavoritesList = new QWidget();
        FavoritesList->setObjectName(QString::fromUtf8("FavoritesList"));
        tableWidget = new QTableWidget(FavoritesList);
        if (tableWidget->columnCount() < 2)
            tableWidget->setColumnCount(2);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        __qtablewidgetitem1->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setGeometry(QRect(10, 0, 741, 301));
        tableWidget->setSizeAdjustPolicy(QAbstractScrollArea::AdjustToContents);
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setShowGrid(false);
        tableWidget->horizontalHeader()->setMinimumSectionSize(80);
        pbAdd = new QPushButton(FavoritesList);
        pbAdd->setObjectName(QString::fromUtf8("pbAdd"));
        pbAdd->setGeometry(QRect(190, 390, 181, 33));
        lineEditVolumeID = new QLineEdit(FavoritesList);
        lineEditVolumeID->setObjectName(QString::fromUtf8("lineEditVolumeID"));
        lineEditVolumeID->setGeometry(QRect(150, 300, 461, 31));
        label = new QLabel(FavoritesList);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 300, 131, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pbFile = new QPushButton(FavoritesList);
        pbFile->setObjectName(QString::fromUtf8("pbFile"));
        pbFile->setGeometry(QRect(610, 300, 41, 33));
        pbPartition = new QPushButton(FavoritesList);
        pbPartition->setObjectName(QString::fromUtf8("pbPartition"));
        pbPartition->setGeometry(QRect(650, 300, 41, 33));
        lineEditMountPath = new QLineEdit(FavoritesList);
        lineEditMountPath->setObjectName(QString::fromUtf8("lineEditMountPath"));
        lineEditMountPath->setGeometry(QRect(150, 330, 461, 31));
        label_2 = new QLabel(FavoritesList);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 330, 141, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pbClose = new QPushButton(FavoritesList);
        pbClose->setObjectName(QString::fromUtf8("pbClose"));
        pbClose->setGeometry(QRect(370, 390, 191, 31));
        lineEditMountOptions = new QLineEdit(FavoritesList);
        lineEditMountOptions->setObjectName(QString::fromUtf8("lineEditMountOptions"));
        lineEditMountOptions->setGeometry(QRect(150, 360, 461, 31));
        label_3 = new QLabel(FavoritesList);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(0, 360, 141, 31));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        pbFolder = new QPushButton(FavoritesList);
        pbFolder->setObjectName(QString::fromUtf8("pbFolder"));
        pbFolder->setGeometry(QRect(690, 300, 41, 33));
        tabWidget->addTab(FavoritesList, QString());
        ManageVolumeKeys = new QWidget();
        ManageVolumeKeys->setObjectName(QString::fromUtf8("ManageVolumeKeys"));
        frame_3 = new QFrame(ManageVolumeKeys);
        frame_3->setObjectName(QString::fromUtf8("frame_3"));
        frame_3->setGeometry(QRect(10, 10, 741, 411));
        frame_3->setFrameShape(QFrame::StyledPanel);
        frame_3->setFrameShadow(QFrame::Raised);
        groupBoxKeys = new QGroupBox(frame_3);
        groupBoxKeys->setObjectName(QString::fromUtf8("groupBoxKeys"));
        groupBoxKeys->setGeometry(QRect(10, 10, 201, 241));
        rbInternalWallet = new QRadioButton(groupBoxKeys);
        rbInternalWallet->setObjectName(QString::fromUtf8("rbInternalWallet"));
        rbInternalWallet->setGeometry(QRect(20, 90, 161, 41));
        rbLibSecret = new QRadioButton(groupBoxKeys);
        rbLibSecret->setObjectName(QString::fromUtf8("rbLibSecret"));
        rbLibSecret->setGeometry(QRect(20, 140, 161, 41));
        rbKWallet = new QRadioButton(groupBoxKeys);
        rbKWallet->setObjectName(QString::fromUtf8("rbKWallet"));
        rbKWallet->setGeometry(QRect(20, 190, 161, 41));
        rbNone = new QRadioButton(groupBoxKeys);
        rbNone->setObjectName(QString::fromUtf8("rbNone"));
        rbNone->setGeometry(QRect(20, 40, 161, 41));
        tableWidgetWallet = new QTableWidget(frame_3);
        if (tableWidgetWallet->columnCount() < 1)
            tableWidgetWallet->setColumnCount(1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setTextAlignment(Qt::AlignCenter);
        tableWidgetWallet->setHorizontalHeaderItem(0, __qtablewidgetitem2);
        tableWidgetWallet->setObjectName(QString::fromUtf8("tableWidgetWallet"));
        tableWidgetWallet->setGeometry(QRect(220, 10, 511, 241));
        tableWidgetWallet->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidgetWallet->setSelectionMode(QAbstractItemView::NoSelection);
        label_21 = new QLabel(frame_3);
        label_21->setObjectName(QString::fromUtf8("label_21"));
        label_21->setGeometry(QRect(260, 248, 421, 31));
        label_21->setAlignment(Qt::AlignCenter);
        lineEditVolumePath = new QLineEdit(frame_3);
        lineEditVolumePath->setObjectName(QString::fromUtf8("lineEditVolumePath"));
        lineEditVolumePath->setGeometry(QRect(260, 278, 411, 31));
        lineEditVolumePath->setEchoMode(QLineEdit::Normal);
        label_23 = new QLabel(frame_3);
        label_23->setObjectName(QString::fromUtf8("label_23"));
        label_23->setGeometry(QRect(260, 308, 421, 31));
        label_23->setAlignment(Qt::AlignCenter);
        lineEditPassword = new QLineEdit(frame_3);
        lineEditPassword->setObjectName(QString::fromUtf8("lineEditPassword"));
        lineEditPassword->setGeometry(QRect(260, 338, 411, 31));
        lineEditPassword->setEchoMode(QLineEdit::Password);
        pbAddKeyToWallet = new QPushButton(frame_3);
        pbAddKeyToWallet->setObjectName(QString::fromUtf8("pbAddKeyToWallet"));
        pbAddKeyToWallet->setGeometry(QRect(280, 370, 181, 31));
        pbVolumePathFromFavorites = new QPushButton(frame_3);
        pbVolumePathFromFavorites->setObjectName(QString::fromUtf8("pbVolumePathFromFavorites"));
        pbVolumePathFromFavorites->setGeometry(QRect(670, 278, 31, 31));
        label_22 = new QLabel(frame_3);
        label_22->setObjectName(QString::fromUtf8("label_22"));
        label_22->setGeometry(QRect(10, 278, 201, 51));
        label_22->setAlignment(Qt::AlignBottom|Qt::AlignHCenter);
        label_22->setWordWrap(true);
        pbChangeWalletPassword = new QPushButton(frame_3);
        pbChangeWalletPassword->setObjectName(QString::fromUtf8("pbChangeWalletPassword"));
        pbChangeWalletPassword->setGeometry(QRect(10, 340, 201, 31));
        cbShowPassword = new QCheckBox(frame_3);
        cbShowPassword->setObjectName(QString::fromUtf8("cbShowPassword"));
        cbShowPassword->setGeometry(QRect(670, 338, 31, 31));
        pbClose_2 = new QPushButton(frame_3);
        pbClose_2->setObjectName(QString::fromUtf8("pbClose_2"));
        pbClose_2->setGeometry(QRect(460, 370, 181, 31));
        labelPassword = new QLabel(frame_3);
        labelPassword->setObjectName(QString::fromUtf8("labelPassword"));
        labelPassword->setGeometry(QRect(120, 60, 531, 241));
        labelPassword->setAutoFillBackground(true);
        labelPassword->setAlignment(Qt::AlignCenter);
        labelPassword->setWordWrap(true);
        labelPassword->setTextInteractionFlags(Qt::LinksAccessibleByMouse|Qt::TextSelectableByKeyboard|Qt::TextSelectableByMouse);
        pbVisiblePassword = new QPushButton(frame_3);
        pbVisiblePassword->setObjectName(QString::fromUtf8("pbVisiblePassword"));
        pbVisiblePassword->setGeometry(QRect(310, 260, 131, 33));
        pbVolumePathFromFileSystem = new QPushButton(frame_3);
        pbVolumePathFromFileSystem->setObjectName(QString::fromUtf8("pbVolumePathFromFileSystem"));
        pbVolumePathFromFileSystem->setGeometry(QRect(700, 278, 31, 31));
        tabWidget->addTab(ManageVolumeKeys, QString());
        QWidget::setTabOrder(tabWidget, pbClose);
        QWidget::setTabOrder(pbClose, tableWidget);
        QWidget::setTabOrder(tableWidget, lineEditVolumePath);
        QWidget::setTabOrder(lineEditVolumePath, lineEditPassword);
        QWidget::setTabOrder(lineEditPassword, pbAddKeyToWallet);
        QWidget::setTabOrder(pbAddKeyToWallet, rbNone);
        QWidget::setTabOrder(rbNone, rbInternalWallet);
        QWidget::setTabOrder(rbInternalWallet, rbLibSecret);
        QWidget::setTabOrder(rbLibSecret, rbKWallet);
        QWidget::setTabOrder(rbKWallet, pbChangeWalletPassword);
        QWidget::setTabOrder(pbChangeWalletPassword, tableWidgetWallet);

        retranslateUi(favorites2);

        tabWidget->setCurrentIndex(0);


        QMetaObject::connectSlotsByName(favorites2);
    } // setupUi

    void retranslateUi(QDialog *favorites2)
    {
        favorites2->setWindowTitle(QCoreApplication::translate("favorites2", "Favorites", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("favorites2", "Volume ID", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("favorites2", "Mount Point", nullptr));
        pbAdd->setText(QCoreApplication::translate("favorites2", "Add", nullptr));
        label->setText(QCoreApplication::translate("favorites2", "Add A volume", nullptr));
        pbFile->setText(QString());
        pbPartition->setText(QString());
        label_2->setText(QCoreApplication::translate("favorites2", "Mount Path", nullptr));
        pbClose->setText(QCoreApplication::translate("favorites2", "&Close", nullptr));
        label_3->setText(QCoreApplication::translate("favorites2", "Mount Options", nullptr));
        pbFolder->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(FavoritesList), QCoreApplication::translate("favorites2", "Favorite List", nullptr));
        groupBoxKeys->setTitle(QCoreApplication::translate("favorites2", "Set Default Wallet", nullptr));
        rbInternalWallet->setText(QCoreApplication::translate("favorites2", "Internal Wallet", nullptr));
        rbLibSecret->setText(QCoreApplication::translate("favorites2", "Libsecret", nullptr));
        rbKWallet->setText(QCoreApplication::translate("favorites2", "KWallet", nullptr));
        rbNone->setText(QCoreApplication::translate("favorites2", "None", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidgetWallet->horizontalHeaderItem(0);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("favorites2", "Volume Path", nullptr));
        label_21->setText(QCoreApplication::translate("favorites2", "Enter Volume Path Below", nullptr));
        label_23->setText(QCoreApplication::translate("favorites2", "Enter Password Below", nullptr));
        pbAddKeyToWallet->setText(QCoreApplication::translate("favorites2", "Add", nullptr));
        pbVolumePathFromFavorites->setText(QString());
        label_22->setText(QCoreApplication::translate("favorites2", "Change Internal Wallet Password", nullptr));
        pbChangeWalletPassword->setText(QString());
        cbShowPassword->setText(QString());
        pbClose_2->setText(QCoreApplication::translate("favorites2", "&Close", nullptr));
        labelPassword->setText(QCoreApplication::translate("favorites2", "TextLabel", nullptr));
        pbVisiblePassword->setText(QCoreApplication::translate("favorites2", "Ok", nullptr));
        pbVolumePathFromFileSystem->setText(QString());
        tabWidget->setTabText(tabWidget->indexOf(ManageVolumeKeys), QCoreApplication::translate("favorites2", "Manage Keys In Wallets", nullptr));
    } // retranslateUi

};

namespace Ui {
    class favorites2: public Ui_favorites2 {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FAVORITES2_H
