/********************************************************************************
** Form generated from reading UI file 'changepassworddialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CHANGEPASSWORDDIALOG_H
#define UI_CHANGEPASSWORDDIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>

QT_BEGIN_NAMESPACE

class Ui_changePassWordDialog
{
public:
    QGroupBox *groupBox;
    QPushButton *pushButtonChange;
    QPushButton *pushButtonOK;
    QLineEdit *lineEditCurrentPassWord;
    QLineEdit *lineEditNewPassWord;
    QLineEdit *lineEditNewPassWord_2;
    QLabel *label;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QPushButton *pushButtonCancel;
    QTextEdit *textEdit;
    QTextEdit *textEdit_2;

    void setupUi(QDialog *changePassWordDialog)
    {
        if (changePassWordDialog->objectName().isEmpty())
            changePassWordDialog->setObjectName(QString::fromUtf8("changePassWordDialog"));
        changePassWordDialog->setWindowModality(Qt::ApplicationModal);
        changePassWordDialog->resize(580, 284);
        QIcon icon;
        icon.addFile(QString::fromUtf8("lxqt_wallet_icon.png"), QSize(), QIcon::Normal, QIcon::Off);
        changePassWordDialog->setWindowIcon(icon);
        groupBox = new QGroupBox(changePassWordDialog);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setGeometry(QRect(10, 10, 561, 271));
        pushButtonChange = new QPushButton(groupBox);
        pushButtonChange->setObjectName(QString::fromUtf8("pushButtonChange"));
        pushButtonChange->setGeometry(QRect(190, 240, 91, 31));
        pushButtonOK = new QPushButton(groupBox);
        pushButtonOK->setObjectName(QString::fromUtf8("pushButtonOK"));
        pushButtonOK->setGeometry(QRect(230, 240, 101, 31));
        lineEditCurrentPassWord = new QLineEdit(groupBox);
        lineEditCurrentPassWord->setObjectName(QString::fromUtf8("lineEditCurrentPassWord"));
        lineEditCurrentPassWord->setGeometry(QRect(90, 90, 381, 31));
        lineEditCurrentPassWord->setEchoMode(QLineEdit::Password);
        lineEditNewPassWord = new QLineEdit(groupBox);
        lineEditNewPassWord->setObjectName(QString::fromUtf8("lineEditNewPassWord"));
        lineEditNewPassWord->setGeometry(QRect(90, 150, 381, 31));
        lineEditNewPassWord->setEchoMode(QLineEdit::Password);
        lineEditNewPassWord_2 = new QLineEdit(groupBox);
        lineEditNewPassWord_2->setObjectName(QString::fromUtf8("lineEditNewPassWord_2"));
        lineEditNewPassWord_2->setGeometry(QRect(90, 210, 381, 31));
        lineEditNewPassWord_2->setEchoMode(QLineEdit::Password);
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(20, 20, 521, 31));
        label->setText(QString::fromUtf8("\"XXX\" want to change \"YYY\" password"));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        label_2 = new QLabel(groupBox);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 60, 561, 31));
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);
        label_3 = new QLabel(groupBox);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(0, 120, 561, 31));
        label_3->setAlignment(Qt::AlignCenter);
        label_3->setWordWrap(true);
        label_4 = new QLabel(groupBox);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(0, 180, 561, 31));
        label_4->setAlignment(Qt::AlignCenter);
        label_4->setWordWrap(true);
        pushButtonCancel = new QPushButton(groupBox);
        pushButtonCancel->setObjectName(QString::fromUtf8("pushButtonCancel"));
        pushButtonCancel->setGeometry(QRect(280, 240, 91, 31));
        textEdit = new QTextEdit(groupBox);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));
        textEdit->setGeometry(QRect(10, 170, 51, 31));
        textEdit_2 = new QTextEdit(groupBox);
        textEdit_2->setObjectName(QString::fromUtf8("textEdit_2"));
        textEdit_2->setGeometry(QRect(10, 200, 51, 31));
        QWidget::setTabOrder(lineEditCurrentPassWord, lineEditNewPassWord);
        QWidget::setTabOrder(lineEditNewPassWord, lineEditNewPassWord_2);
        QWidget::setTabOrder(lineEditNewPassWord_2, pushButtonChange);
        QWidget::setTabOrder(pushButtonChange, pushButtonOK);
        QWidget::setTabOrder(pushButtonOK, pushButtonCancel);
        QWidget::setTabOrder(pushButtonCancel, textEdit);
        QWidget::setTabOrder(textEdit, textEdit_2);

        retranslateUi(changePassWordDialog);

        QMetaObject::connectSlotsByName(changePassWordDialog);
    } // setupUi

    void retranslateUi(QDialog *changePassWordDialog)
    {
        changePassWordDialog->setWindowTitle(QCoreApplication::translate("changePassWordDialog", "Change Wallet's Password", nullptr));
        groupBox->setTitle(QString());
        pushButtonChange->setText(QCoreApplication::translate("changePassWordDialog", "C&hange", nullptr));
        pushButtonOK->setText(QCoreApplication::translate("changePassWordDialog", "&Ok", nullptr));
        label_2->setText(QCoreApplication::translate("changePassWordDialog", "Enter Current Password Below.", nullptr));
        label_3->setText(QCoreApplication::translate("changePassWordDialog", "Enter New Password Below.", nullptr));
        label_4->setText(QCoreApplication::translate("changePassWordDialog", "Re Enter New Password Below.", nullptr));
        pushButtonCancel->setText(QCoreApplication::translate("changePassWordDialog", "&Cancel", nullptr));
        textEdit->setHtml(QCoreApplication::translate("changePassWordDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Monospace'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-size:9pt;\">An application '</span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">%1</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\">' has made a request for a password of its wallet '</span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">%2</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\">' to be changed</span></p>\n"
"<p style=\"-qt-paragraph-type:empty; margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-bl"
                        "ock-indent:0; text-indent:0px; font-family:'Sans Serif'; font-size:9pt;\"><br /></p></body></html>", nullptr));
        textEdit_2->setHtml(QCoreApplication::translate("changePassWordDialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Monospace'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-size:9pt;\">Enter password information below to create a new wallet '</span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">%1</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\">' for application '</span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">%2</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\">'</span></p></body></html>", nullptr));
    } // retranslateUi

};

namespace Ui {
    class changePassWordDialog: public Ui_changePassWordDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CHANGEPASSWORDDIALOG_H
