/********************************************************************************
** Form generated from reading UI file 'showluksslots.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_SHOWLUKSSLOTS_H
#define UI_SHOWLUKSSLOTS_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>

QT_BEGIN_NAMESPACE

class Ui_showLUKSSlots
{
public:
    QLineEdit *lineEdit;
    QPushButton *pbFile;
    QPushButton *pbDevice;
    QLabel *label;
    QTableWidget *tableWidget;
    QPushButton *pbClose;
    QLabel *label_2;
    QLabel *labelError;
    QPushButton *pbOK;
    QCheckBox *checkBox;

    void setupUi(QDialog *showLUKSSlots)
    {
        if (showLUKSSlots->objectName().isEmpty())
            showLUKSSlots->setObjectName(QString::fromUtf8("showLUKSSlots"));
        showLUKSSlots->setWindowModality(Qt::ApplicationModal);
        showLUKSSlots->resize(824, 546);
        lineEdit = new QLineEdit(showLUKSSlots);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(170, 480, 481, 31));
        pbFile = new QPushButton(showLUKSSlots);
        pbFile->setObjectName(QString::fromUtf8("pbFile"));
        pbFile->setGeometry(QRect(650, 480, 41, 33));
        pbDevice = new QPushButton(showLUKSSlots);
        pbDevice->setObjectName(QString::fromUtf8("pbDevice"));
        pbDevice->setGeometry(QRect(690, 480, 41, 33));
        label = new QLabel(showLUKSSlots);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(70, 350, 461, 41));
        label->setAlignment(Qt::AlignCenter);
        tableWidget = new QTableWidget(showLUKSSlots);
        if (tableWidget->columnCount() < 1)
            tableWidget->setColumnCount(1);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setGeometry(QRect(70, 20, 681, 401));
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        pbClose = new QPushButton(showLUKSSlots);
        pbClose->setObjectName(QString::fromUtf8("pbClose"));
        pbClose->setGeometry(QRect(330, 510, 161, 33));
        label_2 = new QLabel(showLUKSSlots);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(170, 450, 481, 31));
        label_2->setAlignment(Qt::AlignCenter);
        labelError = new QLabel(showLUKSSlots);
        labelError->setObjectName(QString::fromUtf8("labelError"));
        labelError->setGeometry(QRect(100, 120, 621, 271));
        labelError->setAutoFillBackground(true);
        labelError->setAlignment(Qt::AlignCenter);
        labelError->setWordWrap(true);
        pbOK = new QPushButton(showLUKSSlots);
        pbOK->setObjectName(QString::fromUtf8("pbOK"));
        pbOK->setGeometry(QRect(360, 340, 101, 33));
        checkBox = new QCheckBox(showLUKSSlots);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setGeometry(QRect(170, 420, 481, 31));

        retranslateUi(showLUKSSlots);

        QMetaObject::connectSlotsByName(showLUKSSlots);
    } // setupUi

    void retranslateUi(QDialog *showLUKSSlots)
    {
        showLUKSSlots->setWindowTitle(QCoreApplication::translate("showLUKSSlots", "LUKS' Slot Properties", nullptr));
        pbFile->setText(QString());
        pbDevice->setText(QString());
        label->setText(QCoreApplication::translate("showLUKSSlots", "Enter Path To A LUKS Volume Below", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("showLUKSSlots", "Key Slots Status", nullptr));
        pbClose->setText(QCoreApplication::translate("showLUKSSlots", "Close", nullptr));
        label_2->setText(QCoreApplication::translate("showLUKSSlots", "Set Volume Path Below", nullptr));
        labelError->setText(QCoreApplication::translate("showLUKSSlots", "TextLabel", nullptr));
        pbOK->setText(QCoreApplication::translate("showLUKSSlots", "OK", nullptr));
        checkBox->setText(QCoreApplication::translate("showLUKSSlots", "Show Only Occupied Slots", nullptr));
    } // retranslateUi

};

namespace Ui {
    class showLUKSSlots: public Ui_showLUKSSlots {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_SHOWLUKSSLOTS_H
