/****************************************************************************
** Meta object code from reading C++ file 'luksaddkey.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../zuluCrypt-gui/luksaddkey.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'luksaddkey.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_luksaddkey_t {
    QByteArrayData data[26];
    char stringdata0[320];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_luksaddkey_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_luksaddkey_t qt_meta_stringdata_luksaddkey = {
    {
QT_MOC_LITERAL(0, 0, 10), // "luksaddkey"
QT_MOC_LITERAL(1, 11, 12), // "clickedpbAdd"
QT_MOC_LITERAL(2, 24, 0), // ""
QT_MOC_LITERAL(3, 25, 12), // "PathToVolume"
QT_MOC_LITERAL(4, 38, 7), // "keyfile"
QT_MOC_LITERAL(5, 46, 11), // "ExistingKey"
QT_MOC_LITERAL(6, 58, 10), // "newkeyfile"
QT_MOC_LITERAL(7, 69, 6), // "NewKey"
QT_MOC_LITERAL(8, 76, 22), // "pbOpenPartitionClicked"
QT_MOC_LITERAL(9, 99, 6), // "ShowUI"
QT_MOC_LITERAL(10, 106, 21), // "std::function<void()>"
QT_MOC_LITERAL(11, 128, 6), // "HideUI"
QT_MOC_LITERAL(12, 135, 12), // "cbVolumeType"
QT_MOC_LITERAL(13, 148, 13), // "cbExistingKey"
QT_MOC_LITERAL(14, 162, 8), // "cbNewKey"
QT_MOC_LITERAL(15, 171, 12), // "keyChanged_0"
QT_MOC_LITERAL(16, 184, 12), // "keyChanged_1"
QT_MOC_LITERAL(17, 197, 22), // "pbOpenExisitingKeyFile"
QT_MOC_LITERAL(18, 220, 16), // "pbOpenNewKeyFile"
QT_MOC_LITERAL(19, 237, 10), // "pbOpenFile"
QT_MOC_LITERAL(20, 248, 15), // "pbOpenPartition"
QT_MOC_LITERAL(21, 264, 5), // "pbAdd"
QT_MOC_LITERAL(22, 270, 8), // "pbCancel"
QT_MOC_LITERAL(23, 279, 12), // "taskFinished"
QT_MOC_LITERAL(24, 292, 13), // "utility::Task"
QT_MOC_LITERAL(25, 306, 13) // "setFieldFocus"

    },
    "luksaddkey\0clickedpbAdd\0\0PathToVolume\0"
    "keyfile\0ExistingKey\0newkeyfile\0NewKey\0"
    "pbOpenPartitionClicked\0ShowUI\0"
    "std::function<void()>\0HideUI\0cbVolumeType\0"
    "cbExistingKey\0cbNewKey\0keyChanged_0\0"
    "keyChanged_1\0pbOpenExisitingKeyFile\0"
    "pbOpenNewKeyFile\0pbOpenFile\0pbOpenPartition\0"
    "pbAdd\0pbCancel\0taskFinished\0utility::Task\0"
    "setFieldFocus"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_luksaddkey[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      19,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       2,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    5,  109,    2, 0x06 /* Public */,
       8,    0,  120,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       9,    1,  121,    2, 0x0a /* Public */,
       9,    3,  124,    2, 0x0a /* Public */,
       9,    0,  131,    2, 0x0a /* Public */,
      11,    0,  132,    2, 0x0a /* Public */,
      12,    1,  133,    2, 0x08 /* Private */,
      13,    1,  136,    2, 0x08 /* Private */,
      14,    1,  139,    2, 0x08 /* Private */,
      15,    1,  142,    2, 0x08 /* Private */,
      16,    1,  145,    2, 0x08 /* Private */,
      17,    0,  148,    2, 0x08 /* Private */,
      18,    0,  149,    2, 0x08 /* Private */,
      19,    0,  150,    2, 0x08 /* Private */,
      20,    0,  151,    2, 0x08 /* Private */,
      21,    0,  152,    2, 0x08 /* Private */,
      22,    0,  153,    2, 0x08 /* Private */,
      23,    1,  154,    2, 0x08 /* Private */,
      25,    0,  157,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::QString, QMetaType::Bool, QMetaType::QString,    3,    4,    5,    6,    7,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString, QMetaType::QString, 0x80000000 | 10,    2,    2,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, 0x80000000 | 24,    2,
    QMetaType::Void,

       0        // eod
};

void luksaddkey::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<luksaddkey *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->clickedpbAdd((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3])),(*reinterpret_cast< bool(*)>(_a[4])),(*reinterpret_cast< QString(*)>(_a[5]))); break;
        case 1: _t->pbOpenPartitionClicked(); break;
        case 2: _t->ShowUI((*reinterpret_cast< const QString(*)>(_a[1]))); break;
        case 3: _t->ShowUI((*reinterpret_cast< const QString(*)>(_a[1])),(*reinterpret_cast< const QString(*)>(_a[2])),(*reinterpret_cast< std::function<void()>(*)>(_a[3]))); break;
        case 4: _t->ShowUI(); break;
        case 5: _t->HideUI(); break;
        case 6: _t->cbVolumeType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 7: _t->cbExistingKey((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 8: _t->cbNewKey((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 9: _t->keyChanged_0((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 10: _t->keyChanged_1((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 11: _t->pbOpenExisitingKeyFile(); break;
        case 12: _t->pbOpenNewKeyFile(); break;
        case 13: _t->pbOpenFile(); break;
        case 14: _t->pbOpenPartition(); break;
        case 15: _t->pbAdd(); break;
        case 16: _t->pbCancel(); break;
        case 17: _t->taskFinished((*reinterpret_cast< const utility::Task(*)>(_a[1]))); break;
        case 18: _t->setFieldFocus(); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (luksaddkey::*)(QString , bool , QString , bool , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&luksaddkey::clickedpbAdd)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (luksaddkey::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&luksaddkey::pbOpenPartitionClicked)) {
                *result = 1;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject luksaddkey::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_luksaddkey.data,
    qt_meta_data_luksaddkey,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *luksaddkey::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *luksaddkey::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_luksaddkey.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int luksaddkey::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 19)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 19;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 19)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 19;
    }
    return _id;
}

// SIGNAL 0
void luksaddkey::clickedpbAdd(QString _t1, bool _t2, QString _t3, bool _t4, QString _t5)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t4))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t5))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void luksaddkey::pbOpenPartitionClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
