/********************************************************************************
** Form generated from reading UI file 'plugin.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PLUGIN_H
#define UI_PLUGIN_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_plugin
{
public:
    QPushButton *pbSetKey;
    QPushButton *pbCancel;
    QLineEdit *lineEdit;
    QPushButton *pbKeyFile;
    QGroupBox *groupBox;
    QLabel *label;
    QLabel *label_2;
    QLineEdit *lineEdit_2;
    QLabel *label_3;

    void setupUi(QDialog *plugin)
    {
        if (plugin->objectName().isEmpty())
            plugin->setObjectName(QString::fromUtf8("plugin"));
        plugin->setWindowModality(Qt::ApplicationModal);
        plugin->resize(541, 233);
        pbSetKey = new QPushButton(plugin);
        pbSetKey->setObjectName(QString::fromUtf8("pbSetKey"));
        pbSetKey->setGeometry(QRect(140, 200, 131, 31));
        pbCancel = new QPushButton(plugin);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(270, 200, 131, 31));
        lineEdit = new QLineEdit(plugin);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(110, 140, 321, 31));
        lineEdit->setEchoMode(QLineEdit::Password);
        pbKeyFile = new QPushButton(plugin);
        pbKeyFile->setObjectName(QString::fromUtf8("pbKeyFile"));
        pbKeyFile->setGeometry(QRect(430, 170, 31, 31));
        groupBox = new QGroupBox(plugin);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setGeometry(QRect(10, 0, 521, 141));
        label = new QLabel(groupBox);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 20, 501, 101));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        label_2 = new QLabel(plugin);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(11, 140, 91, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        lineEdit_2 = new QLineEdit(plugin);
        lineEdit_2->setObjectName(QString::fromUtf8("lineEdit_2"));
        lineEdit_2->setGeometry(QRect(110, 170, 321, 31));
        label_3 = new QLabel(plugin);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(11, 170, 91, 31));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);

        retranslateUi(plugin);

        QMetaObject::connectSlotsByName(plugin);
    } // setupUi

    void retranslateUi(QDialog *plugin)
    {
        plugin->setWindowTitle(QCoreApplication::translate("plugin", "Key Generator Using A Passphrase And A KeyFile", nullptr));
        pbSetKey->setText(QCoreApplication::translate("plugin", "&Set Key", nullptr));
        pbCancel->setText(QCoreApplication::translate("plugin", "&Cancel", nullptr));
        pbKeyFile->setText(QString());
        groupBox->setTitle(QString());
        label->setText(QCoreApplication::translate("plugin", "Create an encryption key that is made up of a passphrase and a keyfile.\n"
"\n"
"A volume created with a key generated here should be opened with \"hmac\" plugin.", nullptr));
        label_2->setText(QCoreApplication::translate("plugin", "Passphrase", nullptr));
        label_3->setText(QCoreApplication::translate("plugin", "KeyFile", nullptr));
    } // retranslateUi

};

namespace Ui {
    class plugin: public Ui_plugin {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PLUGIN_H
