/********************************************************************************
** Form generated from reading UI file 'readonlywarning.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_READONLYWARNING_H
#define UI_READONLYWARNING_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_readOnlyWarning
{
public:
    QCheckBox *checkBox;
    QLabel *label;
    QPushButton *PbOK;

    void setupUi(QDialog *readOnlyWarning)
    {
        if (readOnlyWarning->objectName().isEmpty())
            readOnlyWarning->setObjectName(QString::fromUtf8("readOnlyWarning"));
        readOnlyWarning->resize(431, 172);
        checkBox = new QCheckBox(readOnlyWarning);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setGeometry(QRect(80, 80, 341, 51));
        label = new QLabel(readOnlyWarning);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 10, 411, 71));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        PbOK = new QPushButton(readOnlyWarning);
        PbOK->setObjectName(QString::fromUtf8("PbOK"));
        PbOK->setGeometry(QRect(150, 140, 131, 31));

        retranslateUi(readOnlyWarning);

        QMetaObject::connectSlotsByName(readOnlyWarning);
    } // setupUi

    void retranslateUi(QDialog *readOnlyWarning)
    {
        readOnlyWarning->setWindowTitle(QCoreApplication::translate("readOnlyWarning", "WARNING", nullptr));
        checkBox->setText(QCoreApplication::translate("readOnlyWarning", "Do Not Show This Message Again.", nullptr));
        label->setText(QCoreApplication::translate("readOnlyWarning", "Setting this option will cause the volume to open in read only mode.", nullptr));
        PbOK->setText(QCoreApplication::translate("readOnlyWarning", "&Ok", nullptr));
    } // retranslateUi

};

namespace Ui {
    class readOnlyWarning: public Ui_readOnlyWarning {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_READONLYWARNING_H
