/********************************************************************************
** Form generated from reading UI file 'createvolumedialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEVOLUMEDIALOG_H
#define UI_CREATEVOLUMEDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_createVolumeDialog
{
public:
    QPushButton *pbYes;
    QPushButton *pbNo;
    QLabel *label_1;

    void setupUi(QDialog *createVolumeDialog)
    {
        if (createVolumeDialog->objectName().isEmpty())
            createVolumeDialog->setObjectName(QString::fromUtf8("createVolumeDialog"));
        createVolumeDialog->setWindowModality(Qt::ApplicationModal);
        createVolumeDialog->resize(500, 243);
        pbYes = new QPushButton(createVolumeDialog);
        pbYes->setObjectName(QString::fromUtf8("pbYes"));
        pbYes->setGeometry(QRect(160, 210, 91, 31));
        pbNo = new QPushButton(createVolumeDialog);
        pbNo->setObjectName(QString::fromUtf8("pbNo"));
        pbNo->setGeometry(QRect(250, 210, 91, 31));
        label_1 = new QLabel(createVolumeDialog);
        label_1->setObjectName(QString::fromUtf8("label_1"));
        label_1->setGeometry(QRect(10, 10, 481, 201));
        label_1->setAlignment(Qt::AlignCenter);
        label_1->setWordWrap(true);

        retranslateUi(createVolumeDialog);

        QMetaObject::connectSlotsByName(createVolumeDialog);
    } // setupUi

    void retranslateUi(QDialog *createVolumeDialog)
    {
        createVolumeDialog->setWindowTitle(QCoreApplication::translate("createVolumeDialog", "Warning!!", nullptr));
        pbYes->setText(QCoreApplication::translate("createVolumeDialog", "&Yes", nullptr));
        pbNo->setText(QCoreApplication::translate("createVolumeDialog", "&No", nullptr));
        label_1->setText(QCoreApplication::translate("createVolumeDialog", "This operation will lead to permanent destrunction of all present data in /dev/sdc1. Are you sure you want to continue?", nullptr));
    } // retranslateUi

};

namespace Ui {
    class createVolumeDialog: public Ui_createVolumeDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEVOLUMEDIALOG_H
