/****************************************************************************
** Meta object code from reading C++ file 'managevolumeheader.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../zuluCrypt-gui/managevolumeheader.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'managevolumeheader.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_managevolumeheader_t {
    QByteArrayData data[18];
    char stringdata0[226];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_managevolumeheader_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_managevolumeheader_t qt_meta_stringdata_managevolumeheader = {
    {
QT_MOC_LITERAL(0, 0, 18), // "managevolumeheader"
QT_MOC_LITERAL(1, 19, 12), // "HideUISignal"
QT_MOC_LITERAL(2, 32, 0), // ""
QT_MOC_LITERAL(3, 33, 6), // "ShowUI"
QT_MOC_LITERAL(4, 40, 6), // "HideUI"
QT_MOC_LITERAL(5, 47, 12), // "backUpHeader"
QT_MOC_LITERAL(6, 60, 13), // "restoreHeader"
QT_MOC_LITERAL(7, 74, 8), // "pbCancel"
QT_MOC_LITERAL(8, 83, 8), // "pbCreate"
QT_MOC_LITERAL(9, 92, 22), // "pbOpenLuksHeaderBackUp"
QT_MOC_LITERAL(10, 115, 12), // "taskFinished"
QT_MOC_LITERAL(11, 128, 15), // "pbOpenPartition"
QT_MOC_LITERAL(12, 144, 10), // "pbOpenFile"
QT_MOC_LITERAL(13, 155, 9), // "pbKeyFile"
QT_MOC_LITERAL(14, 165, 22), // "backUpHeaderNameChange"
QT_MOC_LITERAL(15, 188, 9), // "cbKeyType"
QT_MOC_LITERAL(16, 198, 12), // "cbVolumeType"
QT_MOC_LITERAL(17, 211, 14) // "cbVolumeHeader"

    },
    "managevolumeheader\0HideUISignal\0\0"
    "ShowUI\0HideUI\0backUpHeader\0restoreHeader\0"
    "pbCancel\0pbCreate\0pbOpenLuksHeaderBackUp\0"
    "taskFinished\0pbOpenPartition\0pbOpenFile\0"
    "pbKeyFile\0backUpHeaderNameChange\0"
    "cbKeyType\0cbVolumeType\0cbVolumeHeader"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_managevolumeheader[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      17,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       1,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    0,   99,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       3,    0,  100,    2, 0x0a /* Public */,
       4,    0,  101,    2, 0x0a /* Public */,
       5,    0,  102,    2, 0x0a /* Public */,
       5,    1,  103,    2, 0x0a /* Public */,
       6,    0,  106,    2, 0x0a /* Public */,
       7,    0,  107,    2, 0x08 /* Private */,
       8,    0,  108,    2, 0x08 /* Private */,
       9,    0,  109,    2, 0x08 /* Private */,
      10,    1,  110,    2, 0x08 /* Private */,
      11,    0,  113,    2, 0x08 /* Private */,
      12,    0,  114,    2, 0x08 /* Private */,
      13,    0,  115,    2, 0x08 /* Private */,
      14,    1,  116,    2, 0x08 /* Private */,
      15,    1,  119,    2, 0x08 /* Private */,
      16,    1,  122,    2, 0x08 /* Private */,
      17,    1,  125,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QString,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void, QMetaType::Int,    2,

       0        // eod
};

void managevolumeheader::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<managevolumeheader *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->HideUISignal(); break;
        case 1: _t->ShowUI(); break;
        case 2: _t->HideUI(); break;
        case 3: _t->backUpHeader(); break;
        case 4: _t->backUpHeader((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 5: _t->restoreHeader(); break;
        case 6: _t->pbCancel(); break;
        case 7: _t->pbCreate(); break;
        case 8: _t->pbOpenLuksHeaderBackUp(); break;
        case 9: _t->taskFinished((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 10: _t->pbOpenPartition(); break;
        case 11: _t->pbOpenFile(); break;
        case 12: _t->pbKeyFile(); break;
        case 13: _t->backUpHeaderNameChange((*reinterpret_cast< QString(*)>(_a[1]))); break;
        case 14: _t->cbKeyType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 15: _t->cbVolumeType((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 16: _t->cbVolumeHeader((*reinterpret_cast< int(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (managevolumeheader::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&managevolumeheader::HideUISignal)) {
                *result = 0;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject managevolumeheader::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_managevolumeheader.data,
    qt_meta_data_managevolumeheader,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *managevolumeheader::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *managevolumeheader::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_managevolumeheader.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int managevolumeheader::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 17)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 17;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 17)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 17;
    }
    return _id;
}

// SIGNAL 0
void managevolumeheader::HideUISignal()
{
    QMetaObject::activate(this, &staticMetaObject, 0, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
