/********************************************************************************
** Form generated from reading UI file 'managevolumeheader.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGEVOLUMEHEADER_H
#define UI_MANAGEVOLUMEHEADER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_managevolumeheader
{
public:
    QLineEdit *lineEditBackUpName;
    QLabel *labelBackUpHeader;
    QPushButton *pbOpenFolder;
    QPushButton *pbCreate;
    QPushButton *pbCancel;
    QLabel *labelDevicePath;
    QLineEdit *lineEditDevicePath;
    QPushButton *pushButtonFile;
    QPushButton *pushButtonPartition;
    QComboBox *cbVolumeType;
    QLabel *labelVolumeType;
    QLineEdit *lineEditPIM;
    QComboBox *cbVolumeHeader;
    QLabel *labelPIM;
    QLineEdit *lineEditPassWord;
    QPushButton *pBKeyFile;
    QComboBox *cbKeySource;
    QLabel *labelKeySource;
    QLabel *labelKeyType;
    QLabel *labelVeraCryptWarning;

    void setupUi(QDialog *managevolumeheader)
    {
        if (managevolumeheader->objectName().isEmpty())
            managevolumeheader->setObjectName(QString::fromUtf8("managevolumeheader"));
        managevolumeheader->setWindowModality(Qt::ApplicationModal);
        managevolumeheader->resize(561, 306);
        lineEditBackUpName = new QLineEdit(managevolumeheader);
        lineEditBackUpName->setObjectName(QString::fromUtf8("lineEditBackUpName"));
        lineEditBackUpName->setGeometry(QRect(120, 40, 321, 31));
        labelBackUpHeader = new QLabel(managevolumeheader);
        labelBackUpHeader->setObjectName(QString::fromUtf8("labelBackUpHeader"));
        labelBackUpHeader->setGeometry(QRect(10, 40, 101, 31));
        labelBackUpHeader->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelBackUpHeader->setWordWrap(true);
        pbOpenFolder = new QPushButton(managevolumeheader);
        pbOpenFolder->setObjectName(QString::fromUtf8("pbOpenFolder"));
        pbOpenFolder->setGeometry(QRect(440, 40, 31, 31));
        pbCreate = new QPushButton(managevolumeheader);
        pbCreate->setObjectName(QString::fromUtf8("pbCreate"));
        pbCreate->setGeometry(QRect(170, 270, 111, 31));
        pbCreate->setAutoDefault(true);
        pbCancel = new QPushButton(managevolumeheader);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(280, 270, 111, 31));
        pbCancel->setAutoDefault(true);
        labelDevicePath = new QLabel(managevolumeheader);
        labelDevicePath->setObjectName(QString::fromUtf8("labelDevicePath"));
        labelDevicePath->setGeometry(QRect(10, 10, 101, 31));
        labelDevicePath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelDevicePath->setWordWrap(true);
        lineEditDevicePath = new QLineEdit(managevolumeheader);
        lineEditDevicePath->setObjectName(QString::fromUtf8("lineEditDevicePath"));
        lineEditDevicePath->setGeometry(QRect(120, 10, 321, 31));
        pushButtonFile = new QPushButton(managevolumeheader);
        pushButtonFile->setObjectName(QString::fromUtf8("pushButtonFile"));
        pushButtonFile->setGeometry(QRect(440, 10, 31, 31));
        pushButtonPartition = new QPushButton(managevolumeheader);
        pushButtonPartition->setObjectName(QString::fromUtf8("pushButtonPartition"));
        pushButtonPartition->setGeometry(QRect(470, 10, 31, 31));
        cbVolumeType = new QComboBox(managevolumeheader);
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->setObjectName(QString::fromUtf8("cbVolumeType"));
        cbVolumeType->setGeometry(QRect(120, 150, 321, 31));
        labelVolumeType = new QLabel(managevolumeheader);
        labelVolumeType->setObjectName(QString::fromUtf8("labelVolumeType"));
        labelVolumeType->setGeometry(QRect(10, 150, 101, 31));
        labelVolumeType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumeType->setWordWrap(true);
        lineEditPIM = new QLineEdit(managevolumeheader);
        lineEditPIM->setObjectName(QString::fromUtf8("lineEditPIM"));
        lineEditPIM->setGeometry(QRect(120, 110, 321, 29));
        lineEditPIM->setEchoMode(QLineEdit::Password);
        cbVolumeHeader = new QComboBox(managevolumeheader);
        cbVolumeHeader->addItem(QString());
        cbVolumeHeader->addItem(QString());
        cbVolumeHeader->addItem(QString());
        cbVolumeHeader->setObjectName(QString::fromUtf8("cbVolumeHeader"));
        cbVolumeHeader->setGeometry(QRect(120, 80, 321, 31));
        labelPIM = new QLabel(managevolumeheader);
        labelPIM->setObjectName(QString::fromUtf8("labelPIM"));
        labelPIM->setGeometry(QRect(40, 110, 71, 31));
        labelPIM->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        lineEditPassWord = new QLineEdit(managevolumeheader);
        lineEditPassWord->setObjectName(QString::fromUtf8("lineEditPassWord"));
        lineEditPassWord->setGeometry(QRect(120, 230, 321, 31));
        lineEditPassWord->setEchoMode(QLineEdit::Password);
        pBKeyFile = new QPushButton(managevolumeheader);
        pBKeyFile->setObjectName(QString::fromUtf8("pBKeyFile"));
        pBKeyFile->setGeometry(QRect(440, 230, 31, 31));
        cbKeySource = new QComboBox(managevolumeheader);
        cbKeySource->addItem(QString());
        cbKeySource->addItem(QString());
        cbKeySource->setObjectName(QString::fromUtf8("cbKeySource"));
        cbKeySource->setGeometry(QRect(120, 190, 321, 31));
        labelKeySource = new QLabel(managevolumeheader);
        labelKeySource->setObjectName(QString::fromUtf8("labelKeySource"));
        labelKeySource->setGeometry(QRect(10, 190, 101, 31));
        labelKeySource->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelKeySource->setWordWrap(true);
        labelKeyType = new QLabel(managevolumeheader);
        labelKeyType->setObjectName(QString::fromUtf8("labelKeyType"));
        labelKeyType->setGeometry(QRect(10, 220, 101, 51));
        labelKeyType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelKeyType->setWordWrap(true);
        labelVeraCryptWarning = new QLabel(managevolumeheader);
        labelVeraCryptWarning->setObjectName(QString::fromUtf8("labelVeraCryptWarning"));
        labelVeraCryptWarning->setGeometry(QRect(10, 0, 541, 301));
        labelVeraCryptWarning->setAutoFillBackground(true);
        labelVeraCryptWarning->setAlignment(Qt::AlignCenter);
        labelVeraCryptWarning->setWordWrap(true);
        QWidget::setTabOrder(lineEditDevicePath, pushButtonFile);
        QWidget::setTabOrder(pushButtonFile, pushButtonPartition);
        QWidget::setTabOrder(pushButtonPartition, lineEditBackUpName);
        QWidget::setTabOrder(lineEditBackUpName, pbOpenFolder);
        QWidget::setTabOrder(pbOpenFolder, cbVolumeHeader);
        QWidget::setTabOrder(cbVolumeHeader, lineEditPIM);
        QWidget::setTabOrder(lineEditPIM, cbVolumeType);
        QWidget::setTabOrder(cbVolumeType, cbKeySource);
        QWidget::setTabOrder(cbKeySource, lineEditPassWord);
        QWidget::setTabOrder(lineEditPassWord, pBKeyFile);
        QWidget::setTabOrder(pBKeyFile, pbCreate);
        QWidget::setTabOrder(pbCreate, pbCancel);

        retranslateUi(managevolumeheader);

        pbCreate->setDefault(true);
        pbCancel->setDefault(false);


        QMetaObject::connectSlotsByName(managevolumeheader);
    } // setupUi

    void retranslateUi(QDialog *managevolumeheader)
    {
        managevolumeheader->setWindowTitle(QCoreApplication::translate("managevolumeheader", "Backup Volume Header", nullptr));
        labelBackUpHeader->setText(QCoreApplication::translate("managevolumeheader", "Backup Name", nullptr));
#if QT_CONFIG(tooltip)
        pbOpenFolder->setToolTip(QString());
#endif // QT_CONFIG(tooltip)
        pbOpenFolder->setText(QString());
        pbCreate->setText(QCoreApplication::translate("managevolumeheader", "C&reate", nullptr));
        pbCancel->setText(QCoreApplication::translate("managevolumeheader", "&Cancel", nullptr));
        labelDevicePath->setText(QCoreApplication::translate("managevolumeheader", "Volume Path", nullptr));
        pushButtonFile->setText(QString());
        pushButtonPartition->setText(QString());
        cbVolumeType->setItemText(0, QCoreApplication::translate("managevolumeheader", "Normal Volume", nullptr));
        cbVolumeType->setItemText(1, QCoreApplication::translate("managevolumeheader", "Window System Volume", nullptr));
        cbVolumeType->setItemText(2, QCoreApplication::translate("managevolumeheader", "Whole Drive Encrypted Volume", nullptr));

        labelVolumeType->setText(QCoreApplication::translate("managevolumeheader", "Volume Type", nullptr));
        cbVolumeHeader->setItemText(0, QCoreApplication::translate("managevolumeheader", "Manage A LUKS Header", nullptr));
        cbVolumeHeader->setItemText(1, QCoreApplication::translate("managevolumeheader", "Manage A TrueCrypt Header", nullptr));
        cbVolumeHeader->setItemText(2, QCoreApplication::translate("managevolumeheader", "Manage A VeraCrypt Header", nullptr));

        labelPIM->setText(QCoreApplication::translate("managevolumeheader", "PIM", nullptr));
        pBKeyFile->setText(QString());
        cbKeySource->setItemText(0, QCoreApplication::translate("managevolumeheader", "Password", nullptr));
        cbKeySource->setItemText(1, QCoreApplication::translate("managevolumeheader", "KeyFile", nullptr));

        labelKeySource->setText(QCoreApplication::translate("managevolumeheader", "Password Source", nullptr));
        labelKeyType->setText(QCoreApplication::translate("managevolumeheader", "Outer Volume Password ONLY", nullptr));
        labelVeraCryptWarning->setText(QCoreApplication::translate("managevolumeheader", "TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class managevolumeheader: public Ui_managevolumeheader {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MANAGEVOLUMEHEADER_H
