/********************************************************************************
** Form generated from reading UI file 'tcrypt.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_TCRYPT_H
#define UI_TCRYPT_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>

QT_BEGIN_NAMESPACE

class Ui_tcrypt
{
public:
    QPushButton *pbSend;
    QPushButton *pbCancel;
    QLineEdit *lineEdit;
    QPushButton *pbAddKeyFile;
    QTableWidget *tableWidget;
    QLabel *label;
    QLabel *label_2;

    void setupUi(QDialog *tcrypt)
    {
        if (tcrypt->objectName().isEmpty())
            tcrypt->setObjectName(QString::fromUtf8("tcrypt"));
        tcrypt->resize(623, 382);
        tcrypt->setAcceptDrops(true);
        pbSend = new QPushButton(tcrypt);
        pbSend->setObjectName(QString::fromUtf8("pbSend"));
        pbSend->setGeometry(QRect(110, 350, 101, 31));
        pbCancel = new QPushButton(tcrypt);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(410, 350, 101, 31));
        lineEdit = new QLineEdit(tcrypt);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(90, 320, 441, 31));
        lineEdit->setEchoMode(QLineEdit::Password);
        pbAddKeyFile = new QPushButton(tcrypt);
        pbAddKeyFile->setObjectName(QString::fromUtf8("pbAddKeyFile"));
        pbAddKeyFile->setGeometry(QRect(210, 350, 201, 31));
        tableWidget = new QTableWidget(tcrypt);
        if (tableWidget->columnCount() < 1)
            tableWidget->setColumnCount(1);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setGeometry(QRect(90, 50, 441, 231));
        tableWidget->setAcceptDrops(true);
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setTabKeyNavigation(false);
        tableWidget->setProperty("showDropIndicator", QVariant(false));
        tableWidget->setDragDropOverwriteMode(false);
        tableWidget->setDragDropMode(QAbstractItemView::NoDragDrop);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget->setGridStyle(Qt::NoPen);
        label = new QLabel(tcrypt);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 5, 601, 41));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        label_2 = new QLabel(tcrypt);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(10, 280, 601, 41));
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);

        retranslateUi(tcrypt);

        QMetaObject::connectSlotsByName(tcrypt);
    } // setupUi

    void retranslateUi(QDialog *tcrypt)
    {
        tcrypt->setWindowTitle(QCoreApplication::translate("tcrypt", "TrueCrypt Keys", nullptr));
        pbSend->setText(QCoreApplication::translate("tcrypt", "&Open", nullptr));
        pbCancel->setText(QCoreApplication::translate("tcrypt", "&Cancel", nullptr));
        pbAddKeyFile->setText(QCoreApplication::translate("tcrypt", "Add &Keyfile", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("tcrypt", "Keyfile Paths", nullptr));
#if QT_CONFIG(tooltip)
        ___qtablewidgetitem->setToolTip(QCoreApplication::translate("tcrypt", "drag and drop key files to add them to the list", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        tableWidget->setToolTip(QCoreApplication::translate("tcrypt", "drag and drop key files to add them to the list", nullptr));
#endif // QT_CONFIG(tooltip)
        label->setText(QCoreApplication::translate("tcrypt", "Enter key files below to be used to open the volume", nullptr));
        label_2->setText(QCoreApplication::translate("tcrypt", "Enter A Passphrase Below To Be Used To Open The Volume", nullptr));
    } // retranslateUi

};

namespace Ui {
    class tcrypt: public Ui_tcrypt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_TCRYPT_H
