/********************************************************************************
** Form generated from reading UI file 'luksdeletekey.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LUKSDELETEKEY_H
#define UI_LUKSDELETEKEY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_luksdeletekey
{
public:
    QLineEdit *lineEditPassphrase;
    QLabel *label_3;
    QLineEdit *lineEditSlotNumber;
    QLabel *labelPassphrase;
    QPushButton *pushButtonOpenKeyFile;
    QPushButton *pushButtonDelete;
    QPushButton *pushButtonCancel;
    QLineEdit *lineEditVolumePath;
    QLabel *label;
    QPushButton *pushButtonOpenVolume;
    QPushButton *pushButtonOpenPartition;
    QComboBox *cbKey;
    QLabel *label_2;
    QPushButton *pushButton;

    void setupUi(QDialog *luksdeletekey)
    {
        if (luksdeletekey->objectName().isEmpty())
            luksdeletekey->setObjectName(QString::fromUtf8("luksdeletekey"));
        luksdeletekey->setWindowModality(Qt::ApplicationModal);
        luksdeletekey->resize(542, 195);
        luksdeletekey->setAcceptDrops(true);
        luksdeletekey->setModal(true);
        lineEditPassphrase = new QLineEdit(luksdeletekey);
        lineEditPassphrase->setObjectName(QString::fromUtf8("lineEditPassphrase"));
        lineEditPassphrase->setGeometry(QRect(110, 70, 321, 31));
        label_3 = new QLabel(luksdeletekey);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(2, 89, 101, 51));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);
        lineEditSlotNumber = new QLineEdit(luksdeletekey);
        lineEditSlotNumber->setObjectName(QString::fromUtf8("lineEditSlotNumber"));
        lineEditSlotNumber->setGeometry(QRect(110, 100, 321, 31));
        labelPassphrase = new QLabel(luksdeletekey);
        labelPassphrase->setObjectName(QString::fromUtf8("labelPassphrase"));
        labelPassphrase->setGeometry(QRect(10, 70, 91, 31));
        labelPassphrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelPassphrase->setWordWrap(true);
        pushButtonOpenKeyFile = new QPushButton(luksdeletekey);
        pushButtonOpenKeyFile->setObjectName(QString::fromUtf8("pushButtonOpenKeyFile"));
        pushButtonOpenKeyFile->setGeometry(QRect(430, 70, 31, 31));
        pushButtonOpenKeyFile->setAutoDefault(true);
        pushButtonDelete = new QPushButton(luksdeletekey);
        pushButtonDelete->setObjectName(QString::fromUtf8("pushButtonDelete"));
        pushButtonDelete->setGeometry(QRect(180, 160, 91, 31));
        pushButtonDelete->setAutoDefault(true);
        pushButtonCancel = new QPushButton(luksdeletekey);
        pushButtonCancel->setObjectName(QString::fromUtf8("pushButtonCancel"));
        pushButtonCancel->setGeometry(QRect(270, 160, 91, 31));
        pushButtonCancel->setAutoDefault(true);
        lineEditVolumePath = new QLineEdit(luksdeletekey);
        lineEditVolumePath->setObjectName(QString::fromUtf8("lineEditVolumePath"));
        lineEditVolumePath->setGeometry(QRect(110, 40, 321, 31));
        label = new QLabel(luksdeletekey);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 40, 91, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        pushButtonOpenVolume = new QPushButton(luksdeletekey);
        pushButtonOpenVolume->setObjectName(QString::fromUtf8("pushButtonOpenVolume"));
        pushButtonOpenVolume->setGeometry(QRect(430, 40, 31, 31));
        pushButtonOpenVolume->setAutoDefault(true);
        pushButtonOpenPartition = new QPushButton(luksdeletekey);
        pushButtonOpenPartition->setObjectName(QString::fromUtf8("pushButtonOpenPartition"));
        pushButtonOpenPartition->setGeometry(QRect(460, 40, 31, 31));
        pushButtonOpenPartition->setAutoDefault(true);
        cbKey = new QComboBox(luksdeletekey);
        cbKey->addItem(QString());
        cbKey->addItem(QString());
        cbKey->addItem(QString());
        cbKey->setObjectName(QString::fromUtf8("cbKey"));
        cbKey->setGeometry(QRect(110, 130, 321, 31));
        label_2 = new QLabel(luksdeletekey);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, -10, 541, 201));
        label_2->setAutoFillBackground(true);
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);
        pushButton = new QPushButton(luksdeletekey);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(220, 160, 101, 33));
        QWidget::setTabOrder(lineEditVolumePath, pushButtonOpenVolume);
        QWidget::setTabOrder(pushButtonOpenVolume, pushButtonOpenPartition);
        QWidget::setTabOrder(pushButtonOpenPartition, lineEditPassphrase);
        QWidget::setTabOrder(lineEditPassphrase, pushButtonOpenKeyFile);
        QWidget::setTabOrder(pushButtonOpenKeyFile, cbKey);
        QWidget::setTabOrder(cbKey, pushButtonDelete);
        QWidget::setTabOrder(pushButtonDelete, pushButtonCancel);

        retranslateUi(luksdeletekey);

        pushButtonDelete->setDefault(true);
        pushButtonCancel->setDefault(false);


        QMetaObject::connectSlotsByName(luksdeletekey);
    } // setupUi

    void retranslateUi(QDialog *luksdeletekey)
    {
        luksdeletekey->setWindowTitle(QCoreApplication::translate("luksdeletekey", "Remove A Key From A Volume", nullptr));
        label_3->setText(QCoreApplication::translate("luksdeletekey", "LUKS Slot Number", nullptr));
        labelPassphrase->setText(QCoreApplication::translate("luksdeletekey", "Password", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOpenKeyFile->setToolTip(QCoreApplication::translate("luksdeletekey", "open a keyfile", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenKeyFile->setText(QString());
        pushButtonDelete->setText(QCoreApplication::translate("luksdeletekey", "&Delete", nullptr));
        pushButtonCancel->setText(QCoreApplication::translate("luksdeletekey", "&Cancel", nullptr));
        label->setText(QCoreApplication::translate("luksdeletekey", "Volume Path", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOpenVolume->setToolTip(QCoreApplication::translate("luksdeletekey", "open an encrypted file", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenVolume->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonOpenPartition->setToolTip(QCoreApplication::translate("luksdeletekey", "open an encrypted partition", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenPartition->setText(QString());
        cbKey->setItemText(0, QCoreApplication::translate("luksdeletekey", "Password", nullptr));
        cbKey->setItemText(1, QCoreApplication::translate("luksdeletekey", "KeyFile", nullptr));
        cbKey->setItemText(2, QCoreApplication::translate("luksdeletekey", "Key+KeyFIle", nullptr));

        label_2->setText(QCoreApplication::translate("luksdeletekey", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("luksdeletekey", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class luksdeletekey: public Ui_luksdeletekey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LUKSDELETEKEY_H
