/****************************************************************************
** Meta object code from reading C++ file 'tcrypt.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../../../zuluCrypt-gui/tcrypt.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'tcrypt.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_tcrypt_t {
    QByteArrayData data[16];
    char stringdata0[164];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_tcrypt_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_tcrypt_t qt_meta_stringdata_tcrypt = {
    {
QT_MOC_LITERAL(0, 0, 6), // "tcrypt"
QT_MOC_LITERAL(1, 7, 18), // "currentItemChanged"
QT_MOC_LITERAL(2, 26, 0), // ""
QT_MOC_LITERAL(3, 27, 17), // "QTableWidgetItem*"
QT_MOC_LITERAL(4, 45, 7), // "current"
QT_MOC_LITERAL(5, 53, 8), // "previous"
QT_MOC_LITERAL(6, 62, 11), // "itemClicked"
QT_MOC_LITERAL(7, 74, 4), // "item"
QT_MOC_LITERAL(8, 79, 14), // "dragEnterEvent"
QT_MOC_LITERAL(9, 94, 16), // "QDragEnterEvent*"
QT_MOC_LITERAL(10, 111, 1), // "e"
QT_MOC_LITERAL(11, 113, 9), // "dropEvent"
QT_MOC_LITERAL(12, 123, 11), // "QDropEvent*"
QT_MOC_LITERAL(13, 135, 6), // "pbSend"
QT_MOC_LITERAL(14, 142, 8), // "pbCancel"
QT_MOC_LITERAL(15, 151, 12) // "pbAddKeyFIle"

    },
    "tcrypt\0currentItemChanged\0\0QTableWidgetItem*\0"
    "current\0previous\0itemClicked\0item\0"
    "dragEnterEvent\0QDragEnterEvent*\0e\0"
    "dropEvent\0QDropEvent*\0pbSend\0pbCancel\0"
    "pbAddKeyFIle"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_tcrypt[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
       7,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       0,       // signalCount

 // slots: name, argc, parameters, tag, flags
       1,    2,   49,    2, 0x08 /* Private */,
       6,    1,   54,    2, 0x08 /* Private */,
       8,    1,   57,    2, 0x08 /* Private */,
      11,    1,   60,    2, 0x08 /* Private */,
      13,    0,   63,    2, 0x08 /* Private */,
      14,    0,   64,    2, 0x08 /* Private */,
      15,    0,   65,    2, 0x08 /* Private */,

 // slots: parameters
    QMetaType::Void, 0x80000000 | 3, 0x80000000 | 3,    4,    5,
    QMetaType::Void, 0x80000000 | 3,    7,
    QMetaType::Void, 0x80000000 | 9,   10,
    QMetaType::Void, 0x80000000 | 12,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,

       0        // eod
};

void tcrypt::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<tcrypt *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->currentItemChanged((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1])),(*reinterpret_cast< QTableWidgetItem*(*)>(_a[2]))); break;
        case 1: _t->itemClicked((*reinterpret_cast< QTableWidgetItem*(*)>(_a[1]))); break;
        case 2: _t->dragEnterEvent((*reinterpret_cast< QDragEnterEvent*(*)>(_a[1]))); break;
        case 3: _t->dropEvent((*reinterpret_cast< QDropEvent*(*)>(_a[1]))); break;
        case 4: _t->pbSend(); break;
        case 5: _t->pbCancel(); break;
        case 6: _t->pbAddKeyFIle(); break;
        default: ;
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject tcrypt::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_tcrypt.data,
    qt_meta_data_tcrypt,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *tcrypt::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *tcrypt::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_tcrypt.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int tcrypt::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 7)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 7;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 7)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 7;
    }
    return _id;
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
