/********************************************************************************
** Form generated from reading UI file 'veracryptpimdialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_VERACRYPTPIMDIALOG_H
#define UI_VERACRYPTPIMDIALOG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_VeraCryptPIMDialog
{
public:
    QPushButton *pbSet;
    QPushButton *pbCancel;
    QLabel *label;
    QLineEdit *lineEditPIM;

    void setupUi(QDialog *VeraCryptPIMDialog)
    {
        if (VeraCryptPIMDialog->objectName().isEmpty())
            VeraCryptPIMDialog->setObjectName(QString::fromUtf8("VeraCryptPIMDialog"));
        VeraCryptPIMDialog->resize(480, 182);
        pbSet = new QPushButton(VeraCryptPIMDialog);
        pbSet->setObjectName(QString::fromUtf8("pbSet"));
        pbSet->setGeometry(QRect(139, 150, 101, 31));
        pbCancel = new QPushButton(VeraCryptPIMDialog);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(239, 150, 101, 31));
        label = new QLabel(VeraCryptPIMDialog);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(20, 10, 451, 91));
        label->setAlignment(Qt::AlignCenter);
        lineEditPIM = new QLineEdit(VeraCryptPIMDialog);
        lineEditPIM->setObjectName(QString::fromUtf8("lineEditPIM"));
        lineEditPIM->setGeometry(QRect(20, 110, 441, 31));
        lineEditPIM->setEchoMode(QLineEdit::Password);

        retranslateUi(VeraCryptPIMDialog);

        QMetaObject::connectSlotsByName(VeraCryptPIMDialog);
    } // setupUi

    void retranslateUi(QDialog *VeraCryptPIMDialog)
    {
        VeraCryptPIMDialog->setWindowTitle(QCoreApplication::translate("VeraCryptPIMDialog", "VeraCrypt PIM value", nullptr));
        pbSet->setText(QCoreApplication::translate("VeraCryptPIMDialog", "&Set", nullptr));
        pbCancel->setText(QCoreApplication::translate("VeraCryptPIMDialog", "&Cancel", nullptr));
        label->setText(QCoreApplication::translate("VeraCryptPIMDialog", "TextLabel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class VeraCryptPIMDialog: public Ui_VeraCryptPIMDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_VERACRYPTPIMDIALOG_H
