/********************************************************************************
** Form generated from reading UI file 'debugwindow.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DEBUGWINDOW_H
#define UI_DEBUGWINDOW_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_debugWindow
{
public:
    QPushButton *pbClear;
    QPushButton *pbClose;
    QTextEdit *textEdit;

    void setupUi(QWidget *debugWindow)
    {
        if (debugWindow->objectName().isEmpty())
            debugWindow->setObjectName(QString::fromUtf8("debugWindow"));
        debugWindow->resize(659, 465);
        pbClear = new QPushButton(debugWindow);
        pbClear->setObjectName(QString::fromUtf8("pbClear"));
        pbClear->setGeometry(QRect(220, 430, 111, 33));
        pbClose = new QPushButton(debugWindow);
        pbClose->setObjectName(QString::fromUtf8("pbClose"));
        pbClose->setGeometry(QRect(330, 430, 111, 33));
        pbClose->setAutoDefault(true);
        textEdit = new QTextEdit(debugWindow);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));
        textEdit->setGeometry(QRect(10, 10, 641, 421));
        textEdit->setReadOnly(true);

        retranslateUi(debugWindow);

        pbClose->setDefault(true);


        QMetaObject::connectSlotsByName(debugWindow);
    } // setupUi

    void retranslateUi(QWidget *debugWindow)
    {
        debugWindow->setWindowTitle(QCoreApplication::translate("debugWindow", "zuluCrypt Debug Window", nullptr));
        pbClear->setText(QCoreApplication::translate("debugWindow", "C&lear", nullptr));
        pbClose->setText(QCoreApplication::translate("debugWindow", "&Close", nullptr));
    } // retranslateUi

};

namespace Ui {
    class debugWindow: public Ui_debugWindow {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DEBUGWINDOW_H
