/********************************************************************************
** Form generated from reading UI file 'password_dialog.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASSWORD_DIALOG_H
#define UI_PASSWORD_DIALOG_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTextEdit>

QT_BEGIN_NAMESPACE

class Ui_password_dialog
{
public:
    QGroupBox *groupBox;
    QLabel *labelHeader;
    QLineEdit *lineEditKey;
    QLabel *labelWalletDoesNotExist;
    QTextEdit *textEdit_2;
    QTextEdit *textEdit;
    QPushButton *pushButtonSend;
    QPushButton *pushButtonCancel;
    QPushButton *pushButtonOK;
    QPushButton *pushButtonOK_2;

    void setupUi(QDialog *password_dialog)
    {
        if (password_dialog->objectName().isEmpty())
            password_dialog->setObjectName(QString::fromUtf8("password_dialog"));
        password_dialog->setWindowModality(Qt::ApplicationModal);
        password_dialog->resize(501, 171);
        QIcon icon;
        icon.addFile(QString::fromUtf8("lxqt_wallet_icon.png"), QSize(), QIcon::Normal, QIcon::Off);
        password_dialog->setWindowIcon(icon);
        groupBox = new QGroupBox(password_dialog);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setGeometry(QRect(10, 10, 481, 161));
        labelHeader = new QLabel(groupBox);
        labelHeader->setObjectName(QString::fromUtf8("labelHeader"));
        labelHeader->setGeometry(QRect(20, 20, 441, 81));
        labelHeader->setAlignment(Qt::AlignCenter);
        labelHeader->setWordWrap(true);
        lineEditKey = new QLineEdit(groupBox);
        lineEditKey->setObjectName(QString::fromUtf8("lineEditKey"));
        lineEditKey->setGeometry(QRect(20, 100, 441, 31));
        lineEditKey->setEchoMode(QLineEdit::Password);
        labelWalletDoesNotExist = new QLabel(groupBox);
        labelWalletDoesNotExist->setObjectName(QString::fromUtf8("labelWalletDoesNotExist"));
        labelWalletDoesNotExist->setGeometry(QRect(10, 20, 461, 81));
        labelWalletDoesNotExist->setAlignment(Qt::AlignCenter);
        textEdit_2 = new QTextEdit(groupBox);
        textEdit_2->setObjectName(QString::fromUtf8("textEdit_2"));
        textEdit_2->setGeometry(QRect(20, 140, 61, 20));
        textEdit = new QTextEdit(groupBox);
        textEdit->setObjectName(QString::fromUtf8("textEdit"));
        textEdit->setGeometry(QRect(400, 140, 71, 21));
        pushButtonSend = new QPushButton(groupBox);
        pushButtonSend->setObjectName(QString::fromUtf8("pushButtonSend"));
        pushButtonSend->setGeometry(QRect(120, 130, 121, 31));
        pushButtonCancel = new QPushButton(password_dialog);
        pushButtonCancel->setObjectName(QString::fromUtf8("pushButtonCancel"));
        pushButtonCancel->setGeometry(QRect(250, 140, 121, 31));
        pushButtonOK = new QPushButton(password_dialog);
        pushButtonOK->setObjectName(QString::fromUtf8("pushButtonOK"));
        pushButtonOK->setGeometry(QRect(200, 140, 91, 31));
        pushButtonOK_2 = new QPushButton(password_dialog);
        pushButtonOK_2->setObjectName(QString::fromUtf8("pushButtonOK_2"));
        pushButtonOK_2->setGeometry(QRect(200, 140, 91, 31));

        retranslateUi(password_dialog);

        pushButtonSend->setDefault(true);


        QMetaObject::connectSlotsByName(password_dialog);
    } // setupUi

    void retranslateUi(QDialog *password_dialog)
    {
        password_dialog->setWindowTitle(QCoreApplication::translate("password_dialog", "lxqt wallet service", nullptr));
        groupBox->setTitle(QString());
        labelHeader->setText(QCoreApplication::translate("password_dialog", "The application '%1' has requested to open the wallet '%2'.Enter the password below for this wallet to unlock it", nullptr));
        labelWalletDoesNotExist->setText(QCoreApplication::translate("password_dialog", "Wallet '%1' does not exist,do you want to create it?", nullptr));
        textEdit_2->setHtml(QCoreApplication::translate("password_dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Monospace'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-size:9pt;\">Wallet </span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">'%1'</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\"> does not exist, do you want to create it?</span></p></body></html>", nullptr));
        textEdit->setHtml(QCoreApplication::translate("password_dialog", "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.0//EN\" \"http://www.w3.org/TR/REC-html40/strict.dtd\">\n"
"<html><head><meta name=\"qrichtext\" content=\"1\" /><style type=\"text/css\">\n"
"p, li { white-space: pre-wrap; }\n"
"</style></head><body style=\" font-family:'Monospace'; font-size:10pt; font-weight:400; font-style:normal;\">\n"
"<p style=\" margin-top:0px; margin-bottom:0px; margin-left:0px; margin-right:0px; -qt-block-indent:0; text-indent:0px;\"><span style=\" font-family:'Sans Serif'; font-size:9pt;\">An application </span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\">'%1'</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\"> has requested to open a wallet</span><span style=\" font-family:'Sans Serif'; font-size:9pt; font-weight:600;\"> '%2'</span><span style=\" font-family:'Sans Serif'; font-size:9pt;\">. Enter the password below for this wallet to unlock it.</span></p></body></html>", nullptr));
        pushButtonSend->setText(QCoreApplication::translate("password_dialog", "&Unlock", nullptr));
        pushButtonCancel->setText(QCoreApplication::translate("password_dialog", "&Cancel", nullptr));
        pushButtonOK->setText(QCoreApplication::translate("password_dialog", "ok", nullptr));
        pushButtonOK_2->setText(QCoreApplication::translate("password_dialog", "&Ok", nullptr));
    } // retranslateUi

};

namespace Ui {
    class password_dialog: public Ui_password_dialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PASSWORD_DIALOG_H
