/********************************************************************************
** Form generated from reading UI file 'createfile.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEFILE_H
#define UI_CREATEFILE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_createfile
{
public:
    QLineEdit *lineEditFileName;
    QLabel *label;
    QLineEdit *lineEditFilePath;
    QLabel *label_2;
    QLabel *label_3;
    QLineEdit *lineEditFileSize;
    QProgressBar *progressBar;
    QPushButton *pbOpenFolder;
    QPushButton *pbCancel;
    QLabel *label_4;
    QPushButton *pbCreate;
    QComboBox *comboBox;
    QCheckBox *checkBoxNoRandomData;
    QLabel *label_5;
    QLabel *label_6;
    QPushButton *pushButton;

    void setupUi(QDialog *createfile)
    {
        if (createfile->objectName().isEmpty())
            createfile->setObjectName(QString::fromUtf8("createfile"));
        createfile->setWindowModality(Qt::ApplicationModal);
        createfile->resize(521, 225);
        lineEditFileName = new QLineEdit(createfile);
        lineEditFileName->setObjectName(QString::fromUtf8("lineEditFileName"));
        lineEditFileName->setGeometry(QRect(120, 10, 281, 31));
        label = new QLabel(createfile);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 10, 101, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        lineEditFilePath = new QLineEdit(createfile);
        lineEditFilePath->setObjectName(QString::fromUtf8("lineEditFilePath"));
        lineEditFilePath->setGeometry(QRect(120, 40, 281, 31));
        label_2 = new QLabel(createfile);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(10, 40, 101, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        label_3 = new QLabel(createfile);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(10, 140, 101, 31));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);
        lineEditFileSize = new QLineEdit(createfile);
        lineEditFileSize->setObjectName(QString::fromUtf8("lineEditFileSize"));
        lineEditFileSize->setGeometry(QRect(120, 140, 113, 31));
        progressBar = new QProgressBar(createfile);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setGeometry(QRect(120, 170, 281, 21));
        progressBar->setValue(24);
        pbOpenFolder = new QPushButton(createfile);
        pbOpenFolder->setObjectName(QString::fromUtf8("pbOpenFolder"));
        pbOpenFolder->setGeometry(QRect(400, 40, 31, 31));
        pbCancel = new QPushButton(createfile);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(260, 190, 111, 31));
        pbCancel->setAutoDefault(true);
        label_4 = new QLabel(createfile);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(10, 160, 101, 41));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4->setWordWrap(true);
        pbCreate = new QPushButton(createfile);
        pbCreate->setObjectName(QString::fromUtf8("pbCreate"));
        pbCreate->setGeometry(QRect(150, 190, 111, 31));
        pbCreate->setAutoDefault(true);
        comboBox = new QComboBox(createfile);
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->addItem(QString());
        comboBox->setObjectName(QString::fromUtf8("comboBox"));
        comboBox->setGeometry(QRect(230, 140, 51, 31));
        comboBox->setFrame(true);
        checkBoxNoRandomData = new QCheckBox(createfile);
        checkBoxNoRandomData->setObjectName(QString::fromUtf8("checkBoxNoRandomData"));
        checkBoxNoRandomData->setGeometry(QRect(120, 70, 21, 71));
        label_5 = new QLabel(createfile);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setGeometry(QRect(150, 70, 251, 71));
        label_5->setWordWrap(true);
        label_6 = new QLabel(createfile);
        label_6->setObjectName(QString::fromUtf8("label_6"));
        label_6->setGeometry(QRect(0, 0, 521, 221));
        label_6->setAutoFillBackground(true);
        label_6->setAlignment(Qt::AlignCenter);
        label_6->setWordWrap(true);
        pushButton = new QPushButton(createfile);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(200, 190, 121, 33));
        QWidget::setTabOrder(lineEditFileName, lineEditFilePath);
        QWidget::setTabOrder(lineEditFilePath, pbOpenFolder);
        QWidget::setTabOrder(pbOpenFolder, lineEditFileSize);
        QWidget::setTabOrder(lineEditFileSize, comboBox);
        QWidget::setTabOrder(comboBox, pbCreate);
        QWidget::setTabOrder(pbCreate, pbCancel);

        retranslateUi(createfile);

        pbCancel->setDefault(false);
        pbCreate->setDefault(true);


        QMetaObject::connectSlotsByName(createfile);
    } // setupUi

    void retranslateUi(QDialog *createfile)
    {
        createfile->setWindowTitle(QCoreApplication::translate("createfile", "Create A Container File", nullptr));
        label->setText(QCoreApplication::translate("createfile", "File Name", nullptr));
        label_2->setText(QCoreApplication::translate("createfile", "File Path", nullptr));
        label_3->setText(QCoreApplication::translate("createfile", "File Size", nullptr));
#if QT_CONFIG(tooltip)
        pbOpenFolder->setToolTip(QCoreApplication::translate("createfile", "open a folder dialog box", nullptr));
#endif // QT_CONFIG(tooltip)
        pbOpenFolder->setText(QString());
        pbCancel->setText(QCoreApplication::translate("createfile", "&Cancel", nullptr));
        label_4->setText(QCoreApplication::translate("createfile", "% Complete", nullptr));
        pbCreate->setText(QCoreApplication::translate("createfile", "C&reate", nullptr));
        comboBox->setItemText(0, QCoreApplication::translate("createfile", "KB", nullptr));
        comboBox->setItemText(1, QCoreApplication::translate("createfile", "MB", nullptr));
        comboBox->setItemText(2, QCoreApplication::translate("createfile", "GB", nullptr));

        checkBoxNoRandomData->setText(QString());
        label_5->setText(QCoreApplication::translate("createfile", "Do Not Write Random Data To Container(STRONGLY discouraged)", nullptr));
        label_6->setText(QCoreApplication::translate("createfile", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("createfile", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class createfile: public Ui_createfile {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEFILE_H
