/********************************************************************************
** Form generated from reading UI file 'createkeyfile.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEKEYFILE_H
#define UI_CREATEKEYFILE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_createkeyfile
{
public:
    QLineEdit *lineEditFileName;
    QLabel *label;
    QLineEdit *lineEditPath;
    QPushButton *pbOpenFolder;
    QPushButton *pbCreate;
    QPushButton *pbCancel;
    QLabel *label_2;
    QLabel *labelRNG;
    QComboBox *comboBoxRNG;
    QLabel *label_3;
    QPushButton *pushButton;

    void setupUi(QDialog *createkeyfile)
    {
        if (createkeyfile->objectName().isEmpty())
            createkeyfile->setObjectName(QString::fromUtf8("createkeyfile"));
        createkeyfile->setWindowModality(Qt::ApplicationModal);
        createkeyfile->resize(551, 133);
        lineEditFileName = new QLineEdit(createkeyfile);
        lineEditFileName->setObjectName(QString::fromUtf8("lineEditFileName"));
        lineEditFileName->setGeometry(QRect(120, 10, 311, 31));
        label = new QLabel(createkeyfile);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 10, 101, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        lineEditPath = new QLineEdit(createkeyfile);
        lineEditPath->setObjectName(QString::fromUtf8("lineEditPath"));
        lineEditPath->setGeometry(QRect(120, 40, 311, 31));
        pbOpenFolder = new QPushButton(createkeyfile);
        pbOpenFolder->setObjectName(QString::fromUtf8("pbOpenFolder"));
        pbOpenFolder->setGeometry(QRect(430, 40, 31, 31));
        pbCreate = new QPushButton(createkeyfile);
        pbCreate->setObjectName(QString::fromUtf8("pbCreate"));
        pbCreate->setGeometry(QRect(200, 100, 81, 31));
        pbCreate->setAutoDefault(true);
        pbCancel = new QPushButton(createkeyfile);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(280, 100, 81, 31));
        pbCancel->setAutoDefault(true);
        label_2 = new QLabel(createkeyfile);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(10, 40, 101, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        labelRNG = new QLabel(createkeyfile);
        labelRNG->setObjectName(QString::fromUtf8("labelRNG"));
        labelRNG->setGeometry(QRect(10, 70, 101, 31));
        labelRNG->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelRNG->setWordWrap(true);
        comboBoxRNG = new QComboBox(createkeyfile);
        comboBoxRNG->addItem(QString::fromUtf8("/dev/urandom"));
        comboBoxRNG->addItem(QString::fromUtf8("/dev/random"));
        comboBoxRNG->setObjectName(QString::fromUtf8("comboBoxRNG"));
        comboBoxRNG->setGeometry(QRect(120, 70, 161, 31));
        label_3 = new QLabel(createkeyfile);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(0, 0, 551, 131));
        label_3->setAutoFillBackground(true);
        label_3->setAlignment(Qt::AlignCenter);
        label_3->setWordWrap(true);
        pushButton = new QPushButton(createkeyfile);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(220, 100, 111, 33));
        QWidget::setTabOrder(lineEditFileName, lineEditPath);
        QWidget::setTabOrder(lineEditPath, pbOpenFolder);
        QWidget::setTabOrder(pbOpenFolder, comboBoxRNG);
        QWidget::setTabOrder(comboBoxRNG, pbCreate);
        QWidget::setTabOrder(pbCreate, pbCancel);

        retranslateUi(createkeyfile);

        pbCreate->setDefault(true);
        pbCancel->setDefault(false);


        QMetaObject::connectSlotsByName(createkeyfile);
    } // setupUi

    void retranslateUi(QDialog *createkeyfile)
    {
        createkeyfile->setWindowTitle(QCoreApplication::translate("createkeyfile", "Create A KeyFile", nullptr));
        label->setText(QCoreApplication::translate("createkeyfile", "Keyfile Name", nullptr));
#if QT_CONFIG(tooltip)
        lineEditPath->setToolTip(QCoreApplication::translate("createkeyfile", "path to a folder to create a key in", nullptr));
#endif // QT_CONFIG(tooltip)
#if QT_CONFIG(tooltip)
        pbOpenFolder->setToolTip(QCoreApplication::translate("createkeyfile", "open a folder a key file will be created in", nullptr));
#endif // QT_CONFIG(tooltip)
        pbOpenFolder->setText(QString());
        pbCreate->setText(QCoreApplication::translate("createkeyfile", "C&reate", nullptr));
        pbCancel->setText(QCoreApplication::translate("createkeyfile", "&Cancel", nullptr));
        label_2->setText(QCoreApplication::translate("createkeyfile", "KeyFile Path", nullptr));
        labelRNG->setText(QCoreApplication::translate("createkeyfile", "RNG", nullptr));

        label_3->setText(QCoreApplication::translate("createkeyfile", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("createkeyfile", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class createkeyfile: public Ui_createkeyfile {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEKEYFILE_H
