/********************************************************************************
** Form generated from reading UI file 'zulumount.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ZULUMOUNT_H
#define UI_ZULUMOUNT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_zuluMount
{
public:
    QVBoxLayout *verticalLayout_3;
    QWidget *centralWidget;
    QVBoxLayout *verticalLayout;
    QTableWidget *tableWidget;
    QHBoxLayout *horizontalLayout;
    QPushButton *pbunlockcryptfs;
    QPushButton *pbmount;
    QPushButton *pbupdate;
    QPushButton *pbfavorites;
    QPushButton *pbmenu;

    void setupUi(QWidget *zuluMount)
    {
        if (zuluMount->objectName().isEmpty())
            zuluMount->setObjectName(QString::fromUtf8("zuluMount"));
        zuluMount->setWindowModality(Qt::NonModal);
        zuluMount->resize(910, 477);
        QIcon icon;
        icon.addFile(QString::fromUtf8(":/zuluMount.png"), QSize(), QIcon::Normal, QIcon::Off);
        zuluMount->setWindowIcon(icon);
        verticalLayout_3 = new QVBoxLayout(zuluMount);
        verticalLayout_3->setSpacing(6);
        verticalLayout_3->setContentsMargins(5, 5, 5, 5);
        verticalLayout_3->setObjectName(QString::fromUtf8("verticalLayout_3"));
        centralWidget = new QWidget(zuluMount);
        centralWidget->setObjectName(QString::fromUtf8("centralWidget"));
        verticalLayout = new QVBoxLayout(centralWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(5, 5, 5, 5);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        verticalLayout->setContentsMargins(0, 0, 0, 0);
        tableWidget = new QTableWidget(centralWidget);
        if (tableWidget->columnCount() < 6)
            tableWidget->setColumnCount(6);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        __qtablewidgetitem1->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        __qtablewidgetitem3->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        __qtablewidgetitem4->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        QTableWidgetItem *__qtablewidgetitem5 = new QTableWidgetItem();
        __qtablewidgetitem5->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(5, __qtablewidgetitem5);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setShowGrid(false);
        tableWidget->setGridStyle(Qt::NoPen);

        verticalLayout->addWidget(tableWidget);

        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setSpacing(6);
        horizontalLayout->setObjectName(QString::fromUtf8("horizontalLayout"));
        horizontalLayout->setSizeConstraint(QLayout::SetFixedSize);
        pbunlockcryptfs = new QPushButton(centralWidget);
        pbunlockcryptfs->setObjectName(QString::fromUtf8("pbunlockcryptfs"));

        horizontalLayout->addWidget(pbunlockcryptfs);

        pbmount = new QPushButton(centralWidget);
        pbmount->setObjectName(QString::fromUtf8("pbmount"));
        pbmount->setAutoDefault(false);

        horizontalLayout->addWidget(pbmount);

        pbupdate = new QPushButton(centralWidget);
        pbupdate->setObjectName(QString::fromUtf8("pbupdate"));

        horizontalLayout->addWidget(pbupdate);

        pbfavorites = new QPushButton(centralWidget);
        pbfavorites->setObjectName(QString::fromUtf8("pbfavorites"));

        horizontalLayout->addWidget(pbfavorites);

        pbmenu = new QPushButton(centralWidget);
        pbmenu->setObjectName(QString::fromUtf8("pbmenu"));

        horizontalLayout->addWidget(pbmenu);


        verticalLayout->addLayout(horizontalLayout);


        verticalLayout_3->addWidget(centralWidget);


        retranslateUi(zuluMount);

        pbmount->setDefault(false);


        QMetaObject::connectSlotsByName(zuluMount);
    } // setupUi

    void retranslateUi(QWidget *zuluMount)
    {
        zuluMount->setWindowTitle(QCoreApplication::translate("zuluMount", "zuluMount", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("zuluMount", "Volume Path", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("zuluMount", "Mount Point Path", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("zuluMount", "File System", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("zuluMount", "Label", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = tableWidget->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("zuluMount", "Size", nullptr));
        QTableWidgetItem *___qtablewidgetitem5 = tableWidget->horizontalHeaderItem(5);
        ___qtablewidgetitem5->setText(QCoreApplication::translate("zuluMount", "%Used", nullptr));
        pbunlockcryptfs->setText(QCoreApplication::translate("zuluMount", "Mount F&older", nullptr));
        pbmount->setText(QCoreApplication::translate("zuluMount", "&Mount File", nullptr));
        pbupdate->setText(QCoreApplication::translate("zuluMount", "&Refresh", nullptr));
        pbfavorites->setText(QCoreApplication::translate("zuluMount", "&Favorites", nullptr));
        pbmenu->setText(QCoreApplication::translate("zuluMount", "Men&u", nullptr));
    } // retranslateUi

};

namespace Ui {
    class zuluMount: public Ui_zuluMount {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ZULUMOUNT_H
