/********************************************************************************
** Form generated from reading UI file 'createvolume.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CREATEVOLUME_H
#define UI_CREATEVOLUME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_createvolume
{
public:
    QLineEdit *lineEditVolumePath;
    QLabel *labelVolumePath;
    QPushButton *pbCreate;
    QPushButton *pbCancel;
    QFrame *frame_3;
    QLineEdit *lineEditPassphrase1;
    QPushButton *pbOpenKeyFile;
    QLabel *labelPassPhrase;
    QLineEdit *lineEditPassPhrase2;
    QLabel *labelRepeatPassPhrase;
    QComboBox *cbNormalVolume;
    QComboBox *comboBoxFS;
    QComboBox *comboBoxVolumeType;
    QPushButton *pbLUKS2Options;
    QComboBox *comboBoxRNG;
    QLabel *labelvolumetype;
    QFrame *frame;
    QLineEdit *lineEditHiddenKey;
    QLabel *labelHidden;
    QLabel *label_2Hidden;
    QLineEdit *lineEditHiddenKey1;
    QPushButton *pbHiddenKeyFile;
    QLabel *label;
    QLineEdit *lineEditHiddenSize;
    QComboBox *comboBoxHiddenSize;
    QComboBox *cbHiddenVolume;
    QLabel *labelIterationNumber;
    QLineEdit *lineEditIterationNumber;
    QComboBox *comboBoxOptions;
    QLabel *labelvolumeOptions;
    QLabel *labelfs;
    QLabel *labelrng;
    QLineEdit *lineEditPIM;
    QLabel *label_2;
    QLabel *veraCryptWarning;
    QLabel *labelLUKS2Options;
    QGroupBox *groupBoxLUKS2Options;
    QLabel *label_7;
    QPushButton *pbLuks2Set;
    QLabel *label_14;
    QLabel *label_15;
    QLabel *label_16;
    QComboBox *cbLuks2Pbkdf;
    QLabel *label_17;
    QLabel *label_18;
    QLineEdit *lineEditLuks2ParallelThreads;
    QLineEdit *lineEditLuks2MaxMemory;
    QLineEdit *lineEditLuks2SubSystem;
    QLineEdit *lineLEdituks2Label;
    QLabel *label_19;
    QLineEdit *lineEditLuks2UnlockingTime;
    QCheckBox *cbLuks2AllowDiscard;
    QLabel *label_20;
    QLabel *label_21;
    QLineEdit *lineEditLuks2ForcedIteration;
    QPushButton *pbLuks2Cancel;

    void setupUi(QDialog *createvolume)
    {
        if (createvolume->objectName().isEmpty())
            createvolume->setObjectName(QString::fromUtf8("createvolume"));
        createvolume->setWindowModality(Qt::ApplicationModal);
        createvolume->resize(560, 432);
        createvolume->setAcceptDrops(true);
        lineEditVolumePath = new QLineEdit(createvolume);
        lineEditVolumePath->setObjectName(QString::fromUtf8("lineEditVolumePath"));
        lineEditVolumePath->setGeometry(QRect(130, 10, 301, 31));
        labelVolumePath = new QLabel(createvolume);
        labelVolumePath->setObjectName(QString::fromUtf8("labelVolumePath"));
        labelVolumePath->setGeometry(QRect(0, 10, 121, 31));
        labelVolumePath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumePath->setWordWrap(true);
        pbCreate = new QPushButton(createvolume);
        pbCreate->setObjectName(QString::fromUtf8("pbCreate"));
        pbCreate->setGeometry(QRect(150, 400, 131, 31));
        pbCreate->setAutoDefault(true);
        pbCancel = new QPushButton(createvolume);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(280, 400, 131, 31));
        frame_3 = new QFrame(createvolume);
        frame_3->setObjectName(QString::fromUtf8("frame_3"));
        frame_3->setGeometry(QRect(0, 40, 561, 91));
        lineEditPassphrase1 = new QLineEdit(frame_3);
        lineEditPassphrase1->setObjectName(QString::fromUtf8("lineEditPassphrase1"));
        lineEditPassphrase1->setGeometry(QRect(130, 30, 301, 31));
        pbOpenKeyFile = new QPushButton(frame_3);
        pbOpenKeyFile->setObjectName(QString::fromUtf8("pbOpenKeyFile"));
        pbOpenKeyFile->setGeometry(QRect(430, 30, 31, 31));
        labelPassPhrase = new QLabel(frame_3);
        labelPassPhrase->setObjectName(QString::fromUtf8("labelPassPhrase"));
        labelPassPhrase->setGeometry(QRect(0, 30, 121, 31));
        labelPassPhrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelPassPhrase->setWordWrap(true);
        lineEditPassPhrase2 = new QLineEdit(frame_3);
        lineEditPassPhrase2->setObjectName(QString::fromUtf8("lineEditPassPhrase2"));
        lineEditPassPhrase2->setGeometry(QRect(130, 60, 301, 31));
        labelRepeatPassPhrase = new QLabel(frame_3);
        labelRepeatPassPhrase->setObjectName(QString::fromUtf8("labelRepeatPassPhrase"));
        labelRepeatPassPhrase->setGeometry(QRect(0, 60, 121, 31));
        labelRepeatPassPhrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelRepeatPassPhrase->setWordWrap(true);
        cbNormalVolume = new QComboBox(frame_3);
        cbNormalVolume->setObjectName(QString::fromUtf8("cbNormalVolume"));
        cbNormalVolume->setGeometry(QRect(130, 0, 301, 31));
        comboBoxFS = new QComboBox(createvolume);
        comboBoxFS->setObjectName(QString::fromUtf8("comboBoxFS"));
        comboBoxFS->setGeometry(QRect(130, 370, 151, 31));
        comboBoxFS->setEditable(false);
        comboBoxVolumeType = new QComboBox(createvolume);
        comboBoxVolumeType->addItem(QString::fromUtf8("plain"));
        comboBoxVolumeType->addItem(QString::fromUtf8("luks"));
        comboBoxVolumeType->setObjectName(QString::fromUtf8("comboBoxVolumeType"));
        comboBoxVolumeType->setGeometry(QRect(130, 130, 301, 31));
        comboBoxVolumeType->setLayoutDirection(Qt::LeftToRight);
        pbLUKS2Options = new QPushButton(createvolume);
        pbLUKS2Options->setObjectName(QString::fromUtf8("pbLUKS2Options"));
        pbLUKS2Options->setGeometry(QRect(430, 130, 31, 31));
        comboBoxRNG = new QComboBox(createvolume);
        comboBoxRNG->addItem(QString::fromUtf8("/dev/urandom"));
        comboBoxRNG->addItem(QString::fromUtf8("/dev/random"));
        comboBoxRNG->setObjectName(QString::fromUtf8("comboBoxRNG"));
        comboBoxRNG->setGeometry(QRect(280, 370, 151, 31));
        labelvolumetype = new QLabel(createvolume);
        labelvolumetype->setObjectName(QString::fromUtf8("labelvolumetype"));
        labelvolumetype->setGeometry(QRect(30, 130, 91, 31));
        labelvolumetype->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelvolumetype->setWordWrap(true);
        frame = new QFrame(createvolume);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setGeometry(QRect(0, 190, 551, 121));
        lineEditHiddenKey = new QLineEdit(frame);
        lineEditHiddenKey->setObjectName(QString::fromUtf8("lineEditHiddenKey"));
        lineEditHiddenKey->setGeometry(QRect(130, 30, 301, 31));
        labelHidden = new QLabel(frame);
        labelHidden->setObjectName(QString::fromUtf8("labelHidden"));
        labelHidden->setGeometry(QRect(0, 30, 121, 31));
        labelHidden->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelHidden->setWordWrap(true);
        label_2Hidden = new QLabel(frame);
        label_2Hidden->setObjectName(QString::fromUtf8("label_2Hidden"));
        label_2Hidden->setGeometry(QRect(0, 60, 121, 31));
        label_2Hidden->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2Hidden->setWordWrap(true);
        lineEditHiddenKey1 = new QLineEdit(frame);
        lineEditHiddenKey1->setObjectName(QString::fromUtf8("lineEditHiddenKey1"));
        lineEditHiddenKey1->setGeometry(QRect(130, 60, 301, 31));
        pbHiddenKeyFile = new QPushButton(frame);
        pbHiddenKeyFile->setObjectName(QString::fromUtf8("pbHiddenKeyFile"));
        pbHiddenKeyFile->setGeometry(QRect(430, 30, 31, 31));
        label = new QLabel(frame);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(0, 90, 121, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        lineEditHiddenSize = new QLineEdit(frame);
        lineEditHiddenSize->setObjectName(QString::fromUtf8("lineEditHiddenSize"));
        lineEditHiddenSize->setGeometry(QRect(130, 90, 151, 31));
        comboBoxHiddenSize = new QComboBox(frame);
        comboBoxHiddenSize->addItem(QString());
        comboBoxHiddenSize->addItem(QString());
        comboBoxHiddenSize->addItem(QString());
        comboBoxHiddenSize->addItem(QString());
        comboBoxHiddenSize->setObjectName(QString::fromUtf8("comboBoxHiddenSize"));
        comboBoxHiddenSize->setGeometry(QRect(280, 90, 151, 31));
        cbHiddenVolume = new QComboBox(frame);
        cbHiddenVolume->setObjectName(QString::fromUtf8("cbHiddenVolume"));
        cbHiddenVolume->setGeometry(QRect(130, 0, 301, 31));
        labelIterationNumber = new QLabel(frame);
        labelIterationNumber->setObjectName(QString::fromUtf8("labelIterationNumber"));
        labelIterationNumber->setGeometry(QRect(10, 0, 111, 31));
        labelIterationNumber->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelIterationNumber->setWordWrap(true);
        lineEditIterationNumber = new QLineEdit(frame);
        lineEditIterationNumber->setObjectName(QString::fromUtf8("lineEditIterationNumber"));
        lineEditIterationNumber->setGeometry(QRect(130, 0, 301, 31));
        comboBoxOptions = new QComboBox(createvolume);
        comboBoxOptions->setObjectName(QString::fromUtf8("comboBoxOptions"));
        comboBoxOptions->setGeometry(QRect(30, 160, 501, 31));
        comboBoxOptions->setLayoutDirection(Qt::LeftToRight);
        labelvolumeOptions = new QLabel(createvolume);
        labelvolumeOptions->setObjectName(QString::fromUtf8("labelvolumeOptions"));
        labelvolumeOptions->setGeometry(QRect(20, 370, 81, 31));
        labelvolumeOptions->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelvolumeOptions->setWordWrap(true);
        labelfs = new QLabel(createvolume);
        labelfs->setObjectName(QString::fromUtf8("labelfs"));
        labelfs->setGeometry(QRect(130, 340, 151, 31));
        labelfs->setAlignment(Qt::AlignCenter);
        labelrng = new QLabel(createvolume);
        labelrng->setObjectName(QString::fromUtf8("labelrng"));
        labelrng->setGeometry(QRect(280, 340, 151, 31));
        labelrng->setAlignment(Qt::AlignCenter);
        lineEditPIM = new QLineEdit(createvolume);
        lineEditPIM->setObjectName(QString::fromUtf8("lineEditPIM"));
        lineEditPIM->setGeometry(QRect(130, 310, 301, 29));
        lineEditPIM->setEchoMode(QLineEdit::Password);
        label_2 = new QLabel(createvolume);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(10, 310, 111, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        veraCryptWarning = new QLabel(createvolume);
        veraCryptWarning->setObjectName(QString::fromUtf8("veraCryptWarning"));
        veraCryptWarning->setGeometry(QRect(0, 0, 561, 431));
        veraCryptWarning->setAutoFillBackground(true);
        veraCryptWarning->setAlignment(Qt::AlignCenter);
        veraCryptWarning->setWordWrap(true);
        labelLUKS2Options = new QLabel(createvolume);
        labelLUKS2Options->setObjectName(QString::fromUtf8("labelLUKS2Options"));
        labelLUKS2Options->setGeometry(QRect(2, 6, 561, 421));
        labelLUKS2Options->setAutoFillBackground(true);
        groupBoxLUKS2Options = new QGroupBox(createvolume);
        groupBoxLUKS2Options->setObjectName(QString::fromUtf8("groupBoxLUKS2Options"));
        groupBoxLUKS2Options->setGeometry(QRect(0, 0, 561, 441));
        label_7 = new QLabel(groupBoxLUKS2Options);
        label_7->setObjectName(QString::fromUtf8("label_7"));
        label_7->setGeometry(QRect(30, 10, 491, 51));
        label_7->setAlignment(Qt::AlignCenter);
        label_7->setWordWrap(true);
        pbLuks2Set = new QPushButton(groupBoxLUKS2Options);
        pbLuks2Set->setObjectName(QString::fromUtf8("pbLuks2Set"));
        pbLuks2Set->setGeometry(QRect(280, 390, 141, 33));
        label_14 = new QLabel(groupBoxLUKS2Options);
        label_14->setObjectName(QString::fromUtf8("label_14"));
        label_14->setGeometry(QRect(20, 60, 251, 31));
        label_14->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_14->setWordWrap(true);
        label_15 = new QLabel(groupBoxLUKS2Options);
        label_15->setObjectName(QString::fromUtf8("label_15"));
        label_15->setGeometry(QRect(20, 100, 251, 31));
        label_15->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_15->setWordWrap(true);
        label_16 = new QLabel(groupBoxLUKS2Options);
        label_16->setObjectName(QString::fromUtf8("label_16"));
        label_16->setGeometry(QRect(100, 320, 171, 31));
        label_16->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        cbLuks2Pbkdf = new QComboBox(groupBoxLUKS2Options);
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->setObjectName(QString::fromUtf8("cbLuks2Pbkdf"));
        cbLuks2Pbkdf->setGeometry(QRect(280, 320, 121, 31));
        label_17 = new QLabel(groupBoxLUKS2Options);
        label_17->setObjectName(QString::fromUtf8("label_17"));
        label_17->setGeometry(QRect(20, 140, 251, 31));
        label_17->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_17->setWordWrap(true);
        label_18 = new QLabel(groupBoxLUKS2Options);
        label_18->setObjectName(QString::fromUtf8("label_18"));
        label_18->setGeometry(QRect(20, 180, 251, 31));
        label_18->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_18->setWordWrap(true);
        lineEditLuks2ParallelThreads = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2ParallelThreads->setObjectName(QString::fromUtf8("lineEditLuks2ParallelThreads"));
        lineEditLuks2ParallelThreads->setGeometry(QRect(280, 180, 121, 31));
        lineEditLuks2MaxMemory = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2MaxMemory->setObjectName(QString::fromUtf8("lineEditLuks2MaxMemory"));
        lineEditLuks2MaxMemory->setGeometry(QRect(280, 140, 121, 31));
        lineEditLuks2SubSystem = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2SubSystem->setObjectName(QString::fromUtf8("lineEditLuks2SubSystem"));
        lineEditLuks2SubSystem->setGeometry(QRect(280, 100, 121, 31));
        lineLEdituks2Label = new QLineEdit(groupBoxLUKS2Options);
        lineLEdituks2Label->setObjectName(QString::fromUtf8("lineLEdituks2Label"));
        lineLEdituks2Label->setGeometry(QRect(280, 60, 121, 31));
        label_19 = new QLabel(groupBoxLUKS2Options);
        label_19->setObjectName(QString::fromUtf8("label_19"));
        label_19->setGeometry(QRect(20, 280, 251, 31));
        label_19->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_19->setWordWrap(true);
        lineEditLuks2UnlockingTime = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2UnlockingTime->setObjectName(QString::fromUtf8("lineEditLuks2UnlockingTime"));
        lineEditLuks2UnlockingTime->setGeometry(QRect(280, 280, 121, 31));
        cbLuks2AllowDiscard = new QCheckBox(groupBoxLUKS2Options);
        cbLuks2AllowDiscard->setObjectName(QString::fromUtf8("cbLuks2AllowDiscard"));
        cbLuks2AllowDiscard->setGeometry(QRect(280, 360, 121, 21));
        label_20 = new QLabel(groupBoxLUKS2Options);
        label_20->setObjectName(QString::fromUtf8("label_20"));
        label_20->setGeometry(QRect(20, 350, 251, 41));
        label_20->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_20->setWordWrap(true);
        label_21 = new QLabel(groupBoxLUKS2Options);
        label_21->setObjectName(QString::fromUtf8("label_21"));
        label_21->setGeometry(QRect(10, 210, 261, 71));
        label_21->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_21->setWordWrap(true);
        lineEditLuks2ForcedIteration = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2ForcedIteration->setObjectName(QString::fromUtf8("lineEditLuks2ForcedIteration"));
        lineEditLuks2ForcedIteration->setGeometry(QRect(280, 230, 121, 31));
        pbLuks2Cancel = new QPushButton(groupBoxLUKS2Options);
        pbLuks2Cancel->setObjectName(QString::fromUtf8("pbLuks2Cancel"));
        pbLuks2Cancel->setGeometry(QRect(140, 390, 141, 33));
        QWidget::setTabOrder(lineEditVolumePath, cbNormalVolume);
        QWidget::setTabOrder(cbNormalVolume, pbOpenKeyFile);
        QWidget::setTabOrder(pbOpenKeyFile, lineEditPassphrase1);
        QWidget::setTabOrder(lineEditPassphrase1, lineEditPassPhrase2);
        QWidget::setTabOrder(lineEditPassPhrase2, comboBoxVolumeType);
        QWidget::setTabOrder(comboBoxVolumeType, comboBoxOptions);
        QWidget::setTabOrder(comboBoxOptions, cbHiddenVolume);
        QWidget::setTabOrder(cbHiddenVolume, pbHiddenKeyFile);
        QWidget::setTabOrder(pbHiddenKeyFile, lineEditHiddenKey);
        QWidget::setTabOrder(lineEditHiddenKey, lineEditHiddenKey1);
        QWidget::setTabOrder(lineEditHiddenKey1, lineEditHiddenSize);
        QWidget::setTabOrder(lineEditHiddenSize, comboBoxHiddenSize);
        QWidget::setTabOrder(comboBoxHiddenSize, lineEditPIM);
        QWidget::setTabOrder(lineEditPIM, comboBoxFS);
        QWidget::setTabOrder(comboBoxFS, pbCreate);
        QWidget::setTabOrder(pbCreate, comboBoxRNG);
        QWidget::setTabOrder(comboBoxRNG, pbCancel);

        retranslateUi(createvolume);

        pbCreate->setDefault(true);
        pbCancel->setDefault(false);


        QMetaObject::connectSlotsByName(createvolume);
    } // setupUi

    void retranslateUi(QDialog *createvolume)
    {
        createvolume->setWindowTitle(QCoreApplication::translate("createvolume", "Create A New Volume", nullptr));
        labelVolumePath->setText(QCoreApplication::translate("createvolume", "Path to Device", nullptr));
        pbCreate->setText(QCoreApplication::translate("createvolume", "C&reate", nullptr));
        pbCancel->setText(QCoreApplication::translate("createvolume", "&Cancel", nullptr));
#if QT_CONFIG(tooltip)
        pbOpenKeyFile->setToolTip(QCoreApplication::translate("createvolume", "open a key file", nullptr));
#endif // QT_CONFIG(tooltip)
        pbOpenKeyFile->setText(QString());
        labelPassPhrase->setText(QCoreApplication::translate("createvolume", "Password", nullptr));
        labelRepeatPassPhrase->setText(QCoreApplication::translate("createvolume", "Repeat Password", nullptr));

#if QT_CONFIG(tooltip)
        pbLUKS2Options->setToolTip(QCoreApplication::translate("createvolume", "Advanced LUKS2 Options", nullptr));
#endif // QT_CONFIG(tooltip)
        pbLUKS2Options->setText(QString());

        labelvolumetype->setText(QCoreApplication::translate("createvolume", "Volume Type", nullptr));
        labelHidden->setText(QCoreApplication::translate("createvolume", "Password", nullptr));
        label_2Hidden->setText(QCoreApplication::translate("createvolume", "Repeat Password", nullptr));
        pbHiddenKeyFile->setText(QString());
        label->setText(QCoreApplication::translate("createvolume", "Volume Size", nullptr));
        comboBoxHiddenSize->setItemText(0, QCoreApplication::translate("createvolume", "Bytes", nullptr));
        comboBoxHiddenSize->setItemText(1, QCoreApplication::translate("createvolume", "KiloBytes", nullptr));
        comboBoxHiddenSize->setItemText(2, QCoreApplication::translate("createvolume", "MegaBytes", nullptr));
        comboBoxHiddenSize->setItemText(3, QCoreApplication::translate("createvolume", "GigaBytes", nullptr));

        labelIterationNumber->setText(QCoreApplication::translate("createvolume", "Iteration Time (milliseconds)", nullptr));
        lineEditIterationNumber->setText(QString());
        labelvolumeOptions->setText(QCoreApplication::translate("createvolume", "Volume Options", nullptr));
        labelfs->setText(QCoreApplication::translate("createvolume", "File System", nullptr));
#if QT_CONFIG(tooltip)
        labelrng->setToolTip(QCoreApplication::translate("createvolume", "random number generator", nullptr));
#endif // QT_CONFIG(tooltip)
        labelrng->setText(QCoreApplication::translate("createvolume", "RNG", nullptr));
        label_2->setText(QCoreApplication::translate("createvolume", "PIM", nullptr));
        veraCryptWarning->setText(QCoreApplication::translate("createvolume", "TextLabel", nullptr));
        labelLUKS2Options->setText(QString());
        groupBoxLUKS2Options->setTitle(QString());
        label_7->setText(QCoreApplication::translate("createvolume", "Advanced Luks2 Options", nullptr));
        pbLuks2Set->setText(QCoreApplication::translate("createvolume", "Set", nullptr));
        label_14->setText(QCoreApplication::translate("createvolume", "Label", nullptr));
        label_15->setText(QCoreApplication::translate("createvolume", "Sub System", nullptr));
        label_16->setText(QCoreApplication::translate("createvolume", "Pbkdf Type", nullptr));
        cbLuks2Pbkdf->setItemText(0, QCoreApplication::translate("createvolume", "argon2id", nullptr));
        cbLuks2Pbkdf->setItemText(1, QCoreApplication::translate("createvolume", "argon2i", nullptr));
        cbLuks2Pbkdf->setItemText(2, QCoreApplication::translate("createvolume", "pbkdf2", nullptr));

        label_17->setText(QCoreApplication::translate("createvolume", "Max Memory (KB)", nullptr));
        label_18->setText(QCoreApplication::translate("createvolume", "Parallel Threads", nullptr));
        label_19->setText(QCoreApplication::translate("createvolume", "Unlocking Time Cost(Milliseconds)", nullptr));
        cbLuks2AllowDiscard->setText(QString());
        label_20->setText(QCoreApplication::translate("createvolume", "Allow Discard(TRIM)", nullptr));
        label_21->setText(QCoreApplication::translate("createvolume", "Forced Iterations\n"
"(Dangerous And Could Lead To Extremely Long Unlocking Time)", nullptr));
        pbLuks2Cancel->setText(QCoreApplication::translate("createvolume", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class createvolume: public Ui_createvolume {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CREATEVOLUME_H
