/********************************************************************************
** Form generated from reading UI file 'dialogok.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGOK_H
#define UI_DIALOGOK_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_dialogok
{
public:
    QPushButton *pbOK;
    QLabel *label;
    QPushButton *pbYES;
    QPushButton *pbNO;

    void setupUi(QDialog *dialogok)
    {
        if (dialogok->objectName().isEmpty())
            dialogok->setObjectName(QString::fromUtf8("dialogok"));
        dialogok->setWindowModality(Qt::ApplicationModal);
        dialogok->resize(502, 235);
        dialogok->setModal(true);
        pbOK = new QPushButton(dialogok);
        pbOK->setObjectName(QString::fromUtf8("pbOK"));
        pbOK->setGeometry(QRect(200, 200, 101, 31));
        label = new QLabel(dialogok);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 10, 481, 181));
        label->setFrameShape(QFrame::NoFrame);
        label->setFrameShadow(QFrame::Raised);
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        pbYES = new QPushButton(dialogok);
        pbYES->setObjectName(QString::fromUtf8("pbYES"));
        pbYES->setGeometry(QRect(150, 200, 101, 31));
        pbNO = new QPushButton(dialogok);
        pbNO->setObjectName(QString::fromUtf8("pbNO"));
        pbNO->setGeometry(QRect(250, 200, 101, 31));

        retranslateUi(dialogok);

        QMetaObject::connectSlotsByName(dialogok);
    } // setupUi

    void retranslateUi(QDialog *dialogok)
    {
        dialogok->setWindowTitle(QCoreApplication::translate("dialogok", "Dialog", nullptr));
        pbOK->setText(QCoreApplication::translate("dialogok", "&Ok", nullptr));
        label->setText(QCoreApplication::translate("dialogok", "TextLabel", nullptr));
        pbYES->setText(QCoreApplication::translate("dialogok", "&Yes", nullptr));
        pbNO->setText(QCoreApplication::translate("dialogok", "&No", nullptr));
    } // retranslateUi

};

namespace Ui {
    class dialogok: public Ui_dialogok {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGOK_H
