/****************************************************************************
** Meta object code from reading C++ file 'luksdeletekey.h'
**
** Created by: The Qt Meta Object Compiler version 67 (Qt 5.15.19)
**
** WARNING! All changes made in this file will be lost!
*****************************************************************************/

#include <memory>
#include "../../zuluCrypt-gui/luksdeletekey.h"
#include <QtCore/qbytearray.h>
#include <QtCore/qmetatype.h>
#if !defined(Q_MOC_OUTPUT_REVISION)
#error "The header file 'luksdeletekey.h' doesn't include <QObject>."
#elif Q_MOC_OUTPUT_REVISION != 67
#error "This file was generated using the moc from 5.15.19. It"
#error "cannot be used with the include files from this version of Qt."
#error "(The moc has changed too much.)"
#endif

QT_BEGIN_MOC_NAMESPACE
QT_WARNING_PUSH
QT_WARNING_DISABLE_DEPRECATED
struct qt_meta_stringdata_luksdeletekey_t {
    QByteArrayData data[15];
    char stringdata0[181];
};
#define QT_MOC_LITERAL(idx, ofs, len) \
    Q_STATIC_BYTE_ARRAY_DATA_HEADER_INITIALIZER_WITH_OFFSET(len, \
    qptrdiff(offsetof(qt_meta_stringdata_luksdeletekey_t, stringdata0) + ofs \
        - idx * sizeof(QByteArrayData)) \
    )
static const qt_meta_stringdata_luksdeletekey_t qt_meta_stringdata_luksdeletekey = {
    {
QT_MOC_LITERAL(0, 0, 13), // "luksdeletekey"
QT_MOC_LITERAL(1, 14, 15), // "pbDeleteClicked"
QT_MOC_LITERAL(2, 30, 0), // ""
QT_MOC_LITERAL(3, 31, 10), // "volumePath"
QT_MOC_LITERAL(4, 42, 16), // "passPhraseIsFile"
QT_MOC_LITERAL(5, 59, 10), // "passPhrase"
QT_MOC_LITERAL(6, 70, 22), // "pbOpenPartitionClicked"
QT_MOC_LITERAL(7, 93, 12), // "HideUISignal"
QT_MOC_LITERAL(8, 106, 3), // "Key"
QT_MOC_LITERAL(9, 110, 15), // "pbOpenPartition"
QT_MOC_LITERAL(10, 126, 8), // "pbDelete"
QT_MOC_LITERAL(11, 135, 8), // "pbCancel"
QT_MOC_LITERAL(12, 144, 13), // "pbOpenKeyFile"
QT_MOC_LITERAL(13, 158, 12), // "pbOpenVolume"
QT_MOC_LITERAL(14, 171, 9) // "deleteKey"

    },
    "luksdeletekey\0pbDeleteClicked\0\0"
    "volumePath\0passPhraseIsFile\0passPhrase\0"
    "pbOpenPartitionClicked\0HideUISignal\0"
    "Key\0pbOpenPartition\0pbDelete\0pbCancel\0"
    "pbOpenKeyFile\0pbOpenVolume\0deleteKey"
};
#undef QT_MOC_LITERAL

static const uint qt_meta_data_luksdeletekey[] = {

 // content:
       8,       // revision
       0,       // classname
       0,    0, // classinfo
      10,   14, // methods
       0,    0, // properties
       0,    0, // enums/sets
       0,    0, // constructors
       0,       // flags
       3,       // signalCount

 // signals: name, argc, parameters, tag, flags
       1,    3,   64,    2, 0x06 /* Public */,
       6,    0,   71,    2, 0x06 /* Public */,
       7,    0,   72,    2, 0x06 /* Public */,

 // slots: name, argc, parameters, tag, flags
       8,    1,   73,    2, 0x08 /* Private */,
       9,    0,   76,    2, 0x08 /* Private */,
      10,    0,   77,    2, 0x08 /* Private */,
      11,    0,   78,    2, 0x08 /* Private */,
      12,    0,   79,    2, 0x08 /* Private */,
      13,    0,   80,    2, 0x08 /* Private */,
      14,    1,   81,    2, 0x08 /* Private */,

 // signals: parameters
    QMetaType::Void, QMetaType::QString, QMetaType::Bool, QMetaType::QString,    3,    4,    5,
    QMetaType::Void,
    QMetaType::Void,

 // slots: parameters
    QMetaType::Void, QMetaType::Int,    2,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void,
    QMetaType::Void, QMetaType::QStringList,    2,

       0        // eod
};

void luksdeletekey::qt_static_metacall(QObject *_o, QMetaObject::Call _c, int _id, void **_a)
{
    if (_c == QMetaObject::InvokeMetaMethod) {
        auto *_t = static_cast<luksdeletekey *>(_o);
        (void)_t;
        switch (_id) {
        case 0: _t->pbDeleteClicked((*reinterpret_cast< QString(*)>(_a[1])),(*reinterpret_cast< bool(*)>(_a[2])),(*reinterpret_cast< QString(*)>(_a[3]))); break;
        case 1: _t->pbOpenPartitionClicked(); break;
        case 2: _t->HideUISignal(); break;
        case 3: _t->Key((*reinterpret_cast< int(*)>(_a[1]))); break;
        case 4: _t->pbOpenPartition(); break;
        case 5: _t->pbDelete(); break;
        case 6: _t->pbCancel(); break;
        case 7: _t->pbOpenKeyFile(); break;
        case 8: _t->pbOpenVolume(); break;
        case 9: _t->deleteKey((*reinterpret_cast< const QStringList(*)>(_a[1]))); break;
        default: ;
        }
    } else if (_c == QMetaObject::IndexOfMethod) {
        int *result = reinterpret_cast<int *>(_a[0]);
        {
            using _t = void (luksdeletekey::*)(QString , bool , QString );
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&luksdeletekey::pbDeleteClicked)) {
                *result = 0;
                return;
            }
        }
        {
            using _t = void (luksdeletekey::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&luksdeletekey::pbOpenPartitionClicked)) {
                *result = 1;
                return;
            }
        }
        {
            using _t = void (luksdeletekey::*)();
            if (*reinterpret_cast<_t *>(_a[1]) == static_cast<_t>(&luksdeletekey::HideUISignal)) {
                *result = 2;
                return;
            }
        }
    }
}

QT_INIT_METAOBJECT const QMetaObject luksdeletekey::staticMetaObject = { {
    QMetaObject::SuperData::link<QDialog::staticMetaObject>(),
    qt_meta_stringdata_luksdeletekey.data,
    qt_meta_data_luksdeletekey,
    qt_static_metacall,
    nullptr,
    nullptr
} };


const QMetaObject *luksdeletekey::metaObject() const
{
    return QObject::d_ptr->metaObject ? QObject::d_ptr->dynamicMetaObject() : &staticMetaObject;
}

void *luksdeletekey::qt_metacast(const char *_clname)
{
    if (!_clname) return nullptr;
    if (!strcmp(_clname, qt_meta_stringdata_luksdeletekey.stringdata0))
        return static_cast<void*>(this);
    return QDialog::qt_metacast(_clname);
}

int luksdeletekey::qt_metacall(QMetaObject::Call _c, int _id, void **_a)
{
    _id = QDialog::qt_metacall(_c, _id, _a);
    if (_id < 0)
        return _id;
    if (_c == QMetaObject::InvokeMetaMethod) {
        if (_id < 10)
            qt_static_metacall(this, _c, _id, _a);
        _id -= 10;
    } else if (_c == QMetaObject::RegisterMethodArgumentMetaType) {
        if (_id < 10)
            *reinterpret_cast<int*>(_a[0]) = -1;
        _id -= 10;
    }
    return _id;
}

// SIGNAL 0
void luksdeletekey::pbDeleteClicked(QString _t1, bool _t2, QString _t3)
{
    void *_a[] = { nullptr, const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t1))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t2))), const_cast<void*>(reinterpret_cast<const void*>(std::addressof(_t3))) };
    QMetaObject::activate(this, &staticMetaObject, 0, _a);
}

// SIGNAL 1
void luksdeletekey::pbOpenPartitionClicked()
{
    QMetaObject::activate(this, &staticMetaObject, 1, nullptr);
}

// SIGNAL 2
void luksdeletekey::HideUISignal()
{
    QMetaObject::activate(this, &staticMetaObject, 2, nullptr);
}
QT_WARNING_POP
QT_END_MOC_NAMESPACE
