/********************************************************************************
** Form generated from reading UI file 'filemanager.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_FILEMANAGER_H
#define UI_FILEMANAGER_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_fileManager
{
public:
    QLabel *label;
    QLineEdit *lineEdit;
    QPushButton *pushButton;

    void setupUi(QDialog *fileManager)
    {
        if (fileManager->objectName().isEmpty())
            fileManager->setObjectName(QString::fromUtf8("fileManager"));
        fileManager->resize(541, 215);
        label = new QLabel(fileManager);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 10, 521, 141));
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        lineEdit = new QLineEdit(fileManager);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(150, 150, 241, 29));
        pushButton = new QPushButton(fileManager);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(200, 180, 141, 31));

        retranslateUi(fileManager);

        QMetaObject::connectSlotsByName(fileManager);
    } // setupUi

    void retranslateUi(QDialog *fileManager)
    {
        fileManager->setWindowTitle(QCoreApplication::translate("fileManager", "Set File Manager", nullptr));
        label->setText(QCoreApplication::translate("fileManager", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("fileManager", "&Set", nullptr));
    } // retranslateUi

};

namespace Ui {
    class fileManager: public Ui_fileManager {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_FILEMANAGER_H
