/********************************************************************************
** Form generated from reading UI file 'mountpartition.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MOUNTPARTITION_H
#define UI_MOUNTPARTITION_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_mountPartition
{
public:
    QLabel *labelMountPoint;
    QPushButton *pbMount;
    QPushButton *pbMountFolder;
    QCheckBox *checkBox;
    QLineEdit *lineEdit;
    QPushButton *pbCancel;
    QCheckBox *checkBoxMountReadOnly;
    QCheckBox *checkBoxShareMountPoint;
    QPushButton *pbOptions;
    QFrame *frame;
    QLabel *label_2;
    QLabel *label_3;
    QLabel *label_4;
    QLineEdit *lineEditFsOptions;
    QLineEdit *lineEditVolumeOffset;
    QLineEdit *lineEditVolumePassword;
    QPushButton *pbFrameSet;
    QPushButton *pbFrameCancel;
    QLabel *label;
    QPushButton *pushButton;

    void setupUi(QWidget *mountPartition)
    {
        if (mountPartition->objectName().isEmpty())
            mountPartition->setObjectName(QString::fromUtf8("mountPartition"));
        mountPartition->resize(523, 185);
        labelMountPoint = new QLabel(mountPartition);
        labelMountPoint->setObjectName(QString::fromUtf8("labelMountPoint"));
        labelMountPoint->setGeometry(QRect(0, 10, 101, 31));
        labelMountPoint->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelMountPoint->setWordWrap(true);
        pbMount = new QPushButton(mountPartition);
        pbMount->setObjectName(QString::fromUtf8("pbMount"));
        pbMount->setGeometry(QRect(200, 140, 121, 31));
        pbMount->setAutoDefault(true);
        pbMountFolder = new QPushButton(mountPartition);
        pbMountFolder->setObjectName(QString::fromUtf8("pbMountFolder"));
        pbMountFolder->setGeometry(QRect(410, 10, 31, 31));
        checkBox = new QCheckBox(mountPartition);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setGeometry(QRect(180, 40, 231, 31));
        lineEdit = new QLineEdit(mountPartition);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(110, 10, 301, 31));
        pbCancel = new QPushButton(mountPartition);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(320, 140, 101, 31));
        pbCancel->setAutoDefault(true);
        checkBoxMountReadOnly = new QCheckBox(mountPartition);
        checkBoxMountReadOnly->setObjectName(QString::fromUtf8("checkBoxMountReadOnly"));
        checkBoxMountReadOnly->setGeometry(QRect(180, 70, 161, 41));
        checkBoxShareMountPoint = new QCheckBox(mountPartition);
        checkBoxShareMountPoint->setObjectName(QString::fromUtf8("checkBoxShareMountPoint"));
        checkBoxShareMountPoint->setGeometry(QRect(180, 110, 181, 31));
        pbOptions = new QPushButton(mountPartition);
        pbOptions->setObjectName(QString::fromUtf8("pbOptions"));
        pbOptions->setGeometry(QRect(100, 140, 101, 31));
        frame = new QFrame(mountPartition);
        frame->setObjectName(QString::fromUtf8("frame"));
        frame->setGeometry(QRect(10, 10, 501, 171));
        frame->setAutoFillBackground(true);
        frame->setFrameShape(QFrame::StyledPanel);
        frame->setFrameShadow(QFrame::Raised);
        label_2 = new QLabel(frame);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(10, 10, 311, 31));
        label_2->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_2->setWordWrap(true);
        label_3 = new QLabel(frame);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(20, 40, 301, 51));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);
        label_4 = new QLabel(frame);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(20, 90, 301, 31));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4->setWordWrap(true);
        lineEditFsOptions = new QLineEdit(frame);
        lineEditFsOptions->setObjectName(QString::fromUtf8("lineEditFsOptions"));
        lineEditFsOptions->setGeometry(QRect(330, 10, 151, 31));
        lineEditVolumeOffset = new QLineEdit(frame);
        lineEditVolumeOffset->setObjectName(QString::fromUtf8("lineEditVolumeOffset"));
        lineEditVolumeOffset->setGeometry(QRect(330, 50, 151, 31));
        lineEditVolumePassword = new QLineEdit(frame);
        lineEditVolumePassword->setObjectName(QString::fromUtf8("lineEditVolumePassword"));
        lineEditVolumePassword->setGeometry(QRect(330, 90, 151, 31));
        lineEditVolumePassword->setEchoMode(QLineEdit::Password);
        pbFrameSet = new QPushButton(frame);
        pbFrameSet->setObjectName(QString::fromUtf8("pbFrameSet"));
        pbFrameSet->setGeometry(QRect(140, 130, 111, 33));
        pbFrameCancel = new QPushButton(frame);
        pbFrameCancel->setObjectName(QString::fromUtf8("pbFrameCancel"));
        pbFrameCancel->setGeometry(QRect(250, 130, 111, 33));
        label = new QLabel(mountPartition);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 0, 501, 181));
        label->setAutoFillBackground(true);
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        pushButton = new QPushButton(mountPartition);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(200, 140, 121, 31));
        QWidget::setTabOrder(lineEdit, pbMountFolder);
        QWidget::setTabOrder(pbMountFolder, checkBox);
        QWidget::setTabOrder(checkBox, checkBoxMountReadOnly);
        QWidget::setTabOrder(checkBoxMountReadOnly, checkBoxShareMountPoint);
        QWidget::setTabOrder(checkBoxShareMountPoint, pbOptions);
        QWidget::setTabOrder(pbOptions, pbMount);
        QWidget::setTabOrder(pbMount, pbCancel);

        retranslateUi(mountPartition);

        pbMount->setDefault(true);


        QMetaObject::connectSlotsByName(mountPartition);
    } // setupUi

    void retranslateUi(QWidget *mountPartition)
    {
        mountPartition->setWindowTitle(QCoreApplication::translate("mountPartition", "select mount point path", nullptr));
        labelMountPoint->setText(QCoreApplication::translate("mountPartition", "Mount Name", nullptr));
        pbMount->setText(QCoreApplication::translate("mountPartition", "&Mount", nullptr));
        pbMountFolder->setText(QString());
        checkBox->setText(QCoreApplication::translate("mountPartition", "Use La&bel", nullptr));
        pbCancel->setText(QCoreApplication::translate("mountPartition", "&Cancel", nullptr));
        checkBoxMountReadOnly->setText(QCoreApplication::translate("mountPartition", "Mount &Read Only", nullptr));
        checkBoxShareMountPoint->setText(QCoreApplication::translate("mountPartition", "&Share Mount Point", nullptr));
        pbOptions->setText(QCoreApplication::translate("mountPartition", "&Options", nullptr));
        label_2->setText(QCoreApplication::translate("mountPartition", "Set File System Options", nullptr));
        label_3->setText(QCoreApplication::translate("mountPartition", "Enter Below The Offset Location Of The Volume About To Be Opened", nullptr));
        label_4->setText(QCoreApplication::translate("mountPartition", "Enter The Password Below To A Volume At The Above Offset", nullptr));
        pbFrameSet->setText(QCoreApplication::translate("mountPartition", "Set", nullptr));
        pbFrameCancel->setText(QCoreApplication::translate("mountPartition", "Cancel", nullptr));
        label->setText(QCoreApplication::translate("mountPartition", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("mountPartition", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class mountPartition: public Ui_mountPartition {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MOUNTPARTITION_H
