/********************************************************************************
** Form generated from reading UI file 'erasedevice.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ERASEDEVICE_H
#define UI_ERASEDEVICE_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QProgressBar>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_erasedevice
{
public:
    QLabel *labelPath;
    QPushButton *pushButtonFile;
    QPushButton *pushButtonPartition;
    QLabel *label;
    QProgressBar *progressBar;
    QPushButton *pushButtonStart;
    QPushButton *pushButtonCancel;
    QLineEdit *lineEdit;
    QLabel *label_3;
    QLabel *label_4;
    QLabel *labelAverageSpeed;
    QLabel *labelETA;
    QLabel *label_2;
    QPushButton *pushButton;

    void setupUi(QDialog *erasedevice)
    {
        if (erasedevice->objectName().isEmpty())
            erasedevice->setObjectName(QString::fromUtf8("erasedevice"));
        erasedevice->setWindowModality(Qt::ApplicationModal);
        erasedevice->resize(532, 175);
        labelPath = new QLabel(erasedevice);
        labelPath->setObjectName(QString::fromUtf8("labelPath"));
        labelPath->setGeometry(QRect(10, 20, 101, 31));
        labelPath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelPath->setWordWrap(true);
        pushButtonFile = new QPushButton(erasedevice);
        pushButtonFile->setObjectName(QString::fromUtf8("pushButtonFile"));
        pushButtonFile->setGeometry(QRect(410, 20, 31, 31));
        pushButtonPartition = new QPushButton(erasedevice);
        pushButtonPartition->setObjectName(QString::fromUtf8("pushButtonPartition"));
        pushButtonPartition->setGeometry(QRect(440, 20, 31, 31));
        label = new QLabel(erasedevice);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(10, 110, 101, 31));
        label->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label->setWordWrap(true);
        progressBar = new QProgressBar(erasedevice);
        progressBar->setObjectName(QString::fromUtf8("progressBar"));
        progressBar->setGeometry(QRect(120, 110, 291, 31));
        progressBar->setValue(24);
        pushButtonStart = new QPushButton(erasedevice);
        pushButtonStart->setObjectName(QString::fromUtf8("pushButtonStart"));
        pushButtonStart->setGeometry(QRect(190, 140, 81, 31));
        pushButtonCancel = new QPushButton(erasedevice);
        pushButtonCancel->setObjectName(QString::fromUtf8("pushButtonCancel"));
        pushButtonCancel->setGeometry(QRect(270, 140, 81, 31));
        pushButtonCancel->setAutoDefault(true);
        lineEdit = new QLineEdit(erasedevice);
        lineEdit->setObjectName(QString::fromUtf8("lineEdit"));
        lineEdit->setGeometry(QRect(120, 20, 291, 31));
        label_3 = new QLabel(erasedevice);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(10, 50, 101, 31));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);
        label_4 = new QLabel(erasedevice);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(10, 86, 101, 21));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelAverageSpeed = new QLabel(erasedevice);
        labelAverageSpeed->setObjectName(QString::fromUtf8("labelAverageSpeed"));
        labelAverageSpeed->setGeometry(QRect(120, 50, 291, 31));
        labelAverageSpeed->setText(QString::fromUtf8("N/A"));
        labelETA = new QLabel(erasedevice);
        labelETA->setObjectName(QString::fromUtf8("labelETA"));
        labelETA->setGeometry(QRect(120, 80, 291, 31));
        labelETA->setWordWrap(true);
        label_2 = new QLabel(erasedevice);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(0, 0, 531, 171));
        label_2->setAutoFillBackground(true);
        label_2->setAlignment(Qt::AlignCenter);
        pushButton = new QPushButton(erasedevice);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(220, 140, 90, 33));

        retranslateUi(erasedevice);

        pushButtonStart->setDefault(true);
        pushButtonCancel->setDefault(false);


        QMetaObject::connectSlotsByName(erasedevice);
    } // setupUi

    void retranslateUi(QDialog *erasedevice)
    {
        erasedevice->setWindowTitle(QCoreApplication::translate("erasedevice", "Erase Data On The Device By Writing Random Data Over Them", nullptr));
        labelPath->setText(QCoreApplication::translate("erasedevice", "Path to Device", nullptr));
        pushButtonFile->setText(QString());
        pushButtonPartition->setText(QString());
        label->setText(QCoreApplication::translate("erasedevice", "% Completed", nullptr));
        pushButtonStart->setText(QCoreApplication::translate("erasedevice", "&Start", nullptr));
        pushButtonCancel->setText(QCoreApplication::translate("erasedevice", "&Cancel", nullptr));
        label_3->setText(QCoreApplication::translate("erasedevice", "Average Speed", nullptr));
        label_4->setText(QCoreApplication::translate("erasedevice", "ETA", nullptr));
        labelETA->setText(QCoreApplication::translate("erasedevice", "N/A", nullptr));
        label_2->setText(QCoreApplication::translate("erasedevice", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("erasedevice", "&OK", nullptr));
    } // retranslateUi

};

namespace Ui {
    class erasedevice: public Ui_erasedevice {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ERASEDEVICE_H
