/********************************************************************************
** Form generated from reading UI file 'luksaddkey.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_LUKSADDKEY_H
#define UI_LUKSADDKEY_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_luksaddkey
{
public:
    QLabel *labelLuksVolume;
    QPushButton *pushButtonOpenFile;
    QPushButton *pushButtonOpenPartition;
    QPushButton *pushButtonAdd;
    QPushButton *pushButtonCancel;
    QLineEdit *textEditPathToVolume;
    QLabel *label;
    QLabel *label_2;
    QLineEdit *lineEditReEnterPassphrase;
    QLabel *labelReEnterPassphrase;
    QPushButton *pushButtonOpenNewKeyFile;
    QLineEdit *textEditPassphraseToAdd;
    QLabel *labelNewPassphrase;
    QComboBox *cbNewKey;
    QLineEdit *textEditExistingPassphrase;
    QLabel *labelExistingPassphrase;
    QPushButton *pushButtonOpenExistingKeyFile;
    QPushButton *pushButtonLuks2AdvancedOptions;
    QComboBox *cbExistingKey;
    QComboBox *cbVolumeType;
    QLabel *label_3;
    QLineEdit *lineEditPIM;
    QLabel *label_4;
    QLabel *label_5;
    QPushButton *pushButton;
    QLabel *labelAdvanceLuks2Options;
    QGroupBox *groupBoxLUKS2Options;
    QLabel *label_9;
    QPushButton *pbLuks2Set;
    QLabel *label_31;
    QLabel *label_32;
    QComboBox *cbLuks2Pbkdf;
    QLabel *label_33;
    QLabel *label_34;
    QLineEdit *lineEditLuks2ParallelThreads;
    QLineEdit *lineEditLuks2MaxMemory;
    QLineEdit *lineEditLuks2KeySlot;
    QLabel *label_35;
    QLineEdit *lineEditLuks2UnlockingTime;
    QLabel *label_37;
    QLineEdit *lineEditLuks2ForcedIteration;
    QPushButton *pbLuks2Cancel;

    void setupUi(QDialog *luksaddkey)
    {
        if (luksaddkey->objectName().isEmpty())
            luksaddkey->setObjectName(QString::fromUtf8("luksaddkey"));
        luksaddkey->setWindowModality(Qt::ApplicationModal);
        luksaddkey->resize(602, 342);
        luksaddkey->setAcceptDrops(true);
        luksaddkey->setModal(true);
        labelLuksVolume = new QLabel(luksaddkey);
        labelLuksVolume->setObjectName(QString::fromUtf8("labelLuksVolume"));
        labelLuksVolume->setGeometry(QRect(10, 10, 121, 31));
        labelLuksVolume->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelLuksVolume->setWordWrap(true);
        pushButtonOpenFile = new QPushButton(luksaddkey);
        pushButtonOpenFile->setObjectName(QString::fromUtf8("pushButtonOpenFile"));
        pushButtonOpenFile->setGeometry(QRect(460, 10, 31, 31));
        pushButtonOpenPartition = new QPushButton(luksaddkey);
        pushButtonOpenPartition->setObjectName(QString::fromUtf8("pushButtonOpenPartition"));
        pushButtonOpenPartition->setGeometry(QRect(490, 10, 31, 31));
        pushButtonAdd = new QPushButton(luksaddkey);
        pushButtonAdd->setObjectName(QString::fromUtf8("pushButtonAdd"));
        pushButtonAdd->setGeometry(QRect(190, 310, 111, 31));
        pushButtonAdd->setAutoDefault(true);
        pushButtonCancel = new QPushButton(luksaddkey);
        pushButtonCancel->setObjectName(QString::fromUtf8("pushButtonCancel"));
        pushButtonCancel->setGeometry(QRect(300, 310, 111, 31));
        pushButtonCancel->setAutoDefault(true);
        textEditPathToVolume = new QLineEdit(luksaddkey);
        textEditPathToVolume->setObjectName(QString::fromUtf8("textEditPathToVolume"));
        textEditPathToVolume->setGeometry(QRect(140, 10, 321, 31));
        label = new QLabel(luksaddkey);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(50, 40, 501, 31));
        label->setAlignment(Qt::AlignCenter);
        label_2 = new QLabel(luksaddkey);
        label_2->setObjectName(QString::fromUtf8("label_2"));
        label_2->setGeometry(QRect(50, 190, 501, 31));
        label_2->setAlignment(Qt::AlignCenter);
        label_2->setWordWrap(true);
        lineEditReEnterPassphrase = new QLineEdit(luksaddkey);
        lineEditReEnterPassphrase->setObjectName(QString::fromUtf8("lineEditReEnterPassphrase"));
        lineEditReEnterPassphrase->setGeometry(QRect(140, 280, 321, 31));
        labelReEnterPassphrase = new QLabel(luksaddkey);
        labelReEnterPassphrase->setObjectName(QString::fromUtf8("labelReEnterPassphrase"));
        labelReEnterPassphrase->setGeometry(QRect(10, 280, 121, 31));
        labelReEnterPassphrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelReEnterPassphrase->setWordWrap(true);
        pushButtonOpenNewKeyFile = new QPushButton(luksaddkey);
        pushButtonOpenNewKeyFile->setObjectName(QString::fromUtf8("pushButtonOpenNewKeyFile"));
        pushButtonOpenNewKeyFile->setGeometry(QRect(460, 250, 31, 31));
        pushButtonOpenNewKeyFile->setAutoDefault(true);
        textEditPassphraseToAdd = new QLineEdit(luksaddkey);
        textEditPassphraseToAdd->setObjectName(QString::fromUtf8("textEditPassphraseToAdd"));
        textEditPassphraseToAdd->setGeometry(QRect(140, 250, 321, 31));
        labelNewPassphrase = new QLabel(luksaddkey);
        labelNewPassphrase->setObjectName(QString::fromUtf8("labelNewPassphrase"));
        labelNewPassphrase->setGeometry(QRect(10, 250, 121, 31));
        labelNewPassphrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelNewPassphrase->setWordWrap(true);
        cbNewKey = new QComboBox(luksaddkey);
        cbNewKey->addItem(QString());
        cbNewKey->addItem(QString());
        cbNewKey->addItem(QString());
        cbNewKey->addItem(QString());
        cbNewKey->setObjectName(QString::fromUtf8("cbNewKey"));
        cbNewKey->setGeometry(QRect(140, 220, 321, 31));
        textEditExistingPassphrase = new QLineEdit(luksaddkey);
        textEditExistingPassphrase->setObjectName(QString::fromUtf8("textEditExistingPassphrase"));
        textEditExistingPassphrase->setGeometry(QRect(140, 100, 321, 31));
        labelExistingPassphrase = new QLabel(luksaddkey);
        labelExistingPassphrase->setObjectName(QString::fromUtf8("labelExistingPassphrase"));
        labelExistingPassphrase->setGeometry(QRect(10, 100, 121, 31));
        labelExistingPassphrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelExistingPassphrase->setWordWrap(true);
        pushButtonOpenExistingKeyFile = new QPushButton(luksaddkey);
        pushButtonOpenExistingKeyFile->setObjectName(QString::fromUtf8("pushButtonOpenExistingKeyFile"));
        pushButtonOpenExistingKeyFile->setGeometry(QRect(460, 100, 31, 31));
        pushButtonOpenExistingKeyFile->setAutoDefault(true);
        pushButtonLuks2AdvancedOptions = new QPushButton(luksaddkey);
        pushButtonLuks2AdvancedOptions->setObjectName(QString::fromUtf8("pushButtonLuks2AdvancedOptions"));
        pushButtonLuks2AdvancedOptions->setGeometry(QRect(460, 130, 31, 31));
        pushButtonLuks2AdvancedOptions->setAutoDefault(true);
        cbExistingKey = new QComboBox(luksaddkey);
        cbExistingKey->addItem(QString());
        cbExistingKey->addItem(QString());
        cbExistingKey->addItem(QString());
        cbExistingKey->addItem(QString());
        cbExistingKey->setObjectName(QString::fromUtf8("cbExistingKey"));
        cbExistingKey->setGeometry(QRect(140, 70, 321, 31));
        cbVolumeType = new QComboBox(luksaddkey);
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->setObjectName(QString::fromUtf8("cbVolumeType"));
        cbVolumeType->setGeometry(QRect(140, 130, 321, 29));
        label_3 = new QLabel(luksaddkey);
        label_3->setObjectName(QString::fromUtf8("label_3"));
        label_3->setGeometry(QRect(10, 130, 121, 31));
        label_3->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_3->setWordWrap(true);
        lineEditPIM = new QLineEdit(luksaddkey);
        lineEditPIM->setObjectName(QString::fromUtf8("lineEditPIM"));
        lineEditPIM->setGeometry(QRect(140, 160, 321, 29));
        lineEditPIM->setEchoMode(QLineEdit::Password);
        label_4 = new QLabel(luksaddkey);
        label_4->setObjectName(QString::fromUtf8("label_4"));
        label_4->setGeometry(QRect(10, 150, 121, 51));
        label_4->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_4->setWordWrap(true);
        label_5 = new QLabel(luksaddkey);
        label_5->setObjectName(QString::fromUtf8("label_5"));
        label_5->setGeometry(QRect(10, 0, 591, 341));
        label_5->setAutoFillBackground(true);
        label_5->setAlignment(Qt::AlignCenter);
        label_5->setWordWrap(true);
        pushButton = new QPushButton(luksaddkey);
        pushButton->setObjectName(QString::fromUtf8("pushButton"));
        pushButton->setGeometry(QRect(230, 300, 141, 33));
        labelAdvanceLuks2Options = new QLabel(luksaddkey);
        labelAdvanceLuks2Options->setObjectName(QString::fromUtf8("labelAdvanceLuks2Options"));
        labelAdvanceLuks2Options->setGeometry(QRect(2, 6, 601, 341));
        labelAdvanceLuks2Options->setAutoFillBackground(true);
        groupBoxLUKS2Options = new QGroupBox(luksaddkey);
        groupBoxLUKS2Options->setObjectName(QString::fromUtf8("groupBoxLUKS2Options"));
        groupBoxLUKS2Options->setGeometry(QRect(0, 0, 601, 351));
        label_9 = new QLabel(groupBoxLUKS2Options);
        label_9->setObjectName(QString::fromUtf8("label_9"));
        label_9->setGeometry(QRect(10, 10, 581, 31));
        label_9->setAlignment(Qt::AlignCenter);
        label_9->setWordWrap(true);
        pbLuks2Set = new QPushButton(groupBoxLUKS2Options);
        pbLuks2Set->setObjectName(QString::fromUtf8("pbLuks2Set"));
        pbLuks2Set->setGeometry(QRect(290, 300, 141, 33));
        label_31 = new QLabel(groupBoxLUKS2Options);
        label_31->setObjectName(QString::fromUtf8("label_31"));
        label_31->setGeometry(QRect(10, 30, 271, 51));
        label_31->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_31->setWordWrap(true);
        label_32 = new QLabel(groupBoxLUKS2Options);
        label_32->setObjectName(QString::fromUtf8("label_32"));
        label_32->setGeometry(QRect(110, 260, 171, 31));
        label_32->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        cbLuks2Pbkdf = new QComboBox(groupBoxLUKS2Options);
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->addItem(QString());
        cbLuks2Pbkdf->setObjectName(QString::fromUtf8("cbLuks2Pbkdf"));
        cbLuks2Pbkdf->setGeometry(QRect(290, 260, 121, 31));
        label_33 = new QLabel(groupBoxLUKS2Options);
        label_33->setObjectName(QString::fromUtf8("label_33"));
        label_33->setGeometry(QRect(30, 80, 251, 31));
        label_33->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_33->setWordWrap(true);
        label_34 = new QLabel(groupBoxLUKS2Options);
        label_34->setObjectName(QString::fromUtf8("label_34"));
        label_34->setGeometry(QRect(30, 120, 251, 31));
        label_34->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_34->setWordWrap(true);
        lineEditLuks2ParallelThreads = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2ParallelThreads->setObjectName(QString::fromUtf8("lineEditLuks2ParallelThreads"));
        lineEditLuks2ParallelThreads->setGeometry(QRect(290, 120, 121, 31));
        lineEditLuks2MaxMemory = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2MaxMemory->setObjectName(QString::fromUtf8("lineEditLuks2MaxMemory"));
        lineEditLuks2MaxMemory->setGeometry(QRect(290, 80, 121, 31));
        lineEditLuks2KeySlot = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2KeySlot->setObjectName(QString::fromUtf8("lineEditLuks2KeySlot"));
        lineEditLuks2KeySlot->setGeometry(QRect(290, 40, 121, 31));
        label_35 = new QLabel(groupBoxLUKS2Options);
        label_35->setObjectName(QString::fromUtf8("label_35"));
        label_35->setGeometry(QRect(10, 210, 271, 51));
        label_35->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_35->setWordWrap(true);
        lineEditLuks2UnlockingTime = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2UnlockingTime->setObjectName(QString::fromUtf8("lineEditLuks2UnlockingTime"));
        lineEditLuks2UnlockingTime->setGeometry(QRect(290, 220, 121, 31));
        label_37 = new QLabel(groupBoxLUKS2Options);
        label_37->setObjectName(QString::fromUtf8("label_37"));
        label_37->setGeometry(QRect(10, 150, 271, 71));
        label_37->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        label_37->setWordWrap(true);
        lineEditLuks2ForcedIteration = new QLineEdit(groupBoxLUKS2Options);
        lineEditLuks2ForcedIteration->setObjectName(QString::fromUtf8("lineEditLuks2ForcedIteration"));
        lineEditLuks2ForcedIteration->setGeometry(QRect(290, 170, 121, 31));
        pbLuks2Cancel = new QPushButton(groupBoxLUKS2Options);
        pbLuks2Cancel->setObjectName(QString::fromUtf8("pbLuks2Cancel"));
        pbLuks2Cancel->setGeometry(QRect(150, 300, 141, 33));
        QWidget::setTabOrder(textEditPathToVolume, pushButtonOpenFile);
        QWidget::setTabOrder(pushButtonOpenFile, pushButtonOpenPartition);
        QWidget::setTabOrder(pushButtonOpenPartition, cbExistingKey);
        QWidget::setTabOrder(cbExistingKey, textEditExistingPassphrase);
        QWidget::setTabOrder(textEditExistingPassphrase, pushButtonOpenExistingKeyFile);
        QWidget::setTabOrder(pushButtonOpenExistingKeyFile, cbVolumeType);
        QWidget::setTabOrder(cbVolumeType, lineEditPIM);
        QWidget::setTabOrder(lineEditPIM, cbNewKey);
        QWidget::setTabOrder(cbNewKey, textEditPassphraseToAdd);
        QWidget::setTabOrder(textEditPassphraseToAdd, pushButtonOpenNewKeyFile);
        QWidget::setTabOrder(pushButtonOpenNewKeyFile, lineEditReEnterPassphrase);
        QWidget::setTabOrder(lineEditReEnterPassphrase, pushButtonAdd);
        QWidget::setTabOrder(pushButtonAdd, pushButtonCancel);

        retranslateUi(luksaddkey);

        pushButtonAdd->setDefault(true);
        pushButtonCancel->setDefault(false);


        QMetaObject::connectSlotsByName(luksaddkey);
    } // setupUi

    void retranslateUi(QDialog *luksaddkey)
    {
        luksaddkey->setWindowTitle(QCoreApplication::translate("luksaddkey", "Add A Key To A Volume", nullptr));
        labelLuksVolume->setText(QCoreApplication::translate("luksaddkey", "Volume Path", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOpenFile->setToolTip(QCoreApplication::translate("luksaddkey", "open file", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenFile->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonOpenPartition->setToolTip(QCoreApplication::translate("luksaddkey", "open partition", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenPartition->setText(QString());
        pushButtonAdd->setText(QCoreApplication::translate("luksaddkey", "&Add", nullptr));
        pushButtonCancel->setText(QCoreApplication::translate("luksaddkey", "&Cancel", nullptr));
        label->setText(QCoreApplication::translate("luksaddkey", "Password Already In The Encrypted Volume", nullptr));
        label_2->setText(QCoreApplication::translate("luksaddkey", " Password To Be Added To The Encrypted Volume", nullptr));
        labelReEnterPassphrase->setText(QCoreApplication::translate("luksaddkey", "Reenter Password", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOpenNewKeyFile->setToolTip(QCoreApplication::translate("luksaddkey", "open keyfile", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenNewKeyFile->setText(QString());
        labelNewPassphrase->setText(QCoreApplication::translate("luksaddkey", "Password", nullptr));
        cbNewKey->setItemText(0, QCoreApplication::translate("luksaddkey", "Password", nullptr));
        cbNewKey->setItemText(1, QCoreApplication::translate("luksaddkey", "KeyFile", nullptr));
        cbNewKey->setItemText(2, QCoreApplication::translate("luksaddkey", "Key+KeyFile", nullptr));
        cbNewKey->setItemText(3, QCoreApplication::translate("luksaddkey", "YubiKey Challenge/Response", nullptr));

        labelExistingPassphrase->setText(QCoreApplication::translate("luksaddkey", "Password", nullptr));
#if QT_CONFIG(tooltip)
        pushButtonOpenExistingKeyFile->setToolTip(QCoreApplication::translate("luksaddkey", "open keyfile", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonOpenExistingKeyFile->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonLuks2AdvancedOptions->setToolTip(QCoreApplication::translate("luksaddkey", "Advanced LUKS2 Options", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonLuks2AdvancedOptions->setText(QString());
        cbExistingKey->setItemText(0, QCoreApplication::translate("luksaddkey", "Password", nullptr));
        cbExistingKey->setItemText(1, QCoreApplication::translate("luksaddkey", "KeyFile", nullptr));
        cbExistingKey->setItemText(2, QCoreApplication::translate("luksaddkey", "Key+KeyFile", nullptr));
        cbExistingKey->setItemText(3, QCoreApplication::translate("luksaddkey", "YubiKey Challenge/Response", nullptr));

        cbVolumeType->setItemText(0, QCoreApplication::translate("luksaddkey", "LUKS", nullptr));
        cbVolumeType->setItemText(1, QCoreApplication::translate("luksaddkey", "TrueCrypt", nullptr));
        cbVolumeType->setItemText(2, QCoreApplication::translate("luksaddkey", "VeraCrypt", nullptr));

        label_3->setText(QCoreApplication::translate("luksaddkey", "Volume Type", nullptr));
        label_4->setText(QCoreApplication::translate("luksaddkey", "PIM", nullptr));
        label_5->setText(QCoreApplication::translate("luksaddkey", "TextLabel", nullptr));
        pushButton->setText(QCoreApplication::translate("luksaddkey", "&OK", nullptr));
        labelAdvanceLuks2Options->setText(QString());
        groupBoxLUKS2Options->setTitle(QString());
        label_9->setText(QCoreApplication::translate("luksaddkey", "Advanced Luks2 Options", nullptr));
        pbLuks2Set->setText(QCoreApplication::translate("luksaddkey", "Set", nullptr));
        label_31->setText(QCoreApplication::translate("luksaddkey", "Key Slot Number To Add Key In", nullptr));
        label_32->setText(QCoreApplication::translate("luksaddkey", "Pbkdf Type", nullptr));
        cbLuks2Pbkdf->setItemText(0, QCoreApplication::translate("luksaddkey", "argon2id", nullptr));
        cbLuks2Pbkdf->setItemText(1, QCoreApplication::translate("luksaddkey", "argon2i", nullptr));
        cbLuks2Pbkdf->setItemText(2, QCoreApplication::translate("luksaddkey", "pbkdf2", nullptr));

        label_33->setText(QCoreApplication::translate("luksaddkey", "Max Memory (KB)", nullptr));
        label_34->setText(QCoreApplication::translate("luksaddkey", "Parallel Threads", nullptr));
        label_35->setText(QCoreApplication::translate("luksaddkey", "Unlocking Time Cost(Milliseconds)", nullptr));
        label_37->setText(QCoreApplication::translate("luksaddkey", "Forced Iterations\n"
"(Dangerous And Could Lead To Extremely Long Unlocking Time)", nullptr));
        pbLuks2Cancel->setText(QCoreApplication::translate("luksaddkey", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class luksaddkey: public Ui_luksaddkey {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_LUKSADDKEY_H
