/********************************************************************************
** Form generated from reading UI file 'managesystemvolumes.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_MANAGESYSTEMVOLUMES_H
#define UI_MANAGESYSTEMVOLUMES_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>

QT_BEGIN_NAMESPACE

class Ui_manageSystemVolumes
{
public:
    QPushButton *pbDone;
    QPushButton *pbFile;
    QPushButton *pbPartition;
    QTableWidget *tableWidget;

    void setupUi(QDialog *manageSystemVolumes)
    {
        if (manageSystemVolumes->objectName().isEmpty())
            manageSystemVolumes->setObjectName(QString::fromUtf8("manageSystemVolumes"));
        manageSystemVolumes->setWindowModality(Qt::ApplicationModal);
        manageSystemVolumes->resize(631, 312);
        manageSystemVolumes->setModal(true);
        pbDone = new QPushButton(manageSystemVolumes);
        pbDone->setObjectName(QString::fromUtf8("pbDone"));
        pbDone->setGeometry(QRect(250, 280, 131, 31));
        pbDone->setAutoDefault(false);
        pbFile = new QPushButton(manageSystemVolumes);
        pbFile->setObjectName(QString::fromUtf8("pbFile"));
        pbFile->setGeometry(QRect(380, 280, 151, 31));
        pbFile->setAutoDefault(false);
        pbPartition = new QPushButton(manageSystemVolumes);
        pbPartition->setObjectName(QString::fromUtf8("pbPartition"));
        pbPartition->setGeometry(QRect(100, 280, 151, 31));
        pbPartition->setAutoDefault(false);
        tableWidget = new QTableWidget(manageSystemVolumes);
        if (tableWidget->columnCount() < 1)
            tableWidget->setColumnCount(1);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setGeometry(QRect(10, 10, 611, 271));
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setProperty("showDropIndicator", QVariant(false));
        tableWidget->setDragDropOverwriteMode(false);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget->setShowGrid(false);
        tableWidget->setGridStyle(Qt::NoPen);

        retranslateUi(manageSystemVolumes);

        pbDone->setDefault(false);
        pbFile->setDefault(false);
        pbPartition->setDefault(false);


        QMetaObject::connectSlotsByName(manageSystemVolumes);
    } // setupUi

    void retranslateUi(QDialog *manageSystemVolumes)
    {
        manageSystemVolumes->setWindowTitle(QCoreApplication::translate("manageSystemVolumes", "Manage System Volumes", nullptr));
        pbDone->setText(QCoreApplication::translate("manageSystemVolumes", "&Done", nullptr));
        pbFile->setText(QCoreApplication::translate("manageSystemVolumes", "Add Fi&le", nullptr));
        pbPartition->setText(QCoreApplication::translate("manageSystemVolumes", "Add Dev&ice", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("manageSystemVolumes", "Path To System Volumes", nullptr));
    } // retranslateUi

};

namespace Ui {
    class manageSystemVolumes: public Ui_manageSystemVolumes {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_MANAGESYSTEMVOLUMES_H
