/********************************************************************************
** Form generated from reading UI file 'password.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_PASSWORD_H
#define UI_PASSWORD_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QFrame>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_PasswordDialog
{
public:
    QPushButton *PushButtonOptions;
    QPushButton *PushButtonOpen;
    QPushButton *PushButtonCancel;
    QCheckBox *checkBoxReadOnly;
    QPushButton *PushButtonMountPointPath;
    QPushButton *PushButtonVolumePath;
    QLineEdit *PassPhraseField;
    QPushButton *pushButtonPassPhraseFromFile;
    QLineEdit *OpenVolumePath;
    QLineEdit *MountPointPath;
    QLabel *labelPassphrase;
    QLabel *labelMoutPointPath;
    QLabel *labelVolumePath;
    QPushButton *pbKeyOption;
    QComboBox *cbKeyType;
    QCheckBox *cbShareMountPoint;
    QComboBox *cbVolumeType;
    QLabel *labelVolumeType;
    QPushButton *pushButtonPlainDmCryptOptions;
    QPushButton *pushButtonLuksExternalHeaderPath;
    QLineEdit *lineEditVolumeProperty;
    QLabel *labelVolumeProperty;
    QCheckBox *checkBoxVisibleKey;
    QLabel *veraCryptWarning;
    QPushButton *pbOK;
    QFrame *frameOptions;
    QLabel *label;
    QLineEdit *lineEditFsOptions;
    QPushButton *pbSet;
    QPushButton *pbCancel;

    void setupUi(QDialog *PasswordDialog)
    {
        if (PasswordDialog->objectName().isEmpty())
            PasswordDialog->setObjectName(QString::fromUtf8("PasswordDialog"));
        PasswordDialog->setWindowModality(Qt::ApplicationModal);
        PasswordDialog->resize(581, 279);
        QFont font;
        font.setBold(false);
        font.setWeight(50);
        PasswordDialog->setFont(font);
        PasswordDialog->setFocusPolicy(Qt::TabFocus);
        PasswordDialog->setAcceptDrops(true);
        PasswordDialog->setModal(true);
        PushButtonOptions = new QPushButton(PasswordDialog);
        PushButtonOptions->setObjectName(QString::fromUtf8("PushButtonOptions"));
        PushButtonOptions->setGeometry(QRect(120, 240, 111, 31));
        PushButtonOptions->setAutoDefault(true);
        PushButtonOpen = new QPushButton(PasswordDialog);
        PushButtonOpen->setObjectName(QString::fromUtf8("PushButtonOpen"));
        PushButtonOpen->setGeometry(QRect(230, 240, 121, 31));
        PushButtonOpen->setAutoDefault(true);
        PushButtonCancel = new QPushButton(PasswordDialog);
        PushButtonCancel->setObjectName(QString::fromUtf8("PushButtonCancel"));
        PushButtonCancel->setGeometry(QRect(350, 240, 111, 31));
        PushButtonCancel->setAutoDefault(true);
        checkBoxReadOnly = new QCheckBox(PasswordDialog);
        checkBoxReadOnly->setObjectName(QString::fromUtf8("checkBoxReadOnly"));
        checkBoxReadOnly->setGeometry(QRect(140, 70, 331, 31));
        checkBoxReadOnly->setChecked(false);
        PushButtonMountPointPath = new QPushButton(PasswordDialog);
        PushButtonMountPointPath->setObjectName(QString::fromUtf8("PushButtonMountPointPath"));
        PushButtonMountPointPath->setGeometry(QRect(440, 40, 31, 31));
        PushButtonMountPointPath->setAutoDefault(true);
        PushButtonVolumePath = new QPushButton(PasswordDialog);
        PushButtonVolumePath->setObjectName(QString::fromUtf8("PushButtonVolumePath"));
        PushButtonVolumePath->setGeometry(QRect(440, 10, 31, 31));
        PushButtonVolumePath->setAutoDefault(true);
        PushButtonVolumePath->setFlat(false);
        PassPhraseField = new QLineEdit(PasswordDialog);
        PassPhraseField->setObjectName(QString::fromUtf8("PassPhraseField"));
        PassPhraseField->setGeometry(QRect(140, 210, 301, 31));
        PassPhraseField->setMaxLength(100);
        PassPhraseField->setEchoMode(QLineEdit::Password);
        pushButtonPassPhraseFromFile = new QPushButton(PasswordDialog);
        pushButtonPassPhraseFromFile->setObjectName(QString::fromUtf8("pushButtonPassPhraseFromFile"));
        pushButtonPassPhraseFromFile->setGeometry(QRect(470, 210, 31, 31));
        pushButtonPassPhraseFromFile->setAutoDefault(true);
        OpenVolumePath = new QLineEdit(PasswordDialog);
        OpenVolumePath->setObjectName(QString::fromUtf8("OpenVolumePath"));
        OpenVolumePath->setGeometry(QRect(140, 10, 301, 31));
        MountPointPath = new QLineEdit(PasswordDialog);
        MountPointPath->setObjectName(QString::fromUtf8("MountPointPath"));
        MountPointPath->setGeometry(QRect(140, 40, 301, 31));
        labelPassphrase = new QLabel(PasswordDialog);
        labelPassphrase->setObjectName(QString::fromUtf8("labelPassphrase"));
        labelPassphrase->setGeometry(QRect(0, 210, 131, 31));
        labelPassphrase->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelPassphrase->setWordWrap(true);
        labelMoutPointPath = new QLabel(PasswordDialog);
        labelMoutPointPath->setObjectName(QString::fromUtf8("labelMoutPointPath"));
        labelMoutPointPath->setGeometry(QRect(10, 40, 121, 31));
        labelMoutPointPath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelMoutPointPath->setWordWrap(true);
        labelVolumePath = new QLabel(PasswordDialog);
        labelVolumePath->setObjectName(QString::fromUtf8("labelVolumePath"));
        labelVolumePath->setGeometry(QRect(10, 10, 121, 31));
        labelVolumePath->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumePath->setWordWrap(true);
        pbKeyOption = new QPushButton(PasswordDialog);
        pbKeyOption->setObjectName(QString::fromUtf8("pbKeyOption"));
        pbKeyOption->setGeometry(QRect(440, 210, 31, 31));
        cbKeyType = new QComboBox(PasswordDialog);
        cbKeyType->addItem(QString());
        cbKeyType->addItem(QString());
        cbKeyType->addItem(QString());
        cbKeyType->addItem(QString());
        cbKeyType->setObjectName(QString::fromUtf8("cbKeyType"));
        cbKeyType->setGeometry(QRect(140, 180, 301, 31));
        cbShareMountPoint = new QCheckBox(PasswordDialog);
        cbShareMountPoint->setObjectName(QString::fromUtf8("cbShareMountPoint"));
        cbShareMountPoint->setGeometry(QRect(140, 90, 301, 41));
        cbVolumeType = new QComboBox(PasswordDialog);
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->addItem(QString());
        cbVolumeType->setObjectName(QString::fromUtf8("cbVolumeType"));
        cbVolumeType->setGeometry(QRect(140, 120, 301, 31));
        labelVolumeType = new QLabel(PasswordDialog);
        labelVolumeType->setObjectName(QString::fromUtf8("labelVolumeType"));
        labelVolumeType->setGeometry(QRect(10, 120, 121, 31));
        labelVolumeType->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumeType->setWordWrap(true);
        pushButtonPlainDmCryptOptions = new QPushButton(PasswordDialog);
        pushButtonPlainDmCryptOptions->setObjectName(QString::fromUtf8("pushButtonPlainDmCryptOptions"));
        pushButtonPlainDmCryptOptions->setGeometry(QRect(440, 120, 31, 31));
        pushButtonLuksExternalHeaderPath = new QPushButton(PasswordDialog);
        pushButtonLuksExternalHeaderPath->setObjectName(QString::fromUtf8("pushButtonLuksExternalHeaderPath"));
        pushButtonLuksExternalHeaderPath->setGeometry(QRect(440, 150, 31, 31));
        lineEditVolumeProperty = new QLineEdit(PasswordDialog);
        lineEditVolumeProperty->setObjectName(QString::fromUtf8("lineEditVolumeProperty"));
        lineEditVolumeProperty->setGeometry(QRect(140, 150, 301, 29));
        lineEditVolumeProperty->setEchoMode(QLineEdit::Password);
        labelVolumeProperty = new QLabel(PasswordDialog);
        labelVolumeProperty->setObjectName(QString::fromUtf8("labelVolumeProperty"));
        labelVolumeProperty->setGeometry(QRect(10, 150, 121, 31));
        labelVolumeProperty->setAlignment(Qt::AlignRight|Qt::AlignTrailing|Qt::AlignVCenter);
        labelVolumeProperty->setWordWrap(true);
        checkBoxVisibleKey = new QCheckBox(PasswordDialog);
        checkBoxVisibleKey->setObjectName(QString::fromUtf8("checkBoxVisibleKey"));
        checkBoxVisibleKey->setGeometry(QRect(440, 180, 31, 31));
        veraCryptWarning = new QLabel(PasswordDialog);
        veraCryptWarning->setObjectName(QString::fromUtf8("veraCryptWarning"));
        veraCryptWarning->setGeometry(QRect(0, -10, 581, 281));
        veraCryptWarning->setAutoFillBackground(true);
        veraCryptWarning->setFrameShadow(QFrame::Raised);
        veraCryptWarning->setScaledContents(false);
        veraCryptWarning->setAlignment(Qt::AlignCenter);
        veraCryptWarning->setWordWrap(true);
        pbOK = new QPushButton(PasswordDialog);
        pbOK->setObjectName(QString::fromUtf8("pbOK"));
        pbOK->setGeometry(QRect(230, 230, 121, 33));
        frameOptions = new QFrame(PasswordDialog);
        frameOptions->setObjectName(QString::fromUtf8("frameOptions"));
        frameOptions->setGeometry(QRect(10, 10, 561, 261));
        frameOptions->setAutoFillBackground(true);
        frameOptions->setFrameShape(QFrame::StyledPanel);
        frameOptions->setFrameShadow(QFrame::Raised);
        label = new QLabel(frameOptions);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(60, 129, 441, 41));
        label->setAlignment(Qt::AlignCenter);
        lineEditFsOptions = new QLineEdit(frameOptions);
        lineEditFsOptions->setObjectName(QString::fromUtf8("lineEditFsOptions"));
        lineEditFsOptions->setGeometry(QRect(60, 170, 441, 31));
        pbSet = new QPushButton(frameOptions);
        pbSet->setObjectName(QString::fromUtf8("pbSet"));
        pbSet->setGeometry(QRect(170, 200, 111, 33));
        pbCancel = new QPushButton(frameOptions);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(280, 200, 111, 33));
        QWidget::setTabOrder(OpenVolumePath, PushButtonVolumePath);
        QWidget::setTabOrder(PushButtonVolumePath, MountPointPath);
        QWidget::setTabOrder(MountPointPath, PushButtonMountPointPath);
        QWidget::setTabOrder(PushButtonMountPointPath, checkBoxReadOnly);
        QWidget::setTabOrder(checkBoxReadOnly, cbShareMountPoint);
        QWidget::setTabOrder(cbShareMountPoint, cbVolumeType);
        QWidget::setTabOrder(cbVolumeType, pushButtonPlainDmCryptOptions);
        QWidget::setTabOrder(pushButtonPlainDmCryptOptions, lineEditVolumeProperty);
        QWidget::setTabOrder(lineEditVolumeProperty, cbKeyType);
        QWidget::setTabOrder(cbKeyType, checkBoxVisibleKey);
        QWidget::setTabOrder(checkBoxVisibleKey, PassPhraseField);
        QWidget::setTabOrder(PassPhraseField, pbKeyOption);
        QWidget::setTabOrder(pbKeyOption, pushButtonPassPhraseFromFile);
        QWidget::setTabOrder(pushButtonPassPhraseFromFile, PushButtonOpen);
        QWidget::setTabOrder(PushButtonOpen, PushButtonCancel);

        retranslateUi(PasswordDialog);

        PushButtonOptions->setDefault(false);
        PushButtonOpen->setDefault(true);
        PushButtonCancel->setDefault(false);


        QMetaObject::connectSlotsByName(PasswordDialog);
    } // setupUi

    void retranslateUi(QDialog *PasswordDialog)
    {
        PasswordDialog->setWindowTitle(QCoreApplication::translate("PasswordDialog", "Open Encrypted Volume", nullptr));
        PushButtonOptions->setText(QCoreApplication::translate("PasswordDialog", "&Options", nullptr));
        PushButtonOpen->setText(QCoreApplication::translate("PasswordDialog", "&Open", nullptr));
        PushButtonCancel->setText(QCoreApplication::translate("PasswordDialog", "&Cancel", nullptr));
        checkBoxReadOnly->setText(QCoreApplication::translate("PasswordDialog", "Mount In &Read Only Mode", nullptr));
#if QT_CONFIG(tooltip)
        PushButtonMountPointPath->setToolTip(QCoreApplication::translate("PasswordDialog", "select mount point path", nullptr));
#endif // QT_CONFIG(tooltip)
        PushButtonMountPointPath->setText(QString());
#if QT_CONFIG(tooltip)
        PushButtonVolumePath->setToolTip(QCoreApplication::translate("PasswordDialog", "open volume path", nullptr));
#endif // QT_CONFIG(tooltip)
        PushButtonVolumePath->setText(QString());
#if QT_CONFIG(tooltip)
        pushButtonPassPhraseFromFile->setToolTip(QCoreApplication::translate("PasswordDialog", "open key file", nullptr));
#endif // QT_CONFIG(tooltip)
        pushButtonPassPhraseFromFile->setText(QString());
        labelPassphrase->setText(QCoreApplication::translate("PasswordDialog", "Password", nullptr));
        labelMoutPointPath->setText(QCoreApplication::translate("PasswordDialog", "Mount Name", nullptr));
        labelVolumePath->setText(QCoreApplication::translate("PasswordDialog", "Volume Path", nullptr));
        pbKeyOption->setText(QString());
        cbKeyType->setItemText(0, QCoreApplication::translate("PasswordDialog", "Password", nullptr));
        cbKeyType->setItemText(1, QCoreApplication::translate("PasswordDialog", "KeyFile", nullptr));
        cbKeyType->setItemText(2, QCoreApplication::translate("PasswordDialog", "Key+KeyFile", nullptr));
        cbKeyType->setItemText(3, QCoreApplication::translate("PasswordDialog", "Plugin", nullptr));

        cbShareMountPoint->setText(QCoreApplication::translate("PasswordDialog", "&Share Mount Point", nullptr));
        cbVolumeType->setItemText(0, QCoreApplication::translate("PasswordDialog", "LUKS/TrueCrypt/BitLocker", nullptr));
        cbVolumeType->setItemText(1, QCoreApplication::translate("PasswordDialog", "VeraCrypt", nullptr));
        cbVolumeType->setItemText(2, QCoreApplication::translate("PasswordDialog", "VeraCrypt System", nullptr));
        cbVolumeType->setItemText(3, QCoreApplication::translate("PasswordDialog", "PLAIN dm-crypt", nullptr));

        labelVolumeType->setText(QCoreApplication::translate("PasswordDialog", "Volume Type", nullptr));
        pushButtonPlainDmCryptOptions->setText(QString());
        pushButtonLuksExternalHeaderPath->setText(QString());
        labelVolumeProperty->setText(QString());
        checkBoxVisibleKey->setText(QString());
        veraCryptWarning->setText(QCoreApplication::translate("PasswordDialog", "TextLabel", nullptr));
        pbOK->setText(QCoreApplication::translate("PasswordDialog", "&OK", nullptr));
        label->setText(QCoreApplication::translate("PasswordDialog", "Enter Comma Separated Volume's File System Options Below", nullptr));
        pbSet->setText(QCoreApplication::translate("PasswordDialog", "Set", nullptr));
        pbCancel->setText(QCoreApplication::translate("PasswordDialog", "Cancel", nullptr));
    } // retranslateUi

};

namespace Ui {
    class PasswordDialog: public Ui_PasswordDialog {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_PASSWORD_H
