/********************************************************************************
** Form generated from reading UI file 'cryptoinfo.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CRYPTOINFO_H
#define UI_CRYPTOINFO_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_cryptoinfo
{
public:
    QPushButton *pbOK;
    QLabel *label;
    QCheckBox *checkBox;

    void setupUi(QWidget *cryptoinfo)
    {
        if (cryptoinfo->objectName().isEmpty())
            cryptoinfo->setObjectName(QString::fromUtf8("cryptoinfo"));
        cryptoinfo->setWindowModality(Qt::ApplicationModal);
        cryptoinfo->resize(553, 292);
        pbOK = new QPushButton(cryptoinfo);
        pbOK->setObjectName(QString::fromUtf8("pbOK"));
        pbOK->setGeometry(QRect(230, 260, 101, 31));
        label = new QLabel(cryptoinfo);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(20, 0, 511, 221));
        label->setTextFormat(Qt::PlainText);
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        checkBox = new QCheckBox(cryptoinfo);
        checkBox->setObjectName(QString::fromUtf8("checkBox"));
        checkBox->setGeometry(QRect(150, 220, 391, 41));

        retranslateUi(cryptoinfo);

        QMetaObject::connectSlotsByName(cryptoinfo);
    } // setupUi

    void retranslateUi(QWidget *cryptoinfo)
    {
        cryptoinfo->setWindowTitle(QCoreApplication::translate("cryptoinfo", "Greetings", nullptr));
        pbOK->setText(QCoreApplication::translate("cryptoinfo", "Ok", nullptr));
        label->setText(QCoreApplication::translate("cryptoinfo", "Please consult \"menu->help->open zuluCrypt.pdf\" to get an introduction on zuluCrypt.\n"
"\n"
"Unity users,the menu is on the upper left corner of the screen when zuluCrypt has focus.\n"
"\n"
"Project's homepage is at:\n"
"https://mhogomchungu.github.io/zuluCrypt\n"
"\n"
"Recommending reading FAQ page from the project's main page.", nullptr));
        checkBox->setText(QCoreApplication::translate("cryptoinfo", "Do not show this message again.", nullptr));
    } // retranslateUi

};

namespace Ui {
    class cryptoinfo: public Ui_cryptoinfo {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_CRYPTOINFO_H
