/********************************************************************************
** Form generated from reading UI file 'openvolume.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_OPENVOLUME_H
#define UI_OPENVOLUME_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QDialog>
#include <QtWidgets/QGroupBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QPushButton>
#include <QtWidgets/QTableWidget>

QT_BEGIN_NAMESPACE

class Ui_openvolume
{
public:
    QCheckBox *checkBoxUUID;
    QPushButton *pbHelp;
    QPushButton *pbUUID;
    QPushButton *pbCancel;
    QGroupBox *groupBox;
    QTableWidget *tableWidget;
    QPushButton *pbOpen;

    void setupUi(QDialog *openvolume)
    {
        if (openvolume->objectName().isEmpty())
            openvolume->setObjectName(QString::fromUtf8("openvolume"));
        openvolume->setWindowModality(Qt::ApplicationModal);
        openvolume->resize(751, 383);
        openvolume->setModal(true);
        checkBoxUUID = new QCheckBox(openvolume);
        checkBoxUUID->setObjectName(QString::fromUtf8("checkBoxUUID"));
        checkBoxUUID->setEnabled(true);
        checkBoxUUID->setGeometry(QRect(650, 350, 71, 31));
        pbHelp = new QPushButton(openvolume);
        pbHelp->setObjectName(QString::fromUtf8("pbHelp"));
        pbHelp->setGeometry(QRect(10, 350, 121, 31));
        pbHelp->setAutoDefault(false);
        pbUUID = new QPushButton(openvolume);
        pbUUID->setObjectName(QString::fromUtf8("pbUUID"));
        pbUUID->setGeometry(QRect(310, 350, 131, 31));
        pbUUID->setAutoDefault(false);
        pbCancel = new QPushButton(openvolume);
        pbCancel->setObjectName(QString::fromUtf8("pbCancel"));
        pbCancel->setGeometry(QRect(440, 350, 131, 31));
        pbCancel->setAutoDefault(false);
        groupBox = new QGroupBox(openvolume);
        groupBox->setObjectName(QString::fromUtf8("groupBox"));
        groupBox->setGeometry(QRect(10, 10, 731, 341));
        tableWidget = new QTableWidget(groupBox);
        if (tableWidget->columnCount() < 5)
            tableWidget->setColumnCount(5);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        __qtablewidgetitem->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        __qtablewidgetitem1->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        __qtablewidgetitem2->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        QTableWidgetItem *__qtablewidgetitem3 = new QTableWidgetItem();
        __qtablewidgetitem3->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(3, __qtablewidgetitem3);
        QTableWidgetItem *__qtablewidgetitem4 = new QTableWidgetItem();
        __qtablewidgetitem4->setTextAlignment(Qt::AlignCenter);
        tableWidget->setHorizontalHeaderItem(4, __qtablewidgetitem4);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setGeometry(QRect(10, 30, 711, 301));
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setTabKeyNavigation(false);
        tableWidget->setProperty("showDropIndicator", QVariant(false));
        tableWidget->setDragDropOverwriteMode(false);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget->setShowGrid(false);
        tableWidget->setColumnCount(5);
        tableWidget->horizontalHeader()->setVisible(false);
        tableWidget->verticalHeader()->setVisible(false);
        pbOpen = new QPushButton(openvolume);
        pbOpen->setObjectName(QString::fromUtf8("pbOpen"));
        pbOpen->setGeometry(QRect(180, 350, 131, 31));
        QWidget::setTabOrder(tableWidget, checkBoxUUID);

        retranslateUi(openvolume);

        pbCancel->setDefault(false);


        QMetaObject::connectSlotsByName(openvolume);
    } // setupUi

    void retranslateUi(QDialog *openvolume)
    {
        openvolume->setWindowTitle(QCoreApplication::translate("openvolume", "Select A Partition To Open", nullptr));
        checkBoxUUID->setText(QCoreApplication::translate("openvolume", "Use UUID", nullptr));
        pbHelp->setText(QCoreApplication::translate("openvolume", "&Help", nullptr));
        pbUUID->setText(QCoreApplication::translate("openvolume", "Use &UUID", nullptr));
        pbCancel->setText(QCoreApplication::translate("openvolume", "&Cancel", nullptr));
        groupBox->setTitle(QString());
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("openvolume", "partition", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("openvolume", "size", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("openvolume", "label", nullptr));
        QTableWidgetItem *___qtablewidgetitem3 = tableWidget->horizontalHeaderItem(3);
        ___qtablewidgetitem3->setText(QCoreApplication::translate("openvolume", "type", nullptr));
        QTableWidgetItem *___qtablewidgetitem4 = tableWidget->horizontalHeaderItem(4);
        ___qtablewidgetitem4->setText(QCoreApplication::translate("openvolume", "uuid", nullptr));
        pbOpen->setText(QCoreApplication::translate("openvolume", "&Open", nullptr));
    } // retranslateUi

};

namespace Ui {
    class openvolume: public Ui_openvolume {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_OPENVOLUME_H
