/********************************************************************************
** Form generated from reading UI file 'zulucrypt.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_ZULUCRYPT_H
#define UI_ZULUCRYPT_H

#include <QtCore/QVariant>
#include <QtGui/QIcon>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QMainWindow>
#include <QtWidgets/QMenu>
#include <QtWidgets/QMenuBar>
#include <QtWidgets/QTableWidget>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_zuluCrypt
{
public:
    QAction *actionFileOpen;
    QAction *actionPartitionOpen;
    QAction *actionFileCreate;
    QAction *actionPartitionCreate;
    QAction *actionAbout;
    QAction *actionAddKey;
    QAction *actionDeleteKey;
    QAction *actionInfo;
    QAction *actionCreatekeyFile;
    QAction *actionTray_icon;
    QAction *actionFonts;
    QAction *actionFavorite_volumes;
    QAction *actionManage_favorites;
    QAction *actionSelect_random_number_generator;
    QAction *actionClose_application;
    QAction *action_update_volume_list;
    QAction *actionMinimize_to_tray;
    QAction *action_close;
    QAction *actionClose_all_opened_volumes;
    QAction *actionManage_names;
    QAction *actionErase_data_on_device;
    QAction *actionBackup_header;
    QAction *actionRestore_header;
    QAction *actionPermission_problems;
    QAction *actionEncrypt_file;
    QAction *actionDecrypt_file;
    QAction *actionLuks_header_backup;
    QAction *actionManage_system_partitions;
    QAction *actionManage_volumes_in_internal_wallet;
    QAction *actionUse_kde_default_wallet;
    QAction *actionManage_non_system_partitions;
    QAction *actionManage_volumes_in_kde_wallet;
    QAction *actionManage_volumes_in_gnome_wallet;
    QAction *actionChange_internal_wallet_password;
    QAction *actionTcrypt_backup_header;
    QAction *actionTcrypt_restore_header;
    QAction *actionVeracrypt_container_in_a_file;
    QAction *actionVeracrypt_container_in_a_partition;
    QAction *actionOpen_zuluCrypt_pdf;
    QAction *actionContact_Info;
    QAction *actionSelect_Language;
    QAction *actionAuto_Open_Mount_Point;
    QAction *actionSelect_Icons;
    QAction *actionSet_File_Manager;
    QAction *actionDo_not_minimize_to_tray;
    QAction *actionEncrypted_Container_In_An_Existing_FIle;
    QAction *actionShow_Debug_Window;
    QAction *actionEncrypted_Container_In_A_File;
    QAction *actionClear_Dead_Mount_Points;
    QAction *actionView_LUKS_Key_Slots;
    QWidget *centralWidget;
    QVBoxLayout *verticalLayout;
    QTableWidget *tableWidget;
    QMenuBar *menuBar;
    QMenu *menuOpen;
    QMenu *menuCreate;
    QMenu *menuHelp;
    QMenu *menuConfigure;
    QMenu *menuOptions;
    QMenu *menuFavorites;
    QMenu *menu_zc;

    void setupUi(QMainWindow *zuluCrypt)
    {
        if (zuluCrypt->objectName().isEmpty())
            zuluCrypt->setObjectName(QString::fromUtf8("zuluCrypt"));
        zuluCrypt->setWindowModality(Qt::NonModal);
        zuluCrypt->setEnabled(true);
        zuluCrypt->resize(782, 419);
        QIcon icon;
        icon.addFile(QString::fromUtf8("zuluCrypt.png"), QSize(), QIcon::Normal, QIcon::Off);
        zuluCrypt->setWindowIcon(icon);
        actionFileOpen = new QAction(zuluCrypt);
        actionFileOpen->setObjectName(QString::fromUtf8("actionFileOpen"));
        actionPartitionOpen = new QAction(zuluCrypt);
        actionPartitionOpen->setObjectName(QString::fromUtf8("actionPartitionOpen"));
        actionFileCreate = new QAction(zuluCrypt);
        actionFileCreate->setObjectName(QString::fromUtf8("actionFileCreate"));
        actionFileCreate->setEnabled(true);
        actionFileCreate->setVisible(true);
        actionPartitionCreate = new QAction(zuluCrypt);
        actionPartitionCreate->setObjectName(QString::fromUtf8("actionPartitionCreate"));
        actionPartitionCreate->setEnabled(true);
        actionPartitionCreate->setVisible(true);
        actionAbout = new QAction(zuluCrypt);
        actionAbout->setObjectName(QString::fromUtf8("actionAbout"));
        actionAddKey = new QAction(zuluCrypt);
        actionAddKey->setObjectName(QString::fromUtf8("actionAddKey"));
        actionDeleteKey = new QAction(zuluCrypt);
        actionDeleteKey->setObjectName(QString::fromUtf8("actionDeleteKey"));
        actionInfo = new QAction(zuluCrypt);
        actionInfo->setObjectName(QString::fromUtf8("actionInfo"));
        actionCreatekeyFile = new QAction(zuluCrypt);
        actionCreatekeyFile->setObjectName(QString::fromUtf8("actionCreatekeyFile"));
        actionTray_icon = new QAction(zuluCrypt);
        actionTray_icon->setObjectName(QString::fromUtf8("actionTray_icon"));
        actionFonts = new QAction(zuluCrypt);
        actionFonts->setObjectName(QString::fromUtf8("actionFonts"));
        actionFavorite_volumes = new QAction(zuluCrypt);
        actionFavorite_volumes->setObjectName(QString::fromUtf8("actionFavorite_volumes"));
        actionManage_favorites = new QAction(zuluCrypt);
        actionManage_favorites->setObjectName(QString::fromUtf8("actionManage_favorites"));
        actionSelect_random_number_generator = new QAction(zuluCrypt);
        actionSelect_random_number_generator->setObjectName(QString::fromUtf8("actionSelect_random_number_generator"));
        actionClose_application = new QAction(zuluCrypt);
        actionClose_application->setObjectName(QString::fromUtf8("actionClose_application"));
        action_update_volume_list = new QAction(zuluCrypt);
        action_update_volume_list->setObjectName(QString::fromUtf8("action_update_volume_list"));
        actionMinimize_to_tray = new QAction(zuluCrypt);
        actionMinimize_to_tray->setObjectName(QString::fromUtf8("actionMinimize_to_tray"));
        action_close = new QAction(zuluCrypt);
        action_close->setObjectName(QString::fromUtf8("action_close"));
        actionClose_all_opened_volumes = new QAction(zuluCrypt);
        actionClose_all_opened_volumes->setObjectName(QString::fromUtf8("actionClose_all_opened_volumes"));
        actionManage_names = new QAction(zuluCrypt);
        actionManage_names->setObjectName(QString::fromUtf8("actionManage_names"));
        actionErase_data_on_device = new QAction(zuluCrypt);
        actionErase_data_on_device->setObjectName(QString::fromUtf8("actionErase_data_on_device"));
        actionBackup_header = new QAction(zuluCrypt);
        actionBackup_header->setObjectName(QString::fromUtf8("actionBackup_header"));
        actionRestore_header = new QAction(zuluCrypt);
        actionRestore_header->setObjectName(QString::fromUtf8("actionRestore_header"));
        actionPermission_problems = new QAction(zuluCrypt);
        actionPermission_problems->setObjectName(QString::fromUtf8("actionPermission_problems"));
        actionEncrypt_file = new QAction(zuluCrypt);
        actionEncrypt_file->setObjectName(QString::fromUtf8("actionEncrypt_file"));
        actionDecrypt_file = new QAction(zuluCrypt);
        actionDecrypt_file->setObjectName(QString::fromUtf8("actionDecrypt_file"));
        actionLuks_header_backup = new QAction(zuluCrypt);
        actionLuks_header_backup->setObjectName(QString::fromUtf8("actionLuks_header_backup"));
        actionManage_system_partitions = new QAction(zuluCrypt);
        actionManage_system_partitions->setObjectName(QString::fromUtf8("actionManage_system_partitions"));
        actionManage_volumes_in_internal_wallet = new QAction(zuluCrypt);
        actionManage_volumes_in_internal_wallet->setObjectName(QString::fromUtf8("actionManage_volumes_in_internal_wallet"));
        actionUse_kde_default_wallet = new QAction(zuluCrypt);
        actionUse_kde_default_wallet->setObjectName(QString::fromUtf8("actionUse_kde_default_wallet"));
        actionManage_non_system_partitions = new QAction(zuluCrypt);
        actionManage_non_system_partitions->setObjectName(QString::fromUtf8("actionManage_non_system_partitions"));
        actionManage_volumes_in_kde_wallet = new QAction(zuluCrypt);
        actionManage_volumes_in_kde_wallet->setObjectName(QString::fromUtf8("actionManage_volumes_in_kde_wallet"));
        actionManage_volumes_in_gnome_wallet = new QAction(zuluCrypt);
        actionManage_volumes_in_gnome_wallet->setObjectName(QString::fromUtf8("actionManage_volumes_in_gnome_wallet"));
        actionChange_internal_wallet_password = new QAction(zuluCrypt);
        actionChange_internal_wallet_password->setObjectName(QString::fromUtf8("actionChange_internal_wallet_password"));
        actionTcrypt_backup_header = new QAction(zuluCrypt);
        actionTcrypt_backup_header->setObjectName(QString::fromUtf8("actionTcrypt_backup_header"));
        actionTcrypt_restore_header = new QAction(zuluCrypt);
        actionTcrypt_restore_header->setObjectName(QString::fromUtf8("actionTcrypt_restore_header"));
        actionVeracrypt_container_in_a_file = new QAction(zuluCrypt);
        actionVeracrypt_container_in_a_file->setObjectName(QString::fromUtf8("actionVeracrypt_container_in_a_file"));
        actionVeracrypt_container_in_a_partition = new QAction(zuluCrypt);
        actionVeracrypt_container_in_a_partition->setObjectName(QString::fromUtf8("actionVeracrypt_container_in_a_partition"));
        actionOpen_zuluCrypt_pdf = new QAction(zuluCrypt);
        actionOpen_zuluCrypt_pdf->setObjectName(QString::fromUtf8("actionOpen_zuluCrypt_pdf"));
        actionContact_Info = new QAction(zuluCrypt);
        actionContact_Info->setObjectName(QString::fromUtf8("actionContact_Info"));
        actionSelect_Language = new QAction(zuluCrypt);
        actionSelect_Language->setObjectName(QString::fromUtf8("actionSelect_Language"));
        actionAuto_Open_Mount_Point = new QAction(zuluCrypt);
        actionAuto_Open_Mount_Point->setObjectName(QString::fromUtf8("actionAuto_Open_Mount_Point"));
        actionSelect_Icons = new QAction(zuluCrypt);
        actionSelect_Icons->setObjectName(QString::fromUtf8("actionSelect_Icons"));
        actionSet_File_Manager = new QAction(zuluCrypt);
        actionSet_File_Manager->setObjectName(QString::fromUtf8("actionSet_File_Manager"));
        actionDo_not_minimize_to_tray = new QAction(zuluCrypt);
        actionDo_not_minimize_to_tray->setObjectName(QString::fromUtf8("actionDo_not_minimize_to_tray"));
        actionDo_not_minimize_to_tray->setCheckable(true);
        actionEncrypted_Container_In_An_Existing_FIle = new QAction(zuluCrypt);
        actionEncrypted_Container_In_An_Existing_FIle->setObjectName(QString::fromUtf8("actionEncrypted_Container_In_An_Existing_FIle"));
        actionShow_Debug_Window = new QAction(zuluCrypt);
        actionShow_Debug_Window->setObjectName(QString::fromUtf8("actionShow_Debug_Window"));
        actionEncrypted_Container_In_A_File = new QAction(zuluCrypt);
        actionEncrypted_Container_In_A_File->setObjectName(QString::fromUtf8("actionEncrypted_Container_In_A_File"));
        actionClear_Dead_Mount_Points = new QAction(zuluCrypt);
        actionClear_Dead_Mount_Points->setObjectName(QString::fromUtf8("actionClear_Dead_Mount_Points"));
        actionView_LUKS_Key_Slots = new QAction(zuluCrypt);
        actionView_LUKS_Key_Slots->setObjectName(QString::fromUtf8("actionView_LUKS_Key_Slots"));
        centralWidget = new QWidget(zuluCrypt);
        centralWidget->setObjectName(QString::fromUtf8("centralWidget"));
        centralWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
        verticalLayout = new QVBoxLayout(centralWidget);
        verticalLayout->setSpacing(6);
        verticalLayout->setContentsMargins(11, 11, 11, 11);
        verticalLayout->setObjectName(QString::fromUtf8("verticalLayout"));
        tableWidget = new QTableWidget(centralWidget);
        if (tableWidget->columnCount() < 3)
            tableWidget->setColumnCount(3);
        QTableWidgetItem *__qtablewidgetitem = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(0, __qtablewidgetitem);
        QTableWidgetItem *__qtablewidgetitem1 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(1, __qtablewidgetitem1);
        QTableWidgetItem *__qtablewidgetitem2 = new QTableWidgetItem();
        tableWidget->setHorizontalHeaderItem(2, __qtablewidgetitem2);
        tableWidget->setObjectName(QString::fromUtf8("tableWidget"));
        tableWidget->setContextMenuPolicy(Qt::ActionsContextMenu);
        tableWidget->setFrameShadow(QFrame::Raised);
        tableWidget->setMidLineWidth(1);
        tableWidget->setEditTriggers(QAbstractItemView::NoEditTriggers);
        tableWidget->setTabKeyNavigation(false);
        tableWidget->setProperty("showDropIndicator", QVariant(false));
        tableWidget->setDragDropOverwriteMode(false);
        tableWidget->setSelectionMode(QAbstractItemView::NoSelection);
        tableWidget->setSelectionBehavior(QAbstractItemView::SelectRows);
        tableWidget->setVerticalScrollMode(QAbstractItemView::ScrollPerItem);
        tableWidget->setGridStyle(Qt::NoPen);
        tableWidget->setRowCount(0);
        tableWidget->setColumnCount(3);

        verticalLayout->addWidget(tableWidget);

        zuluCrypt->setCentralWidget(centralWidget);
        menuBar = new QMenuBar(zuluCrypt);
        menuBar->setObjectName(QString::fromUtf8("menuBar"));
        menuBar->setGeometry(QRect(0, 0, 782, 29));
        menuOpen = new QMenu(menuBar);
        menuOpen->setObjectName(QString::fromUtf8("menuOpen"));
        menuCreate = new QMenu(menuBar);
        menuCreate->setObjectName(QString::fromUtf8("menuCreate"));
        menuHelp = new QMenu(menuBar);
        menuHelp->setObjectName(QString::fromUtf8("menuHelp"));
        menuConfigure = new QMenu(menuBar);
        menuConfigure->setObjectName(QString::fromUtf8("menuConfigure"));
        menuOptions = new QMenu(menuBar);
        menuOptions->setObjectName(QString::fromUtf8("menuOptions"));
        menuFavorites = new QMenu(menuBar);
        menuFavorites->setObjectName(QString::fromUtf8("menuFavorites"));
        menu_zc = new QMenu(menuBar);
        menu_zc->setObjectName(QString::fromUtf8("menu_zc"));
        zuluCrypt->setMenuBar(menuBar);

        menuBar->addAction(menu_zc->menuAction());
        menuBar->addAction(menuOpen->menuAction());
        menuBar->addAction(menuCreate->menuAction());
        menuBar->addAction(menuConfigure->menuAction());
        menuBar->addAction(menuFavorites->menuAction());
        menuBar->addAction(menuOptions->menuAction());
        menuBar->addAction(menuHelp->menuAction());
        menuOpen->addAction(actionFileOpen);
        menuOpen->addAction(actionPartitionOpen);
        menuOpen->addSeparator();
        menuOpen->addSeparator();
        menuCreate->addAction(actionFileCreate);
        menuCreate->addAction(actionEncrypted_Container_In_A_File);
        menuCreate->addAction(actionEncrypted_Container_In_An_Existing_FIle);
        menuCreate->addAction(actionPartitionCreate);
        menuCreate->addAction(actionCreatekeyFile);
        menuHelp->addAction(actionOpen_zuluCrypt_pdf);
        menuHelp->addAction(actionAbout);
        menuConfigure->addAction(actionAddKey);
        menuConfigure->addAction(actionDeleteKey);
        menuConfigure->addSeparator();
        menuConfigure->addAction(actionBackup_header);
        menuConfigure->addAction(actionRestore_header);
        menuConfigure->addSeparator();
        menuConfigure->addAction(actionView_LUKS_Key_Slots);
        menuOptions->addAction(actionTray_icon);
        menuOptions->addAction(actionDo_not_minimize_to_tray);
        menuOptions->addAction(actionAuto_Open_Mount_Point);
        menuOptions->addAction(actionSet_File_Manager);
        menuOptions->addAction(actionSelect_Language);
        menuOptions->addAction(actionSelect_Icons);
        menuOptions->addAction(actionFonts);
        menuOptions->addAction(actionManage_system_partitions);
        menuOptions->addAction(actionManage_non_system_partitions);
        menu_zc->addAction(actionMinimize_to_tray);
        menu_zc->addSeparator();
        menu_zc->addAction(action_update_volume_list);
        menu_zc->addAction(actionClose_all_opened_volumes);
        menu_zc->addSeparator();
        menu_zc->addAction(actionErase_data_on_device);
        menu_zc->addSeparator();
        menu_zc->addAction(actionEncrypt_file);
        menu_zc->addAction(actionDecrypt_file);
        menu_zc->addSeparator();
        menu_zc->addSeparator();
        menu_zc->addAction(actionShow_Debug_Window);
        menu_zc->addSeparator();
        menu_zc->addAction(actionClear_Dead_Mount_Points);
        menu_zc->addSeparator();
        menu_zc->addAction(action_close);

        retranslateUi(zuluCrypt);

        QMetaObject::connectSlotsByName(zuluCrypt);
    } // setupUi

    void retranslateUi(QMainWindow *zuluCrypt)
    {
        zuluCrypt->setWindowTitle(QCoreApplication::translate("zuluCrypt", "zuluCrypt", nullptr));
        actionFileOpen->setText(QCoreApplication::translate("zuluCrypt", "&Volume Hosted In A File", nullptr));
#if QT_CONFIG(shortcut)
        actionFileOpen->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+Z", nullptr));
#endif // QT_CONFIG(shortcut)
        actionPartitionOpen->setText(QCoreApplication::translate("zuluCrypt", "Volume &Hosted In A Hard Drive", nullptr));
#if QT_CONFIG(shortcut)
        actionPartitionOpen->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+X", nullptr));
#endif // QT_CONFIG(shortcut)
        actionFileCreate->setText(QCoreApplication::translate("zuluCrypt", "&Encrypted Container In A New File", nullptr));
#if QT_CONFIG(shortcut)
        actionFileCreate->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+A", nullptr));
#endif // QT_CONFIG(shortcut)
        actionPartitionCreate->setText(QCoreApplication::translate("zuluCrypt", "Encrypted &Container In A Hard Drive", nullptr));
#if QT_CONFIG(shortcut)
        actionPartitionCreate->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+S", nullptr));
#endif // QT_CONFIG(shortcut)
        actionAbout->setText(QCoreApplication::translate("zuluCrypt", "&About", nullptr));
#if QT_CONFIG(shortcut)
        actionAbout->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
        actionAddKey->setText(QCoreApplication::translate("zuluCrypt", "&Add A Key To A Volume", nullptr));
#if QT_CONFIG(shortcut)
        actionAddKey->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+U", nullptr));
#endif // QT_CONFIG(shortcut)
        actionDeleteKey->setText(QCoreApplication::translate("zuluCrypt", "&Delete A Key From A Volume", nullptr));
#if QT_CONFIG(shortcut)
        actionDeleteKey->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+W", nullptr));
#endif // QT_CONFIG(shortcut)
        actionInfo->setText(QCoreApplication::translate("zuluCrypt", "crypto info", nullptr));
#if QT_CONFIG(shortcut)
        actionInfo->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+E", nullptr));
#endif // QT_CONFIG(shortcut)
        actionCreatekeyFile->setText(QCoreApplication::translate("zuluCrypt", "&KeyFile", nullptr));
#if QT_CONFIG(shortcut)
        actionCreatekeyFile->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+D", nullptr));
#endif // QT_CONFIG(shortcut)
        actionTray_icon->setText(QCoreApplication::translate("zuluCrypt", "&Tray Icon", nullptr));
#if QT_CONFIG(shortcut)
        actionTray_icon->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+K", nullptr));
#endif // QT_CONFIG(shortcut)
        actionFonts->setText(QCoreApplication::translate("zuluCrypt", "Select &Font", nullptr));
#if QT_CONFIG(shortcut)
        actionFonts->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+L", nullptr));
#endif // QT_CONFIG(shortcut)
        actionFavorite_volumes->setText(QCoreApplication::translate("zuluCrypt", "favorite volumes", nullptr));
        actionManage_favorites->setText(QCoreApplication::translate("zuluCrypt", "manage favorites", nullptr));
        actionSelect_random_number_generator->setText(QCoreApplication::translate("zuluCrypt", "select random number generator", nullptr));
#if QT_CONFIG(shortcut)
        actionSelect_random_number_generator->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+P", nullptr));
#endif // QT_CONFIG(shortcut)
        actionClose_application->setText(QCoreApplication::translate("zuluCrypt", "close application", nullptr));
#if QT_CONFIG(shortcut)
        actionClose_application->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+C", nullptr));
#endif // QT_CONFIG(shortcut)
        action_update_volume_list->setText(QCoreApplication::translate("zuluCrypt", "&Update Volume List", nullptr));
#if QT_CONFIG(shortcut)
        action_update_volume_list->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+T", nullptr));
#endif // QT_CONFIG(shortcut)
        actionMinimize_to_tray->setText(QCoreApplication::translate("zuluCrypt", "&Minimize To Tray", nullptr));
#if QT_CONFIG(shortcut)
        actionMinimize_to_tray->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+Y", nullptr));
#endif // QT_CONFIG(shortcut)
        action_close->setText(QCoreApplication::translate("zuluCrypt", "&Quit", nullptr));
#if QT_CONFIG(shortcut)
        action_close->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+Q", nullptr));
#endif // QT_CONFIG(shortcut)
        actionClose_all_opened_volumes->setText(QCoreApplication::translate("zuluCrypt", "&Close All Opened Volumes", nullptr));
#if QT_CONFIG(shortcut)
        actionClose_all_opened_volumes->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+G", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_names->setText(QCoreApplication::translate("zuluCrypt", "&Manage Favorites", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_names->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+F", nullptr));
#endif // QT_CONFIG(shortcut)
        actionErase_data_on_device->setText(QCoreApplication::translate("zuluCrypt", "&Erase Data In A Device", nullptr));
#if QT_CONFIG(shortcut)
        actionErase_data_on_device->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+N", nullptr));
#endif // QT_CONFIG(shortcut)
        actionBackup_header->setText(QCoreApplication::translate("zuluCrypt", "&Backup Header", nullptr));
#if QT_CONFIG(shortcut)
        actionBackup_header->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+B", nullptr));
#endif // QT_CONFIG(shortcut)
        actionRestore_header->setText(QCoreApplication::translate("zuluCrypt", "&Restore Header", nullptr));
#if QT_CONFIG(shortcut)
        actionRestore_header->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+P", nullptr));
#endif // QT_CONFIG(shortcut)
        actionPermission_problems->setText(QCoreApplication::translate("zuluCrypt", "permissions", nullptr));
#if QT_CONFIG(shortcut)
        actionPermission_problems->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+I", nullptr));
#endif // QT_CONFIG(shortcut)
        actionEncrypt_file->setText(QCoreApplication::translate("zuluCrypt", "Encrypt A &File", nullptr));
#if QT_CONFIG(shortcut)
        actionEncrypt_file->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+R", nullptr));
#endif // QT_CONFIG(shortcut)
        actionDecrypt_file->setText(QCoreApplication::translate("zuluCrypt", "&Decrypt A File", nullptr));
#if QT_CONFIG(shortcut)
        actionDecrypt_file->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+H", nullptr));
#endif // QT_CONFIG(shortcut)
        actionLuks_header_backup->setText(QCoreApplication::translate("zuluCrypt", "&Header Backup", nullptr));
#if QT_CONFIG(shortcut)
        actionLuks_header_backup->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+J", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_system_partitions->setText(QCoreApplication::translate("zuluCrypt", "Manag&e System Volumes", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_system_partitions->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+C", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_volumes_in_internal_wallet->setText(QCoreApplication::translate("zuluCrypt", "Manage &Volumes In Internal Wallet", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_volumes_in_internal_wallet->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+V", nullptr));
#endif // QT_CONFIG(shortcut)
        actionUse_kde_default_wallet->setText(QCoreApplication::translate("zuluCrypt", "configure wallets", nullptr));
#if QT_CONFIG(shortcut)
        actionUse_kde_default_wallet->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+V", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_non_system_partitions->setText(QCoreApplication::translate("zuluCrypt", "Manage &Non System Volumes", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_non_system_partitions->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+M", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_volumes_in_kde_wallet->setText(QCoreApplication::translate("zuluCrypt", "Manage Volumes In &KDE Wallet", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_volumes_in_kde_wallet->setShortcut(QCoreApplication::translate("zuluCrypt", "Shift+V", nullptr));
#endif // QT_CONFIG(shortcut)
        actionManage_volumes_in_gnome_wallet->setText(QCoreApplication::translate("zuluCrypt", "Manage Volumes In &GNOME keyring", nullptr));
#if QT_CONFIG(shortcut)
        actionManage_volumes_in_gnome_wallet->setShortcut(QCoreApplication::translate("zuluCrypt", "Alt+V", nullptr));
#endif // QT_CONFIG(shortcut)
        actionChange_internal_wallet_password->setText(QCoreApplication::translate("zuluCrypt", "&Change Internal Wallet Password", nullptr));
#if QT_CONFIG(shortcut)
        actionChange_internal_wallet_password->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+O", nullptr));
#endif // QT_CONFIG(shortcut)
        actionTcrypt_backup_header->setText(QCoreApplication::translate("zuluCrypt", "tcrypt backup header", nullptr));
        actionTcrypt_restore_header->setText(QCoreApplication::translate("zuluCrypt", "tcrypt restore header", nullptr));
        actionVeracrypt_container_in_a_file->setText(QCoreApplication::translate("zuluCrypt", "VeraCrypt Container In A File", nullptr));
#if QT_CONFIG(shortcut)
        actionVeracrypt_container_in_a_file->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+E", nullptr));
#endif // QT_CONFIG(shortcut)
        actionVeracrypt_container_in_a_partition->setText(QCoreApplication::translate("zuluCrypt", "VeraCrypt Container In A Hard Drive", nullptr));
#if QT_CONFIG(shortcut)
        actionVeracrypt_container_in_a_partition->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+I", nullptr));
#endif // QT_CONFIG(shortcut)
        actionOpen_zuluCrypt_pdf->setText(QCoreApplication::translate("zuluCrypt", "H&elp", nullptr));
#if QT_CONFIG(shortcut)
        actionOpen_zuluCrypt_pdf->setShortcut(QCoreApplication::translate("zuluCrypt", "F1", nullptr));
#endif // QT_CONFIG(shortcut)
        actionContact_Info->setText(QCoreApplication::translate("zuluCrypt", "Contact &Info", nullptr));
#if QT_CONFIG(shortcut)
        actionContact_Info->setShortcut(QCoreApplication::translate("zuluCrypt", "Shift+I", nullptr));
#endif // QT_CONFIG(shortcut)
        actionSelect_Language->setText(QCoreApplication::translate("zuluCrypt", "&Select Language", nullptr));
        actionAuto_Open_Mount_Point->setText(QCoreApplication::translate("zuluCrypt", "&Auto Open Mount Point", nullptr));
#if QT_CONFIG(shortcut)
        actionAuto_Open_Mount_Point->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+E", nullptr));
#endif // QT_CONFIG(shortcut)
        actionSelect_Icons->setText(QCoreApplication::translate("zuluCrypt", "Select &Icons", nullptr));
        actionSet_File_Manager->setText(QCoreApplication::translate("zuluCrypt", "Set Fi&le Manager", nullptr));
        actionDo_not_minimize_to_tray->setText(QCoreApplication::translate("zuluCrypt", "Do Not Minimize To Tray", nullptr));
#if QT_CONFIG(tooltip)
        actionDo_not_minimize_to_tray->setToolTip(QCoreApplication::translate("zuluCrypt", "This Option Will Close The App Instead Of Minimizing It To Tray", nullptr));
#endif // QT_CONFIG(tooltip)
        actionEncrypted_Container_In_An_Existing_FIle->setText(QCoreApplication::translate("zuluCrypt", "Encrypted Container Hidden In Video/Cover File (Steganography)", nullptr));
#if QT_CONFIG(shortcut)
        actionEncrypted_Container_In_An_Existing_FIle->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+I", nullptr));
#endif // QT_CONFIG(shortcut)
        actionShow_Debug_Window->setText(QCoreApplication::translate("zuluCrypt", "Show Debug Window", nullptr));
#if QT_CONFIG(shortcut)
        actionShow_Debug_Window->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+Shift+D", nullptr));
#endif // QT_CONFIG(shortcut)
        actionEncrypted_Container_In_A_File->setText(QCoreApplication::translate("zuluCrypt", "Encrypted Container In An Existing File", nullptr));
#if QT_CONFIG(shortcut)
        actionEncrypted_Container_In_A_File->setShortcut(QCoreApplication::translate("zuluCrypt", "Ctrl+J", nullptr));
#endif // QT_CONFIG(shortcut)
        actionClear_Dead_Mount_Points->setText(QCoreApplication::translate("zuluCrypt", "Clear Dead Mount Points", nullptr));
        actionView_LUKS_Key_Slots->setText(QCoreApplication::translate("zuluCrypt", "Show LUKS Key Slots", nullptr));
        QTableWidgetItem *___qtablewidgetitem = tableWidget->horizontalHeaderItem(0);
        ___qtablewidgetitem->setText(QCoreApplication::translate("zuluCrypt", "Encrypted Volume Path", nullptr));
        QTableWidgetItem *___qtablewidgetitem1 = tableWidget->horizontalHeaderItem(1);
        ___qtablewidgetitem1->setText(QCoreApplication::translate("zuluCrypt", "Encrypted Volume Mount Point Path", nullptr));
        QTableWidgetItem *___qtablewidgetitem2 = tableWidget->horizontalHeaderItem(2);
        ___qtablewidgetitem2->setText(QCoreApplication::translate("zuluCrypt", "Type", nullptr));
        menuOpen->setTitle(QCoreApplication::translate("zuluCrypt", "&Open", nullptr));
        menuCreate->setTitle(QCoreApplication::translate("zuluCrypt", "&Create", nullptr));
        menuHelp->setTitle(QCoreApplication::translate("zuluCrypt", "&Help", nullptr));
        menuConfigure->setTitle(QCoreApplication::translate("zuluCrypt", "&Volumes", nullptr));
        menuOptions->setTitle(QCoreApplication::translate("zuluCrypt", "Optio&ns", nullptr));
        menuFavorites->setTitle(QCoreApplication::translate("zuluCrypt", "&Favorites", nullptr));
        menu_zc->setTitle(QCoreApplication::translate("zuluCrypt", "&zC", nullptr));
    } // retranslateUi

};

namespace Ui {
    class zuluCrypt: public Ui_zuluCrypt {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_ZULUCRYPT_H
