/********************************************************************************
** Form generated from reading UI file 'dialogmsg.ui'
**
** Created by: Qt User Interface Compiler version 5.15.19
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_DIALOGMSG_H
#define UI_DIALOGMSG_H

#include <QtCore/QVariant>
#include <QtWidgets/QApplication>
#include <QtWidgets/QDialog>
#include <QtWidgets/QLabel>
#include <QtWidgets/QPushButton>

QT_BEGIN_NAMESPACE

class Ui_DialogMsg
{
public:
    QPushButton *pbOk;
    QPushButton *pbYes;
    QPushButton *pbNo;
    QLabel *label;
    QLabel *labelType;
    QLabel *labelCipher;
    QLabel *labelKeySize;
    QLabel *labelDevice;
    QLabel *labelLoop;
    QLabel *labelOffset;
    QLabel *labelSize;
    QLabel *labelMode;
    QLabel *labelFs;
    QLabel *labelSize_2;
    QLabel *labelUsed;
    QLabel *labelUnused;
    QLabel *labelUsedPerc;
    QLabel *labelActiveSlots;

    void setupUi(QDialog *DialogMsg)
    {
        if (DialogMsg->objectName().isEmpty())
            DialogMsg->setObjectName(QString::fromUtf8("DialogMsg"));
        DialogMsg->setWindowModality(Qt::WindowModal);
        DialogMsg->resize(383, 342);
        pbOk = new QPushButton(DialogMsg);
        pbOk->setObjectName(QString::fromUtf8("pbOk"));
        pbOk->setGeometry(QRect(150, 310, 81, 31));
        pbYes = new QPushButton(DialogMsg);
        pbYes->setObjectName(QString::fromUtf8("pbYes"));
        pbYes->setGeometry(QRect(60, 310, 71, 31));
        pbNo = new QPushButton(DialogMsg);
        pbNo->setObjectName(QString::fromUtf8("pbNo"));
        pbNo->setGeometry(QRect(260, 310, 75, 31));
        label = new QLabel(DialogMsg);
        label->setObjectName(QString::fromUtf8("label"));
        label->setGeometry(QRect(260, 240, 41, 31));
        label->setTextFormat(Qt::PlainText);
        label->setAlignment(Qt::AlignCenter);
        label->setWordWrap(true);
        labelType = new QLabel(DialogMsg);
        labelType->setObjectName(QString::fromUtf8("labelType"));
        labelType->setGeometry(QRect(0, 20, 381, 21));
        labelType->setAlignment(Qt::AlignCenter);
        labelType->setWordWrap(true);
        labelCipher = new QLabel(DialogMsg);
        labelCipher->setObjectName(QString::fromUtf8("labelCipher"));
        labelCipher->setGeometry(QRect(0, 40, 381, 21));
        labelCipher->setAlignment(Qt::AlignCenter);
        labelKeySize = new QLabel(DialogMsg);
        labelKeySize->setObjectName(QString::fromUtf8("labelKeySize"));
        labelKeySize->setGeometry(QRect(0, 60, 381, 21));
        labelKeySize->setAlignment(Qt::AlignCenter);
        labelDevice = new QLabel(DialogMsg);
        labelDevice->setObjectName(QString::fromUtf8("labelDevice"));
        labelDevice->setGeometry(QRect(0, 100, 381, 21));
        labelDevice->setAlignment(Qt::AlignCenter);
        labelDevice->setWordWrap(true);
        labelLoop = new QLabel(DialogMsg);
        labelLoop->setObjectName(QString::fromUtf8("labelLoop"));
        labelLoop->setGeometry(QRect(0, 120, 381, 21));
        labelLoop->setAlignment(Qt::AlignCenter);
        labelLoop->setWordWrap(true);
        labelOffset = new QLabel(DialogMsg);
        labelOffset->setObjectName(QString::fromUtf8("labelOffset"));
        labelOffset->setGeometry(QRect(0, 80, 381, 21));
        labelOffset->setAlignment(Qt::AlignCenter);
        labelSize = new QLabel(DialogMsg);
        labelSize->setObjectName(QString::fromUtf8("labelSize"));
        labelSize->setGeometry(QRect(0, 140, 381, 21));
        labelSize->setAlignment(Qt::AlignCenter);
        labelMode = new QLabel(DialogMsg);
        labelMode->setObjectName(QString::fromUtf8("labelMode"));
        labelMode->setGeometry(QRect(0, 160, 381, 21));
        labelMode->setAlignment(Qt::AlignCenter);
        labelFs = new QLabel(DialogMsg);
        labelFs->setObjectName(QString::fromUtf8("labelFs"));
        labelFs->setGeometry(QRect(0, 200, 381, 21));
        labelFs->setAlignment(Qt::AlignCenter);
        labelSize_2 = new QLabel(DialogMsg);
        labelSize_2->setObjectName(QString::fromUtf8("labelSize_2"));
        labelSize_2->setGeometry(QRect(0, 220, 381, 21));
        labelSize_2->setAlignment(Qt::AlignCenter);
        labelUsed = new QLabel(DialogMsg);
        labelUsed->setObjectName(QString::fromUtf8("labelUsed"));
        labelUsed->setGeometry(QRect(0, 240, 381, 20));
        labelUsed->setAlignment(Qt::AlignCenter);
        labelUnused = new QLabel(DialogMsg);
        labelUnused->setObjectName(QString::fromUtf8("labelUnused"));
        labelUnused->setGeometry(QRect(0, 260, 381, 20));
        labelUnused->setAlignment(Qt::AlignCenter);
        labelUsedPerc = new QLabel(DialogMsg);
        labelUsedPerc->setObjectName(QString::fromUtf8("labelUsedPerc"));
        labelUsedPerc->setGeometry(QRect(0, 280, 381, 20));
        labelUsedPerc->setAlignment(Qt::AlignCenter);
        labelActiveSlots = new QLabel(DialogMsg);
        labelActiveSlots->setObjectName(QString::fromUtf8("labelActiveSlots"));
        labelActiveSlots->setGeometry(QRect(0, 180, 381, 20));
        labelActiveSlots->setAlignment(Qt::AlignCenter);

        retranslateUi(DialogMsg);

        QMetaObject::connectSlotsByName(DialogMsg);
    } // setupUi

    void retranslateUi(QDialog *DialogMsg)
    {
        DialogMsg->setWindowTitle(QCoreApplication::translate("DialogMsg", "Dialog", nullptr));
        pbOk->setText(QCoreApplication::translate("DialogMsg", "&Ok", nullptr));
        pbYes->setText(QCoreApplication::translate("DialogMsg", "&Yes", nullptr));
        pbNo->setText(QCoreApplication::translate("DialogMsg", "&No", nullptr));
        label->setText(QCoreApplication::translate("DialogMsg", "text", nullptr));
        labelType->setText(QCoreApplication::translate("DialogMsg", "type", nullptr));
        labelCipher->setText(QCoreApplication::translate("DialogMsg", "cipher", nullptr));
        labelKeySize->setText(QCoreApplication::translate("DialogMsg", "key size", nullptr));
        labelDevice->setText(QCoreApplication::translate("DialogMsg", "device", nullptr));
        labelLoop->setText(QCoreApplication::translate("DialogMsg", "loop", nullptr));
        labelOffset->setText(QCoreApplication::translate("DialogMsg", "offset", nullptr));
        labelSize->setText(QCoreApplication::translate("DialogMsg", "size", nullptr));
        labelMode->setText(QCoreApplication::translate("DialogMsg", "mode", nullptr));
        labelFs->setText(QCoreApplication::translate("DialogMsg", "fs", nullptr));
        labelSize_2->setText(QCoreApplication::translate("DialogMsg", "size", nullptr));
        labelUsed->setText(QCoreApplication::translate("DialogMsg", "used", nullptr));
        labelUnused->setText(QCoreApplication::translate("DialogMsg", "unused", nullptr));
        labelUsedPerc->setText(QCoreApplication::translate("DialogMsg", "used %", nullptr));
        labelActiveSlots->setText(QCoreApplication::translate("DialogMsg", "active slots", nullptr));
    } // retranslateUi

};

namespace Ui {
    class DialogMsg: public Ui_DialogMsg {};
} // namespace Ui

QT_END_NAMESPACE

#endif // UI_DIALOGMSG_H
